@@ -84,7 +84,7 @@ assignOptions <- function(options) {
 		    Debug		= options[31],
 		    CrossValidate	= options[32],
 		    TriggersCut 	= options[33],  #if TRUE ten cut by triggers, else use TriggersOnList (if any) only for vertical ablines on instaneous graphs
-		    TriggersOnList	= as.numeric(unlist(strsplit(options[34], "\\;")))
+		    TriggersOnList	= as.numeric(unlist(strsplit(options[34], "\\;"))),
 
 		    #Triggers:
 		    #  at capture.R
@@ -98,6 +98,8 @@ assignOptions <- function(options) {
 		    #Unassigned here:
 		    #	englishWords [29]
 		    #	translatedWords [30]
+		    SeparateSessionInDays = options[35],
+		    AnalysisMode 	 = options[36]
 		    ))
 }
 
@@ -529,11 +531,11 @@ assignRepOptions <- function(
 
 
 
-#go here with every single curve
+#go here with every single repetition
 #repOp has the options for this repetition
-#repOp$eccon="c" one time each curve
-#repOp$eccon="ec" one time each curve
-#repOp$eccon="ecS" means ecSeparated. two times each curve: one for "e", one for "c"
+#repOp$eccon="c" one time each repetitions
+#repOp$eccon="ec" one time each repetition
+#repOp$eccon="ecS" means ecSeparated. two times each repetition: one for "e", one for "c"
 #kinematicsF <- function(displacement, massBody, massExtra, exercisePercentBodyWeight,
 #			encoderConfigurationName,diameter,diameterExt,anglePush,angleWeight,inertiaMomentum,gearedDown,
 #			smoothingOneEC, smoothingOneC, g, eccon, isPropulsive)
@@ -851,6 +853,8 @@ getDynamicsNotInertial <- function(encoderConfigurationName, speed, accel,
                 force <- massBody*(accel + g*sin(anglePush * pi / 180)) + massExtra*(g*sin(angleWeight * pi / 180) + accel) / gearedDown
         } else if(encoderConfigurationName == "LINEARONPLANE"){
                 force <- (massBody + massExtra)*(accel + g*sin(anglePush * pi / 180))
+        } else if(encoderConfigurationName == "PNEUMATIC"){
+                force  = massExtra * g + massBody * (accel + g*sin(anglePush * pi / 180))         #The force generated by the machine is supposed to be constant
         } else {
                 force <- massTotal*(accel+g)	#g:9.81 (used when movement is against gravity)
         }
