@@ -72,7 +72,7 @@ source(paste(op$scriptsPath, "/scripts-util.R", sep=""))
 #Fits the data to the model f = fmax*(1 - exp(-K*t))
 #Important! It fits the data with the axes moved to initf and startTime. The real maximum force is fmax + initf
 getForceModel <- function(time, force, startTime, # startTime is the instant when the force start to increase
-                          fmaxi,           # fmaxi is the initial value for the force. For numeric purpouses
+                          fmaxi,           # fmaxi is the initial value for the fmax. For numeric purpouses
                           initf)              # initf is the sustained force before the increase
 {
         #We force that the function crosses the (0,0) to better fit the monoexponential
@@ -81,12 +81,13 @@ getForceModel <- function(time, force, startTime, # startTime is the instant whe
         
         data = data.frame(time = time, force = force)
         model = nls( force ~ fmax*(1-exp(-K*time)), data, start=list(fmax=fmaxi, K=1), control=nls.control(warnOnly=TRUE))
+
         fmax = summary(model)$coeff[1,1]
         K = summary(model)$coeff[2,1]
-        return(list(fmax = fmax, K = K))
+        return(list(fmax = fmax, K = K, error =sum(abs(residuals(model)))))
 }
 
-getDynamicsFromLoadCellFile <- function(inputFile, averageLength = 0.1, percentChange = 5)
+getDynamicsFromLoadCellFile <- function(inputFile, averageLength = 0.1, percentChange = 5, bestFit = TRUE, testLength = -1)
 {
         originalTest = read.csv(inputFile, header = F, dec = op$decimalChar, sep = ";", skip = 2)
         colnames(originalTest) <- c("time", "force")
@@ -115,13 +116,63 @@ getDynamicsFromLoadCellFile <- function(inputFile, averageLength = 0.1, percentC
         initf = mean(originalTest$force[(startSample - 20):(startSample - 10)]) #ATENTION. This value is different from f0.raw
         fmax.raw = max(originalTest$force[startSample:endSample])
         
+        f.smoothed = getMovingAverageForce(originalTest, averageLength = averageLength) #Running average with equal weight averageLength seconds
+        fmax.smoothed = max(f.smoothed, na.rm = TRUE)
+        lastRelativeError = 1E16
         #Trimming the data before and after contraction
         testTrimmed = originalTest[startSample:endSample,]
         
-        f.smoothed = getMovingAverageForce(originalTest, averageLength = averageLength) #Running average with equal weight averageLength seconds
-        fmax.smoothed = max(f.smoothed, na.rm = TRUE)
-        
         model = getForceModel(testTrimmed$time, testTrimmed$force, startTime, fmax.smoothed, initf)
+        relativeError = model$error / length(testTrimmed$force)
+        
+        # print(paste("Error:", model$error))
+        # print(paste("length:", length(testTrimmed$force)))
+        # print(paste("Relative Error:", relativeError))
+        # print("--------")
+        
+        
+        if(bestFit)     #looking for the startSample that best fits the data
+        {
+                while(relativeError < lastRelativeError)
+                {
+                        lastRelativeError = relativeError
+                        
+                        startSample = startSample + 1
+                        startTime = originalTest$time[startSample]
+                        
+                        #Make this only if testLength = -1
+                        if (testLength != -1){
+                                endSample = endSample + 1
+                                endTime = originalTest$time[endSample]
+                        }
+                        
+                        
+                        #Trimming the data before and after contraction
+                        testTrimmed = originalTest[startSample:endSample,]
+                        
+                        model = getForceModel(testTrimmed$time, testTrimmed$force, startTime, fmax.smoothed, initf)
+                        relativeError = model$error / length(testTrimmed$force)
+                        
+                        #print(paste("Error:", model$error))
+                        #print(paste("length:", length(testTrimmed$force)))
+                        #print(paste("Relative Error:", model$error / length(testTrimmed$force)))
+                        #print("--------")
+                }
+                
+                #going back to the last sample
+                startSample = startSample - 1
+                startTime = originalTest$time[startSample]
+                
+                endTime = originalTest$time[endSample]
+                
+                
+                #Trimming the data before and after contraction
+                testTrimmed = originalTest[startSample:endSample,]
+                
+                model = getForceModel(testTrimmed$time, testTrimmed$force, startTime, fmax.smoothed, initf)
+        }
+        
+        
         f.fitted =model$fmax*(1-exp(-model$K*(originalTest$time - startTime)))
         
         f0.raw = testTrimmed$force[1]                                                  # Force at t=0ms. ATENTION. This value is different than initf
@@ -139,7 +190,8 @@ getDynamicsFromLoadCellFile <- function(inputFile, averageLength = 0.1, percentC
                     tfmax.raw = tfmax.raw,
                     rfd = rfd,
                     f.raw = originalTest$force, f.smoothed = f.smoothed, f.fitted = f.fitted,
-                    endTime = endTime))
+                    endTime = endTime,
+                    relativeError = relativeError))
 }
 
 drawDynamicsFromLoadCell <- function(
@@ -240,21 +292,8 @@ drawDynamicsFromLoadCell <- function(
                                 c(dynamics$f.raw[startImpulseSample:endImpulseSample], 0, 0), col = "grey")
                         
                         #Calculation of the impulse
-                        #Sum of the area of all the triangles formed with a vertex in the origin and the other vertex in the
-                        #n-th and (n+1)-th point of the polygon
-                        impulse = 0
-                        for(n in startImpulseSample:(endImpulseSample - 1))
-                        {
-                                #Area of the paralelograms, not the triangle
-                                area = ((dynamics$time[n+1] - dynamics$time[dynamics$startSample]) * dynamics$f.raw[n] - (dynamics$time[n] - dynamics$time[dynamics$startSample]) * dynamics$f.raw[n+1])
-                                impulse = impulse + area
-                        }
-                        
-                        area = (dynamics$time[endImpulseSample] - dynamics$time[dynamics$startSample]) * dynamics$f.raw[endImpulseSample]
-                        impulse = impulse + area
-                        
-                        #Area under the curve is one half of the sum of the area of paralelograms
-                        impulse = impulse / 2
+                        impulse = getAreaUnderCurve(dynamics$time[startImpulseSample:endImpulseSample], dynamics$f.raw[startImpulseSample:endImpulseSample])
+             
                 } else if(impulseOptions$impulseFunction == "FITTED")
                 {
                         impulseColor = "blue"
@@ -268,19 +307,21 @@ drawDynamicsFromLoadCell <- function(
                         #Calculation of the impulse
                         #Sum of the area of all the triangles formed with a vertex in the origin and the other vertex in the
                         #n-th and (n+1)-th point of the polygon
-                        impulse = 0
-                        for(n in startImpulseSample:(endImpulseSample - 1))
-                        {
-                                #Area of the paralelograms, not the triangle
-                                area = ((dynamics$time[n+1] - dynamics$time[dynamics$startSample]) * dynamics$f.fitted[n] - (dynamics$time[n] - dynamics$time[dynamics$startSample]) * dynamics$f.fitted[n+1])
-                                impulse = impulse + area
-                        }
-                        
-                        area = (dynamics$time[endImpulseSample] - dynamics$time[dynamics$startSample]) * dynamics$f.fitted[endImpulseSample]
-                        impulse = impulse + area
-                        
+                        # impulse = 0
+                        # for(n in startImpulseSample:(endImpulseSample - 1))
+                        # {
+                        #         #Area of the paralelograms, not the triangle
+                        #         area = ((dynamics$time[n+1] - dynamics$time[dynamics$startSample]) * dynamics$f.fitted[n] - (dynamics$time[n] - dynamics$time[dynamics$startSample]) * dynamics$f.fitted[n+1])
+                        #         impulse = impulse + area
+                        # }
+                        # 
+                        # area = (dynamics$time[endImpulseSample] - dynamics$time[dynamics$startSample]) * dynamics$f.fitted[endImpulseSample]
+                        # impulse = impulse + area
                         #Area under the curve is one half of the sum of the area of paralelograms
-                        impulse = impulse / 2
+                        #impulse = impulse / 2
+                        impulse = getAreaUnderCurve(dynamics$time[startImpulseSample:endImpulseSample], dynamics$f.fitted[startImpulseSample:endImpulseSample])
+                        
+                        
                 }
                 
                 text(x = (dynamics$startTime + (dynamics$time[endImpulseSample] - dynamics$time[startImpulseSample])*0.66), y = mean(dynamics$f.raw[startImpulseSample:endImpulseSample])*0.66,
@@ -376,6 +417,9 @@ drawDynamicsFromLoadCell <- function(
                 
                 print(paste("---- RFD number", n, "--------"))
                 print(options)
+                if(RFDoptions$type == "AVERAGE" & (RFDoptions$start == RFDoptions$end)){
+                        RFDoptions$type = "INSTANTANEOUS"
+                }
                 if(RFDoptions$rfdFunction == "-1")        
                 {
                         next
@@ -554,6 +598,9 @@ drawDynamicsFromLoadCell <- function(
 		legendText = c(legendText, impulseLegend)
                 legendColor = c(legendColor, impulseColor)
 	}
+        
+        legendText = c(legendText, paste("MeanError = ", round(dynamics$relativeError, digits = 2), " N", sep =""))
+        legendColor = c(legendColor, "red")
 
 	legend(x = xmax, y = dynamics$fmax.fitted/2, legend = legendText, xjust = 1, yjust = 0.1, text.col = legendColor)
 }
@@ -628,7 +675,7 @@ getTrimmingSamples <- function(test, rfd, movingAverageForce, averageLength = 0.
                                 startSample = currentSample
                 }
         }
-        
+        #Using the decrease of the force to detect endingSample
         if (testLength <= -1){
                 endSample = startSample + 1
                 maxAverageForce = movingAverageForce[endSample]
@@ -643,6 +690,8 @@ getTrimmingSamples <- function(test, rfd, movingAverageForce, averageLength = 0.
                 }
         } else if(testLength >= 0 && testLength < 0.1){
                 print("Test interval too short")
+                
+        #Using the fixed time to detect endSample
         } else {
                 endSample = which.min(abs(test$time[startSample] + testLength - test$time))
         }
@@ -718,7 +767,8 @@ readImpulseOptions <- function(optionsStr)
 }
 
 prepareGraph(op$os, pngFile, op$graphWidth, op$graphHeight)
-dynamics = getDynamicsFromLoadCellFile(dataFile, op$averageLength, op$percentChange)
+
+dynamics = getDynamicsFromLoadCellFile(dataFile, op$averageLength, op$percentChange, bestFit = TRUE, testLength = -1)
 drawDynamicsFromLoadCell(dynamics, op$vlineT0, op$vline50fmax.raw, op$vline50fmax.fitted, op$hline50fmax.raw, op$hline50fmax.fitted,
                          op$drawRfdOptions)
 #                         op$drawRfdOptions, xlimits = c(0.5, 1.5))
