@@ -22,7 +22,7 @@ args <- commandArgs(TRUE)
 
 tempPath <- args[1]
 optionsFile <- paste(tempPath, "/Roptions.txt", sep="")
-pngFile <- paste(tempPath, "/sprintGraph.png", sep="")
+pngFile <- paste(tempPath, "/sprintEncoderGraph.png", sep="")
 
 #-------------- scan options file -------------
 options <- scan(optionsFile, comment.char="#", what=character(), sep="\n")
@@ -51,6 +51,7 @@ op <- assignOptions(options)
 
 getSprintFromEncoder <- function(filename, testLength, Mass, Temperature = 25, Height , Vw = 0)
 {
+        print("#####Entering in getSprintFromEncoder###############")
         # Constants for the air friction modeling
         ro0 = 1.293
         Pb = 760
@@ -59,31 +60,76 @@ getSprintFromEncoder <- function(filename, testLength, Mass, Temperature = 25, H
         Af = 0.2025*(Height^0.725)*(Mass^0.425)*0.266 # Model of the frontal area
         Ka = 0.5*ro*Af*Cd
         
-        encoderCarrera = read.csv2(file = filename, sep = ";")
-        colnames(encoderCarrera) = c("displacement", "time")
-        totalTime = encoderCarrera$time/1E6     #Converting microseconds to seconds
+        raceAnalyzer = read.csv2(file = filename, sep = ";")
+        colnames(raceAnalyzer) = c("displacement", "time", "force")
+        raceAnalyzer$force = (raceAnalyzer$force) * 0.175806451613 /2  #TODO: Implement the calibration factor comming from the arduino
+        totalTime = raceAnalyzer$time/1E6     #Converting microseconds to seconds
         elapsedTime = diff(c(0,totalTime))      #The elapsed time between each sample
         
         #The encoder can be used with both loose ends of the rope. This means that the encoder can rotate
         #in both directions. We considre always the speed as positive.
-        if(mean(encoderCarrera$displacement) < 0)
-                encoderCarrera$displacement = -encoderCarrera$displacement
+        if(mean(raceAnalyzer$displacement) < 0)
+                raceAnalyzer$displacement = -raceAnalyzer$displacement
         diameter = 0.16         #Diameter of the pulley
-        #encoderCarrera$displacement = encoderCarrera$displacement * 2 * pi * diameter / 200
+        #raceAnalyzer$displacement = raceAnalyzer$displacement * 2 * pi * diameter / 200
         #In 30m there are 12267 pulses.
         #TODO: measure this several times to have an accurate value
-        encoderCarrera$displacement = encoderCarrera$displacement * 30 / 12267
-        position = cumsum(encoderCarrera$displacement)
-        speed = encoderCarrera$displacement / elapsedTime
-        #accel = c(0,diff(speed)/elapsedTime[2:length(elapsedTime)])
+        raceAnalyzer$displacement = 4 * raceAnalyzer$displacement * 30 / 12267
+        position = cumsum(raceAnalyzer$displacement)
+        speed = raceAnalyzer$displacement / elapsedTime
         accel = (speed[3] - speed[1]) / (totalTime[3] - totalTime[1])
-        for(i in 3:length(speed))
+        for(i in 3:(length(speed) -1))
         {
                 accel = c(accel, (speed[i+1] - speed[i-1]) / (totalTime[i +1] - totalTime[i -1]))
         }
-        accel = c(accel, accel[length(accel)])
-        force = accel * Mass + Ka*(speed - Vw)^2
-        power = force * speed
+        accel = c(accel[1],accel, accel[length(accel)])
+        forceBody = accel * Mass + Ka*(speed - Vw)^2
+        totalForce = forceBody + raceAnalyzer$force
+        power = totalForce * speed
+        # print("time:")
+        # print(raceAnalyzer$time)
+        # print("elapsedTime:")
+        # print(elapsedTime)
+        # print("position:")
+        # print(position)
+        # print("speed:")
+        # print(speed)
+        # print("accel:")
+        # print(accel)
+        # print("forceBody:")
+        # print(forceBody)
+        # print("forceRope:")
+        # print(raceAnalyzer$force)
+        print("power:")
+        print(power)
+        
+        
+        # #Checking if the sprint is long enough
+        # longEnough = TRUE
+        # if(position[length(position)] <= testLength){
+        #         longEnough = FALSE
+        #         return(list(longEnough = longEnough))
+        # }
+        
+        #Checking that the position reaches at least testLength
+        if(max(position) < testLength)
+        {
+                plot(totalTime, position, type = "l",
+                     ylim = c(min(position), testLength)*1.05,
+                     xlab = "Time (s)", ylab = "Position (m)")
+                abline(h = testLength, lty = 2)
+                text(x = (totalTime[length(totalTime)] + totalTime[1])/2,
+                     y = testLength,
+                     labels = (paste("Configured test length :", testLength, "m", sep = "")),
+                     pos = 3)
+                text(x = (totalTime[length(totalTime)] + totalTime[1])/2, testLength /2,
+                     labels = "The capture does not reach the length of the test", cex = 2, pos = 3)
+                print("Capture too short")
+                longEnough = FALSE
+                return(list(longEnough = longEnough))
+        } else{
+                longEnough = TRUE
+        }
         
         #Finding when the sprint starts
         trimmingSamples = getTrimmingSamples(totalTime, position, speed, accel, testLength)
@@ -93,19 +139,46 @@ getSprintFromEncoder <- function(filename, testLength, Mass, Temperature = 25, H
         #Zeroing position to the initial acceleration sample
         position = position - position[trimmingSamples$start]
         data = data.frame(time = time[trimmingSamples$start:trimmingSamples$end], speed = speed[trimmingSamples$start:trimmingSamples$end])
-        model = nls(speed ~ Vmax*(1-exp(-K*time)), data,
-                    start = list(Vmax = max(speed), K = 1), control=nls.control(warnOnly=TRUE))
-        Vmax =summary(model)$coeff[1,1]
-        K = summary(model)$coeff[2,1]
+        #print(data)
+        
+        print("Trying nls")
+        regression = tryNLS(data)
+        
+        print("regression:")
+        print(regression)
+        print(paste("longEnough:", longEnough))
+        print(paste("regressionDone:", regression$regressionDone))
+        
+        if (!regression$regressionDone)
+        {
+                print("NLS regression problem")
+                plot(totalTime, speed, type = "l",
+                     #ylim = c(min(speed), testLength)*1.05,
+                     xlab = "Time (s)", ylab = "Speed (m/s)")
+                #abline(h = testLength, lty = 2)
+                # text(x = (totalTime[length(totalTime)] + totalTime[1])/2,
+                #      y = testLength,
+                #      labels = (paste("Configured test length :", testLength, "m", sep = "")),
+                #      pos = 3)
+                text(x = (totalTime[length(totalTime)] + totalTime[1])/2, max(speed) /2,
+                     labels = "The graph doesn't seem a sprint", cex = 2, pos = 3)
+                return(list(longEnough = longEnough, regressionDone = regression$regressionDone))
+        }
+        
+                
+        #model = nls(speed ~ Vmax*(1-exp(-K*time)), data,
+        #            start = list(Vmax = max(speed), K = 1), control=nls.control(warnOnly=TRUE))
+        Vmax =summary(regression$model)$coeff[1,1]
+        K = summary(regression$model)$coeff[2,1]
         return(list(Vmax = Vmax, K = K,
-                    time = time, rawPosition = position, rawSpeed = speed, rawAccel = accel, rawForce = force, rawPower = power,
-                    rawVmax = max(speed[trimmingSamples$start:trimmingSamples$end]), rawAmax = max(accel[trimmingSamples$start:trimmingSamples$end]), rawFmax = max(force[trimmingSamples$start:trimmingSamples$end]), rawPmax = max(power[trimmingSamples$start:trimmingSamples$end]),
-                    startSample = trimmingSamples$start, endSample = trimmingSamples$end, testLength = testLength))
+                    time = time, rawPosition = position, rawSpeed = speed, rawAccel = accel, rawForce = totalForce, rawPower = power,
+                    rawVmax = max(speed[trimmingSamples$start:trimmingSamples$end]), rawAmax = max(accel[trimmingSamples$start:trimmingSamples$end]), rawFmax = max(totalForce[trimmingSamples$start:trimmingSamples$end]), rawPmax = max(power[trimmingSamples$start:trimmingSamples$end]),
+                    startSample = trimmingSamples$start, endSample = trimmingSamples$end, testLength = testLength, longEnough = longEnough, regressionDone = regression$regressionDone))
 }
 
 plotSprintFromEncoder <- function(sprintRawDynamics, sprintFittedDynamics, title = "Test graph",
-                                  plotRawMeanSpeed = TRUE, plotRawSpeed = TRUE, plotRawAccel = TRUE, plotRawForce = TRUE, plotRawPower = FALSE,
-                                  plotFittedSpeed = TRUE, plotFittedAccel = FALSE, plotFittedForce = TRUE, plotFittedPower = FALSE)
+                                  plotRawMeanSpeed = TRUE, plotRawSpeed = TRUE, plotRawAccel = FALSE, plotRawForce = FALSE, plotMeanRawForce = TRUE, plotRawPower = FALSE, plotMeanRawPower = TRUE,
+                                  plotFittedSpeed = TRUE, plotFittedAccel = FALSE, plotFittedForce = FALSE, plotFittedPower = FALSE)
 {
         #Plotting position
         # plot(sprintRawDynamics$time[sprintRawDynamics$startSample:sprintRawDynamics$endSample], sprintRawDynamics$rawPosition[sprintRawDynamics$startSample:sprintRawDynamics$endSample],
@@ -117,9 +190,10 @@ plotSprintFromEncoder <- function(sprintRawDynamics, sprintFittedDynamics, title
         # mtext(side = 3, at = raceTime, text = paste(sprintRawDynamics$testLength, "m", sep=""))
         # mtext(side = 1, at = raceTime, text = paste(round(raceTime, digits = 3), "s", sep=""))
 
+        print("#######Entering plotSprintFromEncoder###########")
         par(mar = c(7, 4, 5, 6.5))
         
-        #Checking that the position reach at least testLength
+        #Checking that the position reaches at least testLength
         if(max(sprintRawDynamics$rawPosition) < sprintRawDynamics$testLength)
         {
                 plot(sprintRawDynamics$time, sprintRawDynamics$rawPosition, type = "l",
@@ -140,11 +214,14 @@ plotSprintFromEncoder <- function(sprintRawDynamics, sprintFittedDynamics, title
         ylimits = c(0, sprintRawDynamics$rawVmax*1.05)
         xlimits =c(0, sprintRawDynamics$time[sprintRawDynamics$endSample]*1.05)
         #Calculing 5m lap times
-        splitPosition = 5
+        splitPosition = min(sprintRawDynamics$testLength, 5)
         splitTime = interpolateXAtY(sprintRawDynamics$time[sprintRawDynamics$startSample:sprintRawDynamics$endSample],
                                   sprintRawDynamics$rawPosition[sprintRawDynamics$startSample:sprintRawDynamics$endSample],
                                   splitPosition)
         meanSpeed = splitPosition / splitTime
+        meanForce =getMeanValue(sprintRawDynamics$time, sprintRawDynamics$rawForce, sprintRawDynamics$time[sprintRawDynamics$startSample], splitTime)
+        meanPower =getMeanValue(sprintRawDynamics$time, sprintRawDynamics$rawPower, sprintRawDynamics$time[sprintRawDynamics$startSample], splitTime)
+
         while(splitPosition[length(splitPosition)] + 5 < sprintRawDynamics$testLength)
         {
                 splitPosition = c(splitPosition, splitPosition[length(splitPosition)] + 5)
@@ -153,6 +230,10 @@ plotSprintFromEncoder <- function(sprintRawDynamics, sprintFittedDynamics, title
                                                      splitPosition[length(splitPosition)]))
                 meanSpeed = c(meanSpeed, (splitPosition[length(splitPosition)] - splitPosition[length(splitPosition) -1]) /
                                       (splitTime[length(splitTime)] - splitTime[length(splitTime) -1]))
+                meanForce = c(meanForce, getMeanValue(sprintRawDynamics$time, sprintRawDynamics$rawForce,
+                                                      splitTime[length(splitTime) -1], splitTime[length(splitTime)]))
+                meanPower = c(meanPower, getMeanValue(sprintRawDynamics$time, sprintRawDynamics$rawPower,
+                                                      splitTime[length(splitTime) -1], splitTime[length(splitTime)]))
         }
         splitPosition = c(splitPosition, sprintRawDynamics$testLength)
         splitTime = c(splitTime, interpolateXAtY(sprintRawDynamics$time[sprintRawDynamics$startSample:sprintRawDynamics$endSample],
@@ -161,6 +242,15 @@ plotSprintFromEncoder <- function(sprintRawDynamics, sprintFittedDynamics, title
         meanSpeed = c(meanSpeed, (splitPosition[length(splitPosition)] - splitPosition[length(splitPosition) -1]) /
                               (splitTime[length(splitTime)] - splitTime[length(splitTime) -1]))
         
+        meanForce = c(meanForce, getMeanValue(sprintRawDynamics$time, sprintRawDynamics$rawForce,
+                                              splitTime[length(splitTime) -1], splitTime[length(splitTime)]))
+        meanPower = c(meanPower, getMeanValue(sprintRawDynamics$time, sprintRawDynamics$rawPower,
+                                              splitTime[length(splitTime) -1], splitTime[length(splitTime)]))
+        print("meanForce:")
+        print(meanForce)
+        print("meanPower:")
+        print(meanPower)
+        
         if(plotRawMeanSpeed)
         {
                 barplot(height = meanSpeed, width = diff(c(0,splitTime)), space = 0,
@@ -186,7 +276,7 @@ plotSprintFromEncoder <- function(sprintRawDynamics, sprintFittedDynamics, title
         mtext(side = 3, at = splitTime, text = paste(splitPosition, "m", sep=""))
         mtext(side = 1, at = splitTime, text = paste(round(splitTime, digits = 3), "s", sep=""))
         
-        legendText = paste("Vmax.raw =", round(max(sprintRawDynamics$rawSpeed), digits = 2), "m/s")
+        legendText = paste("Vmax.raw =", round(sprintRawDynamics$rawVmax, digits = 2), "m/s")
         legendColor = "black"
 
         if (plotFittedSpeed)
@@ -229,6 +319,7 @@ plotSprintFromEncoder <- function(sprintRawDynamics, sprintFittedDynamics, title
         if(plotRawForce|| plotFittedForce)
         {
                 ylimits = c(min(sprintRawDynamics$rawForce[sprintRawDynamics$startSample:sprintRawDynamics$endSample])*0.95, max(c(sprintRawDynamics$rawFmax, sprintFittedDynamics$fmax.fitted)*1.05))
+                #ylimits = c(0,sprintFittedDynamics$fmax.fitted)
                 if (plotRawForce)
                 {
                         #Plotting rawForce
@@ -253,11 +344,33 @@ plotSprintFromEncoder <- function(sprintRawDynamics, sprintFittedDynamics, title
                         legendColor = c(legendColor, "blue")
                 }
                 axis(side = 4, col = "blue", line = 2)
+                print("Mean force from the model")
+                print(getMeanValue(sprintFittedDynamics$t.fitted, sprintRawDynamics$force.fitted, 0, 1.004))
+        }     
+
+        if(plotMeanRawForce)
+        {
+                par(new = TRUE)
+                ylimits = c(min(sprintRawDynamics$rawForce[sprintRawDynamics$startSample:sprintRawDynamics$endSample])*0.95,
+                            max(c(sprintRawDynamics$rawFmax, sprintFittedDynamics$fmax.fitted)*1.05))
+                plot(NULL, NULL,
+                     ylim = ylimits,
+                     xlim = c(sprintRawDynamics$time[sprintRawDynamics$startSample], sprintRawDynamics$time[sprintRawDynamics$endSample]),
+                     xlab = "", ylab = "",
+                     axes = FALSE, yaxs = "i", xaxs = "i")
+                text(splitTime[1]*0.2, meanForce[1], paste(round(meanForce[1], digits = 2), "N"), col = "blue")
+                for(n in 1:length(meanForce))
+                {
+                        text(splitTime[n] + (splitTime[n+1] - splitTime[n])*0.2, meanForce[n+1], paste(round(meanForce[n+1], digits = 2), "N"), col = "blue")
+                        
+                }
+                #axis(side = 4, col = "blue", line = 2)
         }
         
         if(plotRawPower|| plotFittedPower)
         {
-                ylimits = c(min(sprintRawDynamics$rawPower[sprintRawDynamics$startSample:sprintRawDynamics$endSample])*0.95, max(c(sprintRawDynamics$rawPmax, sprintFittedDynamics$pmax.fitted)*1.05))
+                ylimits = c(min(sprintRawDynamics$rawPower[sprintRawDynamics$startSample:sprintRawDynamics$endSample])*0.95,
+                            max(c(sprintRawDynamics$rawPmax, sprintFittedDynamics$pmax.fitted)*1.05))
                 if (plotRawPower)
                 {
                         #Plotting rawForce
@@ -283,6 +396,27 @@ plotSprintFromEncoder <- function(sprintRawDynamics, sprintFittedDynamics, title
                 }
                 axis(side = 4, col = "red", line = 4)
         }
+        
+        
+        if(plotMeanRawPower)
+        {
+                par(new = TRUE)
+                ylimits = c(min(sprintRawDynamics$rawPower[sprintRawDynamics$startSample:sprintRawDynamics$endSample])*0.95,
+                            max(c(sprintRawDynamics$rawPmax, sprintFittedDynamics$pmax.fitted)*1.05))
+                plot(NULL, NULL,
+                     ylim = ylimits,
+                     xlim = c(sprintRawDynamics$time[sprintRawDynamics$startSample], sprintRawDynamics$time[sprintRawDynamics$endSample]),
+                     xlab = "", ylab = "",
+                     axes = FALSE, yaxs = "i", xaxs = "i")
+                text(splitTime[1]*0.8, meanPower[1], paste(round(meanPower[1], digits = 2), "W"), col = "red")
+                for(n in 1:length(meanPower))
+                {
+                        text(splitTime[n] + (splitTime[n+1] - splitTime[n])*0.8, meanPower[n+1], paste(round(meanPower[n+1], digits = 2), "W"), col = "red")
+                        
+                }
+                axis(side = 4, col = "red", line = 4)
+        }
+
         plotSize = par("usr")
         legend(x = plotSize[2], y = plotSize[3] + (plotSize[4] - plotSize[3])*0.66,
                 xjust = 1, yjust = 0.5, cex = 1,
@@ -293,27 +427,46 @@ plotSprintFromEncoder <- function(sprintRawDynamics, sprintFittedDynamics, title
 #Detecting where the sprint start and stops
 getTrimmingSamples <- function(totalTime, position, speed, accel, testLength)
 {
+        print("#########Entering getTrimmingSamples###########33")
         #The test starts when the speed is grater than 1
         startSample = 0
         startingSample = FALSE
-        while(!startingSample)
+        while(!startingSample & startSample < (length(speed)-2))
         {
                 startSample = startSample +1
                 if(accel[startSample+1] > 5)
                 {
-                        #Looking is after 2 seconds the position has increased a meter at least.
-                        sampleAfterSecond = which.min(totalTime - (totalTime[startSample] +1) )
-                        positionAfterSecnod = position[sampleAfterSecond]
-                        if(abs(positionAfterSecnod - position[startSample]) > 2){
+                        print(paste("accel[", startSample +1 ,"] = ", accel[startSample + 1], sep = ""))
+                        
+                        #Looking iF after 1 seconds the position has increased  at least 1m.
+                        sampleAfterSecond = which.min(abs(totalTime - (totalTime[startSample] +1)))
+                        print(paste("sampleAfterSecond =", sampleAfterSecond))
+                        positionAfterSecond = position[sampleAfterSecond]
+                        if(abs(positionAfterSecond - position[startSample]) > 1){
                                 startingSample = TRUE
                         }
                 }
         }
         
+        if(startSample == (length(speed) -2))
+        {
+                print("No start detected")
+                return()
+        }
+        
+        
         #Going back in the time to find a really slow velocity
         while(speed[startSample] > 0.5)
         {
                 startSample = startSample -1
+                
+                #If the sprint doesn't start at a null speed, the first sample is used
+                #In old versions of RaceAnalyzer it was possible to start with a high speed.
+                if(startSample == 0)
+                {
+                        startSample = 1
+                        break
+                }
         }
         
         #Zeroing time to the initial acceleration sample
@@ -325,16 +478,39 @@ getTrimmingSamples <- function(totalTime, position, speed, accel, testLength)
         endSample = which.min(abs(position - testLength))
         if(position[endSample] < testLength)
                 endSample = endSample +1
-        return(list(start = startSample, end = endSample ))
+        return(list(start = startSample, end = endSample, errorInStart = !startingSample ))
+}
+tryNLS <- function(data){
+        print("#######Entering tryNLS#########")
+        tryCatch (
+                {
+                        model = nls(speed ~ Vmax*(1-exp(-K*time)), data,
+                                    start = list(Vmax = max(data[,"speed"]), K = 1), control=nls.control(warnOnly=TRUE))
+                        # print("model:")
+                        # print(model)
+                        return(list(regressionDone = TRUE, model = model))
+                }, 
+                error=function(cond)
+                { 
+                        message(cond)
+                        return(list(regressionDone = FALSE))
+                }
+        )
 }
 
 testEncoderCJ <- function(filename, testLength, mass, personHeight, tempC)
 {
         sprintRawDynamics = getSprintFromEncoder(filename, testLength, op$mass, op$tempC, op$personHeight)
-        sprintFittedDynamics = getDynamicsFromSprint(K = sprintRawDynamics$K, Vmax = sprintRawDynamics$Vmax, mass, tempC, personHeight)
-        print(paste("K =",sprintFittedDynamics$K.fitted, "Vmax =", sprintFittedDynamics$Vmax.fitted))
-        plotSprintFromEncoder(sprintRawDynamic = sprintRawDynamics, sprintFittedDynamics = sprintFittedDynamics, title = "Testing graph")
-        exportSprintDynamics(sprintFittedDynamics)
+        # print("sprintRawDynamics:")
+        # print(sprintRawDynamics)
+        if (sprintRawDynamics$longEnough & sprintRawDynamics$regressionDone)
+        {
+                sprintFittedDynamics = getDynamicsFromSprint(K = sprintRawDynamics$K, Vmax = sprintRawDynamics$Vmax, mass, tempC, personHeight)
+                print(paste("K =",sprintFittedDynamics$K.fitted, "Vmax =", sprintFittedDynamics$Vmax.fitted))
+                plotSprintFromEncoder(sprintRawDynamic = sprintRawDynamics, sprintFittedDynamics = sprintFittedDynamics, title = "Testing graph")
+                exportSprintDynamics(sprintFittedDynamics)
+        } else
+                print("Couldn't calculate the sprint model")
 }
 
 prepareGraph(op$os, pngFile, op$graphWidth, op$graphHeight)
