@@ -30,6 +30,7 @@ logging.basicConfig(level=logging.INFO)
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
  * Copyright (C) 2016-2017 Carles Pina i Estany <carles@pina.cat>
+ * Copyright (C) 2019 Xavier de Blas <xaviblas@gmail.com>
  */
 """
 
@@ -510,7 +511,7 @@ class ImportSession:
         jump.update_session_ids(self.new_session_id)
         jump.update_ids("type", jump_types, "old_name", "new_name")
 
-        self.destination_db.write(table=jump, matches_columns=self.destination_db.column_names("Jump", skip_columns=["uniqueID", "personID", "sessionID"]))
+        self.destination_db.write(table=jump, matches_columns=self.destination_db.column_names("Jump", skip_columns=["uniqueID", "personID"]))
 
     def _import_runs(self):
         # Imports RunTypes table
@@ -636,8 +637,16 @@ class ImportSession:
         encoder_signal_curve.concatenate_table(encoder_signal_curve_curves)
         encoder_signal_curve.remove_duplicates()
 
-        encoder_signal_curve.update_ids("signalID", encoder, "old_uniqueID", "new_uniqueID")
-        encoder_signal_curve.update_ids("curveID", encoder, "old_uniqueID", "new_uniqueID")
+        print("encoder_signal_curve before update_ids")
+        for row in encoder_signal_curve:
+            print(str(row.get("signalID")) + " " + str(row.get("curveID")))
+
+        encoder_signal_curve.update_ids("signalID", encoder, "uniqueID", "new_uniqueID")
+        encoder_signal_curve.update_ids("curveID", encoder, "uniqueID", "new_uniqueID")
+
+        print("encoder_signal_curve after update_ids")
+        for row in encoder_signal_curve:
+            print(str(row.get("signalID")) + " " + str(row.get("curveID")))
 
         self.destination_db.write(table=encoder_signal_curve,
                                   avoids_duplicate_column=None,
@@ -703,6 +712,16 @@ class ImportSession:
 
             shutil.copy(source_file, destination_filename)
 
+            # If on origin there are no curves, curve folder will not be created
+            # and after import curves will not be saved on clicking at capture treeview
+            # create "curve" folder if not exists
+            destination_url = self._encoder_url(session_id, "curve")
+            destination_directory = os.path.join(self.destination_path, "..", "..", destination_url)
+            destination_directory = os.path.abspath(destination_directory)  # os.makedirs() can't handle directories with ".."
+            if not os.path.isdir(destination_directory):
+                os.makedirs(destination_directory)
+
+
 
 def json_information(database_path):
     information = {}
