@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
+ *  Copyright (C) 2004-2019   Xavier de Blas <xaviblas@gmail.com>
  */
 
 
@@ -220,7 +220,7 @@ public class ChronoJump
 		fakeSplashButton = new Gtk.Button();
 		fakeSplashButton.Clicked += new EventHandler(on_splash_ended);
 
-		LongoMatch.Video.Capturer.GstCameraCapturer.InitBackend("");
+		//LongoMatch.Video.Capturer.GstCameraCapturer.InitBackend("");
 
 		thread = new Thread(new ThreadStart(sqliteThings));
 		GLib.Idle.Add (new GLib.IdleHandler (PulseGTK));
@@ -268,10 +268,11 @@ public class ChronoJump
 
 		//to store user videos and photos
 		Util.CreateMultimediaDirsIfNeeded();
-		//to store encoder data and graphs
+
+		//to store (encoder, force sensor, run encoder) data and graphs
 		UtilEncoder.CreateEncoderDirIfNeeded();
-		//to store force sensor data and graphs
 		Util.CreateForceSensorDirIfNeeded();
+		Util.CreateRaceAnalyzerDirIfNeeded();
 
 //TODO: when a session is deleted, encoder data has to be deleted, also multimedia videos, I suppose. Show message to user warning about it
 //TODO: encoder weight auto written depending on person loaded, and changes if it changes person or weight
@@ -353,7 +354,7 @@ public class ChronoJump
 					LogB.Error("problem with sqlite");
 					//check (spanish)
 					//http://mail.gnome.org/archives/chronojump-devel-list/2008-March/msg00011.html
-					string errorMessage = Catalog.GetString("Failed database conversion, ensure you have libsqlite3-0 installed. \nIf problems persist ask in chronojump-list");
+					string errorMessage = Catalog.GetString("Failed database conversion, ensure you have libsqlite3-0 installed.");
 					errorMessage += "\n\n" + string.Format(Catalog.GetString("If you have no data on your database (you just installed Chronojump), you can fix this problem deleting this file: {0}"), 
 							Util.GetDatabaseDir() + Path.DirectorySeparatorChar + "chronojump.db") + 
 						"\n" + Catalog.GetString("And starting Chronojump again.");
@@ -396,8 +397,6 @@ public class ChronoJump
 			createRunningFileName(runningFileName);
 		}
 		
-		
-
 
 		//splashMessageChange(5);  //check for new version
 		splashMessageChange(5);  //connecting to server
@@ -572,12 +571,32 @@ public class ChronoJump
 		}
 		LogB.SQL("all SQL done! starting Chronojump");
 
-		if(sendLog)
-			new ChronoJumpWindow(progVersion, progName, runningFileName, splashWin, true, messageToShowOnBoot);
-		else
-			new ChronoJumpWindow(progVersion, progName, runningFileName, splashWin, false, "");
+		string topMessage = "";
+		if(UtilAll.GetOSEnum() == UtilAll.OperatingSystems.LINUX && ! linuxUserHasDialout())
+			topMessage = Catalog.GetString("Need dialout permissions to read from device.") + "\n" +
+				Catalog.GetString("Check software page on Chronojump website");
+
+		bool showCameraStop = (ExecuteProcess.IsRunning3 (-1, WebcamFfmpeg.GetExecutableCapture(UtilAll.GetOSEnum())));
+
+		new ChronoJumpWindow(progVersion, progName, runningFileName, splashWin, sendLog, messageToShowOnBoot, topMessage, showCameraStop);
 	}
 
+	private bool linuxUserHasDialout()
+	{
+		LogB.Information("Finding dialout:");
+		string executable = "groups";
+		ExecuteProcess.Result execute_result = ExecuteProcess.run (executable, true, true);
+		if(execute_result.success)
+		{
+			LogB.Information(execute_result.stdout);
+			return (execute_result.stdout.Contains("dialout"));
+		}
+
+		//if script has failed, don't bother the user
+		return true;
+	}
+
+
 	private static void createBlankDB() {
 		LogB.SQL("Creating blank database");
 		Sqlite.ConnectBlank();
