@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
+ *  Copyright (C) 2004-2019   Xavier de Blas <xaviblas@gmail.com>
  */
 
 using System;
@@ -142,6 +142,7 @@ public class Constants
 	public const string Encoder1RMTable = "encoder1RM";
 	public const string ExecuteAutoTable = "executeAuto";
 	public const string TriggerTable = "trigger";
+	public const string ForceSensorExerciseTable = "forceSensorExercise";
 	public const string ForceRFDTable = "forceRFD";
 
 	// Dummy variables that exists for translating purposes
@@ -175,6 +176,7 @@ public class Constants
 	//json temp tables
 	public const string UploadEncoderDataTempTable = "uploadEncoderDataTemp";
 	public const string UploadSprintDataTempTable = "uploadSprintDataTemp";
+	public const string UploadExhibitionTestTempTable = "uploadExhibitionTestTemp";
 
 	public const string UndefinedDefault = "Undefined";
 	public const string Any = "Any";
@@ -263,6 +265,8 @@ public class Constants
 			Catalog.GetString("This can be changed at preferences.");
 	}
 
+	public static string JumpsProfileNeededJumps = Catalog.GetString("Please, perform the needed jumps marked in red above.");
+
 /*	OLD, check this
 	public static string PotencyLewisCMJFormula = Catalog.GetString("Peak Power")+ " CMJ (Lewis) " +
 		"(" + Catalog.GetString("body weight") + "+" + Catalog.GetString("extra weight") + ")*9.81*" +
@@ -540,6 +544,7 @@ public class Constants
 	public static string FindDriverNeed = Catalog.GetString("Chronopic driver has to be installed.");
 	public static string FindDriverWindows = Catalog.GetString("If you have problems connecting with Chronopic, ensure you have the <b>driver</b> installed at 'Windows Start Menu / Chronojump / Install Chronopic driver'."); 
 	public static string FindDriverOthers = Catalog.GetString("Check Chronojump software website.");
+	public static string VideoNothingCaptured = Catalog.GetString("Error. Nothing has been captured.");
 
 //	public static System.Media.SystemSound SoundCanStart = System.Media.SystemSounds.Question; 
 //	public static System.Media.SystemSounds SoundGood = System.Media.SystemSounds.Exclamation; 
@@ -633,6 +638,7 @@ public class Constants
 	public static string DirectoryCannotOpen = Catalog.GetString("Error. Cannot open directory.");
 	public static string FileNotFound = Catalog.GetString("Error. File not found.");
 	public static string FileCopyProblem = Catalog.GetString("Error. Cannot copy file.");
+	public static string FileCannotSave = Catalog.GetString("Error. File cannot be saved.");
 
 	public static string ChronopicDefaultPortWindows = "COM?";
 	public static string ChronopicDefaultPortLinux = "/dev/ttyUSB?";
@@ -723,7 +729,8 @@ public class Constants
 	public enum MultimediaItems {
 		PHOTO, PHOTOPNG, VIDEO
 	}
-	public const string ExtensionVideo = ".avi";
+	//public const string ExtensionVideo = ".avi";
+	public const string ExtensionVideo = ".mp4";
 	public const string ExtensionPhoto = ".jpg";
 	public const string ExtensionPhotoPng = ".png"; //used for Cairo resized images
 	public const string SmallPhotoDir = "small";
@@ -736,6 +743,7 @@ public class Constants
 	public static string RunStartInitialSpeedNo = Catalog.GetString("Standing start. Started without initial speed.");
 	
 	public static string CameraNotFound = Catalog.GetString("Sorry, no cameras found.");
+	public static string FfmpegNotInstalled = "Software ffmpeg is not installed, please check instructions on chronojump website (software page)";
 	
 	public enum BellModes {
 		JUMPS, RUNS, ENCODERGRAVITATORY, ENCODERINERTIAL
@@ -744,7 +752,7 @@ public class Constants
 	public enum Menuitem_modes {
 		UNDEFINED,
 		JUMPSSIMPLE, JUMPSREACTIVE,
-		RUNSSIMPLE, RUNSINTERVALLIC,
+		RUNSSIMPLE, RUNSINTERVALLIC, RUNSENCODER,
 		POWERGRAVITATORY, POWERINERTIAL,
 		FORCESENSOR, RT, OTHER } //OTHER can be: Multichronopic, Pulse
 
@@ -766,7 +774,7 @@ public class Constants
 	 * https://cran.r-project.org/doc/manuals/r-devel/R-admin.pdf
 	 */
 	public static string ROSX = "/Library/Frameworks/R.framework/Resources/R";
-	public static string RScriptOSX = "/Library/Frameworks/R.framework/Resources/RScript";
+	public static string RScriptOSX = "/Library/Frameworks/R.framework/Resources/Rscript";
 	
 	//public static string EncoderScriptCapturePythonLinux = "pyserial_pyper.py";
 	//public static string EncoderScriptCapturePythonWindows = "pyserial_pyper_windows.exe";
@@ -805,9 +813,12 @@ public class Constants
 	public enum EncoderGI {ALL, GRAVITATORY, INERTIAL}
 	public enum CheckFileOp {
 		JUMPS_PROFILE_SAVE_IMAGE,
+		RUNS_SPRINT_SAVE_IMAGE,
 		ENCODER_CAPTURE_EXPORT_ALL, ENCODER_ANALYZE_SAVE_IMAGE,
+		ENCODER_ANALYZE_SEND_IMAGE, //like save image but just defines the name exportFileName to be sended
 		ENCODER_ANALYZE_SAVE_AB, ENCODER_ANALYZE_SAVE_TABLE,
-		FORCESENSOR_SAVE_IMAGE_SIGNAL, FORCESENSOR_SAVE_IMAGE_RFD
+		FORCESENSOR_SAVE_IMAGE_SIGNAL, FORCESENSOR_SAVE_IMAGE_RFD_AUTO,
+		FORCESENSOR_SAVE_IMAGE_RFD_MANUAL, FORCESENSOR_ANALYZE_SAVE_AB
 	}
 
 	public static double EncoderErrorCode = -1;
@@ -832,6 +843,7 @@ public class Constants
 	public static string FileNameEncoderLinearOnPlane = "encoder-linear-inclined-plane.png";	
 	public static string FileNameEncoderLinearOnPlaneWeightDiffAngle = "encoder-linear-inclined-plane-weight-diff-angle.png";	
 	public static string FileNameEncoderLinearOnPlaneWeightDiffAngleMovPulley = "encoder-linear-inclined-plane-weight-diff-angle-mov-pulley.png";
+	public static string FileNameEncoderLinearPneumatic = "encoder-linear-pneumatic.png";
 
 	//rotary friction
 	public static string FileNameEncoderFrictionSide = "encoder-rotary-friction-pulley.png";
@@ -854,13 +866,14 @@ public class Constants
 	
 	public static string FileNameEncoderCalculeIM = "encoder-calcule-im.png";	
 
-	public enum EncoderConfigurationNames { //this names are used on graph.R change there also if needed
+	public enum EncoderConfigurationNames { //this names are used on util.R and graph.R change there also if needed
 		// ---- LINEAR ----
 		LINEAR, LINEARINVERTED, LINEARINERTIAL, 
 		WEIGHTEDMOVPULLEYLINEARONPERSON1, WEIGHTEDMOVPULLEYLINEARONPERSON1INV,
 		WEIGHTEDMOVPULLEYLINEARONPERSON2, WEIGHTEDMOVPULLEYLINEARONPERSON2INV,
 		WEIGHTEDMOVPULLEYONLINEARENCODER, 
 		LINEARONPLANE, LINEARONPLANEWEIGHTDIFFANGLE, LINEARONPLANEWEIGHTDIFFANGLEMOVPULLEY,
+		PNEUMATIC,
 		// ---- ROTARY FRICTION ----
 		ROTARYFRICTIONSIDE, ROTARYFRICTIONAXIS,
 		WEIGHTEDMOVPULLEYROTARYFRICTION,
@@ -878,6 +891,7 @@ public class Constants
 		LINEAR, ROTARYFRICTION, ROTARYAXIS
 	}	
 
+	public const string Range = "Range";
 	public const string MeanSpeed = "Mean speed";
 	public const string MaxSpeed = "Max speed";
 	public const string MeanForce = "Mean force";
@@ -927,8 +941,13 @@ public class Constants
 		
 	public enum Encoder1RMMethod { NONWEIGHTED, WEIGHTED, WEIGHTED2, WEIGHTED3 }
 	public enum ContextMenu { NONE, EDITDELETE, DELETE }
-	
-	public enum EncoderAutoSaveCurve { ALL, NONE, BEST, FROM4TOPENULTIMATE }
+
+	//on glade/app1 using the same names
+	public const string ForceSensorLateralityBoth = "Both";
+	public const string ForceSensorLateralityLeft = "Left";
+	public const string ForceSensorLateralityRight = "Right";
+
+	public enum EncoderAutoSaveCurve { ALL, NONE, BEST, FROM4TOPENULTIMATE } //note last mode not need to be 4 because DB 1.63 introduces the config of this value
 
 	//BIGGEST_TC will be the default mode.
 	// - at END of each track: track ends before the biggest TC (just before the trunk arrives)
@@ -991,7 +1010,9 @@ public class Constants
 		"Laterality", "RL", "R", "L",
 		"Inertia M.",
 		"Maximum mean power using the F-V profile",
-		"Mean power parabole using the Power-Load data"
+		"Mean power parabole using the Power-Load data",
+		"Propulsive",
+		"Non propulsive"
 	};
 	/*
 	 * written here in order to be translated
@@ -1040,6 +1061,8 @@ public class Constants
 		Catalog.GetString("Laterality"), Catalog.GetString("RL"), Catalog.GetString("R"), Catalog.GetString("L"),
 		Catalog.GetString("Inertia M."),
 		Catalog.GetString("Maximum mean power using the F-V profile"),
-		Catalog.GetString("Mean power parabole using the Power-Load data")
+		Catalog.GetString("Mean power parabole using the Power-Load data"),
+		Catalog.GetString("Propulsive"),
+		Catalog.GetString("Non propulsive")
 	};
 }
