@@ -161,14 +161,19 @@ public class EncoderGraphROptions
 	public bool crossValidate;
 	private bool cutByTriggers;
 	private string triggerList;
-	
+	public bool separateSessionInDays;
+	public AnalysisModes analysisMode; //the four analysisModes
+
+	public enum AnalysisModes { CAPTURE, INDIVIDUAL_CURRENT_SET, INDIVIDUAL_CURRENT_SESSION, INDIVIDUAL_ALL_SESSIONS, GROUPAL_CURRENT_SESSION }
+
 	public EncoderGraphROptions(
 			string inputData, string outputGraph, string outputData1, 
 			string encoderRPath, string encoderTempPath,
 			EncoderParams ep,
 			string title, string operatingSystem,
 			string englishWords, string translatedWords,
-			bool debug, bool crossValidate, bool cutByTriggers, string triggerList)
+			bool debug, bool crossValidate, bool cutByTriggers, string triggerList,
+			bool separateSessionInDays, AnalysisModes analysisMode)
 	{
 		this.inputData = inputData;
 		this.outputGraph = outputGraph;
@@ -184,6 +189,8 @@ public class EncoderGraphROptions
 		this.crossValidate = crossValidate;
 		this.cutByTriggers = cutByTriggers;
 		this.triggerList = triggerList;
+		this.separateSessionInDays = separateSessionInDays;
+		this.analysisMode = analysisMode;
 
 		//ensure triggerList is not null or blank
 		if(triggerList == null || triggerList == "")
@@ -205,7 +212,9 @@ public class EncoderGraphROptions
 			"#debug\n" +		Util.BoolToRBool(debug) + "\n" +
 			"#crossValidate\n" +	Util.BoolToRBool(crossValidate) + "\n" +
 			"#cutByTriggers\n" +	Util.BoolToRBool(cutByTriggers) + "\n" +
-			"#triggerList\n" +	triggerList + "\n";
+			"#triggerList\n" +	triggerList + "\n" +
+			"#separateSessionInDays\n" +	Util.BoolToRBool(separateSessionInDays) + "\n" +
+			"#analysisMode\n" + 	analysisMode.ToString() + "\n";
 	}
 	
 
@@ -340,6 +349,8 @@ public class EncoderCurve
 
 	public double GetParameter(string parameter) {
 		switch(parameter) {
+			case Constants.Range:
+				return Math.Abs(Convert.ToDouble(Height));
 			case Constants.MeanSpeed:
 				return Convert.ToDouble(MeanSpeed);
 			case Constants.MaxSpeed:
@@ -386,7 +397,7 @@ public class EncoderCurve
 		else
 			return Util.ChangeChars(str, ":::", ",");
 	}
-	
+
 	public double MeanSpeedD { get { return Convert.ToDouble(MeanSpeed); } }
 	public double MaxSpeedD  { get { return Convert.ToDouble(MaxSpeed);  } }
 	public double MeanPowerD { get { return Convert.ToDouble(MeanPower); } }
@@ -413,14 +424,15 @@ public class EncoderSignal
 	}
 
 	//this can be an eccentric or concentric curve
-	public int FindPosOfBest(string variable) {
+	public int FindPosOfBest(int start, string variable)
+	{
 		double bestValue = 0;
-		int bestValuePos = 0;
+		int bestValuePos = start;
 		int i = 0;
 		
 		foreach(EncoderCurve curve in curves) 
 		{
-			if(curve.GetParameter(variable) > bestValue) {
+			if(i >= start && curve.GetParameter(variable) > bestValue) {
 				bestValue = curve.GetParameter(variable);
 				bestValuePos = i;
 			}
@@ -431,13 +443,14 @@ public class EncoderSignal
 	}
 	
 	//this is an ecc-con curve
-	public int FindPosOfBestEccCon(string variable) 
+	//start is a counter of phases not of repetitions
+	public int FindPosOfBestEccCon(int start, string variable)
 	{
 		double eccValue = 0;
 		double conValue = 0;
 
 		double bestValue = 0; //will be ecc-con average
-		int bestValuePos = 0; //will be the position of the ecc
+		int bestValuePos = start; //will be the position of the ecc
 		int i = 0;
 		
 		bool ecc = true;
@@ -447,7 +460,7 @@ public class EncoderSignal
 				eccValue = curve.GetParameter(variable);
 			} else {
 				conValue = curve.GetParameter(variable);
-				if( ( (eccValue + conValue) / 2 ) > bestValue) {
+				if( i >= start && ( (eccValue + conValue) / 2 ) > bestValue) {
 					bestValue = (eccValue + conValue) / 2;
 					bestValuePos = i -1;
 				}
@@ -458,7 +471,98 @@ public class EncoderSignal
 		}
 		return bestValuePos;
 	}
-	
+
+	public double GetEccConMean(int eccPos, string variable)
+	{
+		return(
+				(
+				((EncoderCurve) curves[eccPos]).GetParameter(variable) +
+				((EncoderCurve) curves[eccPos +1]).GetParameter(variable)
+				) /2 );
+	}
+
+	//use also with range
+	public double GetEccConMax(int eccPos, string variable)
+	{
+		double eccValue = Math.Abs( ((EncoderCurve) curves[eccPos]).GetParameter(variable));
+		double conValue = Math.Abs( ((EncoderCurve) curves[eccPos +1]).GetParameter(variable));
+
+		if(eccValue > conValue)
+			return eccValue;
+		return conValue;
+	}
+
+	public int GetEccConLossByOnlyConPhase(string variable)
+	{
+		double lowest = 100000;
+		double highest = 0;
+		double eccValue = 0;
+		double conValue = 0;
+		bool ecc = true;
+		//int i = 0;
+		foreach (EncoderCurve curve in curves)
+		{
+			if(ecc)
+			{
+				ecc = false;
+				continue;
+			}
+
+			double compareTo = curve.MeanSpeedD;
+			if(variable == Constants.MeanPower)
+				compareTo = curve.MeanPowerD;
+
+			conValue = compareTo;
+			if(compareTo > highest)
+				highest = compareTo;
+			if(compareTo < lowest)
+				lowest = compareTo;
+
+			//LogB.Information(string.Format("Loss ecc/con (by con) of {0}; i: {1} is: {2}", variable, i++,
+			//			Convert.ToInt32(Util.DivideSafe(100.0 * (highest - lowest), highest))));
+
+			ecc = true;
+		}
+		return Convert.ToInt32(Util.DivideSafe(100.0 * (highest - lowest), highest));
+
+	}
+	/*
+	 * this method uses ecc and con and calculates the loss by having the average of them for each repetition
+	 * better do only using the con phase (see above method)
+	 *
+	public int GetEccConLoss(string variable)
+	{
+		double lowest = 100000;
+		double highest = 0;
+		double eccValue = 0;
+		double conValue = 0;
+		bool ecc = true;
+		//int i = 0;
+		foreach (EncoderCurve curve in curves)
+		{
+			double compareTo = curve.MeanSpeedD;
+			if(variable == Constants.MeanPower)
+				compareTo = curve.MeanPowerD;
+
+			if(ecc)
+				eccValue = compareTo;
+			else {
+				conValue = compareTo;
+				if( ( (eccValue + conValue) / 2 ) > highest)
+					highest = (eccValue + conValue) / 2;
+				if( ( (eccValue + conValue) / 2 ) < lowest)
+					lowest = (eccValue + conValue) / 2;
+			}
+			//LogB.Information(string.Format("Loss ecc/con (ecc?: {0}) of {1}; i: {2} is: {3}", ecc.ToString(), variable, i++,
+			//			Convert.ToInt32(Util.DivideSafe(100.0 * (highest - lowest), highest))));
+
+			ecc = ! ecc;
+		}
+		return Convert.ToInt32(Util.DivideSafe(100.0 * (highest - lowest), highest));
+
+	}
+	*/
+
 	~EncoderSignal() {}
 }
 
@@ -1359,6 +1463,15 @@ public class EncoderConfiguration
 			has_angle_weight = true;
 			has_gearedDown = true;
 		}
+		if(name == Constants.EncoderConfigurationNames.PNEUMATIC) {
+			type = Constants.EncoderType.LINEAR;
+			position = 10;
+			image = Constants.FileNameEncoderLinearPneumatic;
+			code = "Linear - Pneumatic machine";
+			text = "Linear encoder connected to a pneumatic machine";
+
+			has_angle_push = true;
+		}
 		// ---- inertial
 		else if(name == Constants.EncoderConfigurationNames.LINEARINERTIAL) {
 			type = Constants.EncoderType.LINEAR;
@@ -1968,6 +2081,7 @@ public class EncoderAnalyzeInstant
 		if(ini == end) {
 			listAVG = dlist[ini];
 			listMAX = dlist[ini];
+			return;
 		}
 
 		double sum = 0;
