@@ -32,6 +32,7 @@ public abstract class EncoderRProc
 	public Status status;
 	public bool Debug = false;
 	public bool CrossValidate;
+	public bool SeparateSessionInDays;
 	public int CurvesReaded;
 
 	protected string optionsFile;	
@@ -257,8 +258,9 @@ public class EncoderRProcCapture : EncoderRProc
 				Debug,
 				false,	//crossValidate (unactive on capture at the moment)
 				(CutByTriggers != Preferences.TriggerTypes.NO_TRIGGERS),
-				printTriggers()
-				).ToString();
+				printTriggers(),
+				false, 	//separateSessionInDays (false at capture)
+				EncoderGraphROptions.AnalysisModes.CAPTURE).ToString();
 
 		TextWriter writer = File.CreateText(optionsFile);
 		writer.Write(scriptOptions);
@@ -286,6 +288,7 @@ public class EncoderRProcAnalyze : EncoderRProc
 	private bool translate;
 	private bool cutByTriggers;
 	private TriggerList triggerList;
+	private EncoderGraphROptions.AnalysisModes analysisMode;
 
 	/*
 	 * to avoid problems on some windows. R exports csv to Util.GetEncoderExportTempFileName()
@@ -299,13 +302,14 @@ public class EncoderRProcAnalyze : EncoderRProc
 	}
 
 	public void SendData(string title, bool neuromuscularProfileDo, bool translate,
-			bool cutByTriggers, TriggerList triggerList)
+			bool cutByTriggers, TriggerList triggerList, EncoderGraphROptions.AnalysisModes analysisMode)
 	{
 		this.title = title;
 		this.neuromuscularProfileDo = neuromuscularProfileDo;
 		this.translate = translate;
 		this.cutByTriggers = cutByTriggers;
 		this.triggerList = triggerList;
+		this.analysisMode = analysisMode;
 		
 		CancelRScript = false;
 	}
@@ -514,7 +518,9 @@ public class EncoderRProcAnalyze : EncoderRProc
 				Debug,
 				CrossValidate,
 				cutByTriggers,
-				printTriggers()
+				printTriggers(),
+				SeparateSessionInDays,
+				analysisMode
 				).ToString();
 
 		TextWriter writer = File.CreateText(optionsFile);
