@@ -66,6 +66,8 @@ public class EventExecute
 	protected string feedbackMessage;
 	protected bool needShowFeedbackMessage;
 
+	public bool WebcamStarted;
+
 	//instances with the info to create
 	public PrepareEventGraphJumpSimple PrepareEventGraphJumpSimpleObject; 
 	public PrepareEventGraphJumpReactive PrepareEventGraphJumpReactiveObject;
@@ -114,7 +116,6 @@ public class EventExecute
 	
 	protected States loggedState;		//log of last state
 	//protected Gtk.ProgressBar progressBar;
-	protected Gtk.Label event_execute_label_message;
 	protected Gtk.Window app;
 	protected int pDN;
 	
@@ -244,6 +245,14 @@ public class EventExecute
 		return true;
 	}
 
+	//used on Chronojump exit (if user wants to close program while it is capturing
+	public bool IsThreadRunning() {
+		if (thread != null && thread.IsAlive)
+			return true;
+
+		return false;
+	}
+
 	public void ThreadAbort() {
 		thread.Abort();
 	}
@@ -354,7 +363,7 @@ public class EventExecute
 		}
 		
 		// <-------------------------- end of races specific
-		
+
 		//check if it should finish by time
 		if(shouldFinishByTime()) {
 			finish = true;
@@ -598,7 +607,7 @@ public class EventExecute
 	public Event EventDone {
 		get { return eventDone; }
 	}
-	
+
 	// multi Chronopic stuff
 	public int Chronopics { get { return chronopics; } }
 
