@@ -48,15 +48,17 @@ public class JumpExecute : EventExecute
 	protected static jumpPhases jumpPhase;
 
 	private int angle = -1;
+	private bool avoidGraph;
 	
 	public JumpExecute() {
 	}
 
 	//jump execution
 	public JumpExecute(int personID, string personName, int sessionID, string type, double fall, double weight,  
-			Chronopic cp, Gtk.Label event_execute_label_message, Gtk.Window app, int pDN,
+			Chronopic cp, Gtk.Window app, int pDN,
 			bool volumeOn, Preferences.GstreamerTypes gstreamer,
-			double progressbarLimit, ExecutingGraphData egd, string description
+			double progressbarLimit, ExecutingGraphData egd, string description,
+			bool avoidGraph //on configChronojump.Exhibition do not show graph because it gets too slow with big database
 			)
 	{
 		this.personID = personID;
@@ -67,7 +69,6 @@ public class JumpExecute : EventExecute
 		this.weight = weight;
 		
 		this.cp = cp;
-		this.event_execute_label_message = event_execute_label_message;
 		this.app = app;
 
 		this.pDN = pDN;
@@ -76,6 +77,7 @@ public class JumpExecute : EventExecute
 		this.progressbarLimit = progressbarLimit;
 		this.egd = egd;
 		this.description = description;
+		this.avoidGraph = avoidGraph;
 	
 		if(TypeHasFall) {
 			hasFall = true;
@@ -470,10 +472,13 @@ public class JumpExecute : EventExecute
 		//define the created object
 		eventDone = new Jump(uniqueID, personID, sessionID, type, tv, tc, fall, 
 				weight, description, angle, Util.BoolToNegativeInt(simulated)); 
-		
-		PrepareEventGraphJumpSimpleObject = new PrepareEventGraphJumpSimple(tv, tc, sessionID, personID, table, type);
-		needUpdateGraphType = eventType.JUMP;
-		needUpdateGraph = true;
+
+		if(! avoidGraph)
+		{
+			PrepareEventGraphJumpSimpleObject = new PrepareEventGraphJumpSimple(tv, tc, sessionID, personID, table, type);
+			needUpdateGraphType = eventType.JUMP;
+			needUpdateGraph = true;
+		}
 		
 		needEndEvent = true; //used for hiding some buttons on eventWindow
 	}
@@ -541,7 +546,7 @@ public class JumpRjExecute : JumpExecute
 	public JumpRjExecute(int personID, string personName, 
 			int sessionID, string type, double fall, double weight, 
 			double limitAsDouble, bool jumpsLimited, 
-			Chronopic cp, Gtk.Label event_execute_label_message, Gtk.Window app, int pDN, bool allowFinishAfterTime, 
+			Chronopic cp, Gtk.Window app, int pDN, bool allowFinishAfterTime,
 			bool volumeOn, Preferences.GstreamerTypes gstreamer,
 			RepetitiveConditionsWindow repetitiveConditionsWin,
 			double progressbarLimit, ExecutingGraphData egd
@@ -563,7 +568,6 @@ public class JumpRjExecute : JumpExecute
 		}
 		
 		this.cp = cp;
-		this.event_execute_label_message = event_execute_label_message;
 		this.app = app;
 
 		this.pDN = pDN;
