@@ -77,7 +77,7 @@ public class RunExecute : EventExecute
 
 	//run execution
 	public RunExecute(int personID, int sessionID, string type, double distance,   
-			Chronopic cp, Gtk.Label event_execute_label_message, Gtk.Window app, 
+			Chronopic cp, Gtk.Window app,
 			int pDN, bool metersSecondsPreferred,
 			bool volumeOn, Preferences.GstreamerTypes gstreamer,
 			double progressbarLimit, ExecutingGraphData egd,
@@ -92,7 +92,6 @@ public class RunExecute : EventExecute
 		this.distance = distance;
 		
 		this.cp = cp;
-		this.event_execute_label_message = event_execute_label_message;
 		this.app = app;
 
 		this.pDN = pDN;
@@ -254,7 +253,10 @@ public class RunExecute : EventExecute
 				checkDoubleContactTime,
 				speedStartArrival
 				);
-		runPTL = new RunPhaseTimeList(checkDoubleContactTime);
+		runPTL = new RunPhaseTimeList(
+				checkDoubleContactMode,
+				checkDoubleContactTime
+				);
 
 		bool firstFromChronopicReceived = false;
 		bool exitWaitEventBucle = false;
@@ -767,7 +769,7 @@ public class RunIntervalExecute : RunExecute
 
 	//run execution
 	public RunIntervalExecute(int personID, int sessionID, string type, double distanceInterval, double limitAsDouble, bool tracksLimited,  
-			Chronopic cp, Gtk.Label event_execute_label_message, Gtk.Window app, int pDN, bool metersSecondsPreferred, 
+			Chronopic cp, Gtk.Window app, int pDN, bool metersSecondsPreferred,
 			bool volumeOn, Preferences.GstreamerTypes gstreamer,
 			RepetitiveConditionsWindow repetitiveConditionsWin,
 			double progressbarLimit, ExecutingGraphData egd ,
@@ -800,7 +802,6 @@ public class RunIntervalExecute : RunExecute
 		
 		
 		this.cp = cp;
-		this.event_execute_label_message = event_execute_label_message;
 		this.app = app;
 
 		this.metersSecondsPreferred = metersSecondsPreferred;
@@ -840,6 +841,7 @@ public class RunIntervalExecute : RunExecute
 		distanceIntervalFixed = distanceInterval;
 		tracks = 0;
 		countForSavingTempTable = 0;
+		finishByTimeReturnedTrueAtThisCapture = false;
 
 		//initialize eventDone as a RunInterval
 		eventDone = new RunInterval();
@@ -997,20 +999,37 @@ public class RunIntervalExecute : RunExecute
 
 	}
 
-	protected override bool shouldFinishByTime() {
+	static bool finishByTimeReturnedTrueAtThisCapture;
+	protected override bool shouldFinishByTime()
+	{
+		//do not call FinishDo n times while waiting catchedTimeOut there
+		if(finishByTimeReturnedTrueAtThisCapture)
+			return false;
+
 		//check if it should finish now (time limited, not unlimited and time exceeded)
 		//check that the run started
 		//if( ! tracksLimited && limitAsDouble != -1 && timerCount > limitAsDouble 
-		if( ! tracksLimited && limitAsDouble != -1 && Util.GetTotalTime(intervalTimesString) > limitAsDouble 
+		if( ! tracksLimited && limitAsDouble != -1
 				&& !(runPhase == runPhases.PRE_RUNNING) 
 				&& !(runPhase == runPhases.PLATFORM_INI_NO_TIME)
 				&& !(runPhase == runPhases.PLATFORM_INI_YES_TIME)
+				&& timerLastTf > DateTime.MinValue
+				&& (Util.GetTotalTime(intervalTimesString) + (DateTime.Now - timerLastTf).TotalSeconds) > limitAsDouble
 				) 
+		{
+			LogB.Information("shouldFinishByTime finishes Chronopic calling FinishDo");
+			//as we will be on waitEvent do { ok = cp.Read_event ... }
+			//call this to end Read_cambio called by Read_event
+			Chronopic.FinishDo();
+
+			finishByTimeReturnedTrueAtThisCapture = true;
+
 			return true;
+		}
 		else
 			return false;
 	}
-	
+
 	protected override void updateTimeProgressBar() {
 		/* 4 situations:
 		 *   1- if we start out and have not arrived to platform, it should be a pulse with no time value on label:
