@@ -46,6 +46,7 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Image image_mode_encoder_capture;
 	[Widget] Gtk.Image image_manage_persons;
 	[Widget] Gtk.Image image_current_person_zoom;
+	[Widget] Gtk.Image image_current_person_zoom_h;
 	[Widget] Gtk.Image image_person;
 	[Widget] Gtk.Image image_person1;
 	[Widget] Gtk.Image image_edit_current_person;
@@ -75,6 +76,7 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Image image_add_test2;
 	[Widget] Gtk.Image image_add_test3;
 	[Widget] Gtk.Image image_add_test4;
+	[Widget] Gtk.Image image_add_test5;
 	[Widget] Gtk.Image image_test_inspect;
 
 	[Widget] Gtk.Image image_selector_start_jumps;
@@ -114,7 +116,7 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Image image_encoder_1RM_info;
 	//[Widget] Gtk.Image image_encoder_exercise_close;
 	[Widget] Gtk.Image image_inertial_rolled;
-	[Widget] Gtk.Image image_inertial_half_rolled;
+	//[Widget] Gtk.Image image_inertial_half_rolled;
 	[Widget] Gtk.Image image_inertial_extended;
 	[Widget] Gtk.Image image_encoder_calibrate;
 	[Widget] Gtk.Image image_encoder_recalibrate;
@@ -123,6 +125,9 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Image image_encoder_analyze_mode_options;
 	[Widget] Gtk.Image image_encoder_analyze_mode_options_close;
 	[Widget] Gtk.Image image_encoder_analyze_cancel;
+	[Widget] Gtk.Image image_encoder_analyze_image_compujump_send_email_image;
+	[Widget] Gtk.Image image_encoder_analyze_image_compujump_send_email_send;
+	[Widget] Gtk.Image image_encoder_analyze_check;
 
 	//force sensor
 	[Widget] Gtk.Image image_selector_start_force_sensor;
@@ -137,7 +142,38 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Image image_force_sensor_capture_adjust_close;
 	[Widget] Gtk.Image image_force_sensor_analyze_options;
 	[Widget] Gtk.Image image_force_sensor_analyze_options_close;
+	[Widget] Gtk.Image image_force_sensor_capture_recalculate;
 	[Widget] Gtk.Image image_force_sensor_analyze_recalculate;
+	[Widget] Gtk.Image image_force_sensor_exercise_edit;
+	[Widget] Gtk.Image image_force_sensor_laterality_both;
+	[Widget] Gtk.Image image_force_sensor_laterality_r;
+	[Widget] Gtk.Image image_force_sensor_laterality_l;
+
+	//video play icons
+	[Widget] Gtk.Image image_video_play_this_test;
+	[Widget] Gtk.Image image_video_play_this_test_encoder;
+	[Widget] Gtk.Image image_video_play_selected_jump;
+	[Widget] Gtk.Image image_video_play_selected_jump_rj;
+	[Widget] Gtk.Image image_video_play_selected_run;
+	[Widget] Gtk.Image image_video_play_selected_run_interval;
+	[Widget] Gtk.Image image_video_play_selected_pulse;
+	[Widget] Gtk.Image image_video_play_selected_reaction_time;
+	[Widget] Gtk.Image image_video_play_selected_multi_chronopic;
+	[Widget] Gtk.Image image_video_preview;
+	[Widget] Gtk.Image image_video_encoder_preview;
+
+	[Widget] Gtk.Image image_encoder_analyze_table_save_1;
+	[Widget] Gtk.Image image_encoder_analyze_image_save_1;
+	[Widget] Gtk.Image image_encoder_analyze_1RM_save_1;
+	[Widget] Gtk.Image image_encoder_analyze_image_save_2;
+	[Widget] Gtk.Image image_forcesensor_analyze_image_save2;
+	[Widget] Gtk.Image image_forcesensor_analyze_image_save3;
+	[Widget] Gtk.Image image_forcesensor_analyze_image_save5;
+	[Widget] Gtk.Image image_forcesensor_analyze_image_save6;
+	[Widget] Gtk.Image image_forcesensor_analyze_image_save7;
+	[Widget] Gtk.Image image_sprint_analyze_image_save;
+	[Widget] Gtk.Image image_message_permissions_at_boot;
+	[Widget] Gtk.Image image_camera_at_boot;
 
 	private void putNonStandardIcons()
 	{
@@ -178,6 +214,8 @@ public partial class ChronoJumpWindow
 		image_quit2.Pixbuf = pixbuf;
 		image_quit_from_app1.Pixbuf = pixbuf;
 
+		image_message_permissions_at_boot.Pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_warning_red.png");
+
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "muscle-concentric.png");
 		image_top_eccon.Pixbuf = pixbuf;
 
@@ -188,13 +226,16 @@ public partial class ChronoJumpWindow
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "laterality-both.png");
 		image_top_laterality.Pixbuf = pixbuf;
-
-		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "laterality-both.png");
 		image_encoder_laterality_both.Pixbuf = pixbuf;
+		image_force_sensor_laterality_both.Pixbuf = pixbuf;
+
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "laterality-right.png");
 		image_encoder_laterality_r.Pixbuf = pixbuf;
+		image_force_sensor_laterality_r.Pixbuf = pixbuf;
+
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "laterality-left.png");
 		image_encoder_laterality_l.Pixbuf = pixbuf;
+		image_force_sensor_laterality_l.Pixbuf = pixbuf;
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "extra-mass.png");
 		image_top_extra_mass.Pixbuf = pixbuf;
@@ -206,9 +247,12 @@ public partial class ChronoJumpWindow
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "folder_check.png");
 		image_force_sensor_open_folder.Pixbuf = pixbuf;
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "zoom.png");
-		image_current_person_zoom.Pixbuf = pixbuf;
 		image_force_sensor_check_version.Pixbuf = pixbuf;
 
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "portrait_zoom.png");
+		image_current_person_zoom.Pixbuf = pixbuf;
+		image_current_person_zoom_h.Pixbuf = pixbuf;
+
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_no_photo.png");
 		image_current_person.Pixbuf = pixbuf;
 
@@ -225,9 +269,6 @@ public partial class ChronoJumpWindow
 		image_tests_sprint.Pixbuf = pixbuf;
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_cancel.png");
-		image_button_cancel.Pixbuf = pixbuf;
-		image_encoder_capture_cancel.Pixbuf = pixbuf;
-		image_encoder_analyze_cancel.Pixbuf = pixbuf;
 		image_selector_start_cancel.Pixbuf = pixbuf;
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_person_pin.png");
@@ -254,6 +295,7 @@ public partial class ChronoJumpWindow
 		image_add_test2.Pixbuf = pixbuf;
 		image_add_test3.Pixbuf = pixbuf;
 		image_add_test4.Pixbuf = pixbuf;
+		image_add_test5.Pixbuf = pixbuf;
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_test_inspect.png");
 		image_test_inspect.Pixbuf = pixbuf;
@@ -264,6 +306,7 @@ public partial class ChronoJumpWindow
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_recalculate.png");
 		image_recalculate.Pixbuf = pixbuf;
+		image_force_sensor_capture_recalculate.Pixbuf = pixbuf;
 		image_force_sensor_analyze_recalculate.Pixbuf = pixbuf;
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_build_24.png");
@@ -306,6 +349,7 @@ public partial class ChronoJumpWindow
 		image_encoder_exercise_add.Pixbuf = pixbuf;
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_edit.png");
 		image_encoder_exercise_edit.Pixbuf = pixbuf;
+		image_force_sensor_exercise_edit.Pixbuf = pixbuf;
 		image_edit_current_person.Pixbuf = pixbuf;
 		image_edit_current_person_h.Pixbuf = pixbuf;
 		image_session_edit.Pixbuf = pixbuf;
@@ -338,14 +382,14 @@ public partial class ChronoJumpWindow
 		image_rest.Pixbuf = pixbuf;
 		image_encoder_rhythm_rest.Pixbuf = pixbuf;
 
-		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_visibility.png");
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "folder_check.png");
 		image_all_persons_events.Pixbuf = pixbuf;
 		image_all_persons_events_h.Pixbuf = pixbuf;
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "inertial_rolled.png");
 		image_inertial_rolled.Pixbuf = pixbuf;
-		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "inertial_half_rolled.png");
-		image_inertial_half_rolled.Pixbuf = pixbuf;
+		//pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "inertial_half_rolled.png");
+		//image_inertial_half_rolled.Pixbuf = pixbuf;
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "inertial_extended.png");
 		image_inertial_extended.Pixbuf = pixbuf;
 
@@ -353,6 +397,18 @@ public partial class ChronoJumpWindow
 		image_encoder_calibrate.Pixbuf = pixbuf;
 		image_encoder_recalibrate.Pixbuf = pixbuf;
 
+		image_video_yes.Pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "videocamera_on.png");
+		image_video_encoder_yes.Pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "videocamera_on.png");
+		image_video_encoder_yes1.Pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "videocamera_on.png");
+		image_video_no.Pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "videocamera_off.png");
+		image_video_encoder_no.Pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "videocamera_off.png");
+
+		image_camera_at_boot.Pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "videocamera_off.png");
+
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_photo_preview.png");
+		image_video_preview.Pixbuf = pixbuf;
+		image_video_encoder_preview.Pixbuf = pixbuf;
+
 		/*
 		 * <------ end of material design icons
 		 */
@@ -478,6 +534,10 @@ public partial class ChronoJumpWindow
 		image_run_type_delete_simple.Pixbuf = pixbuf;
 		image_run_type_delete_intervallic.Pixbuf = pixbuf;
 		image_session_delete.Pixbuf = pixbuf;
+
+		image_button_cancel.Pixbuf = pixbuf;
+		image_encoder_capture_cancel.Pixbuf = pixbuf;
+		image_encoder_analyze_cancel.Pixbuf = pixbuf;
 		
 		//zoom icons, done like this because there's one zoom icon created ad-hoc, 
 		//and is not nice that the other are different for an user theme change
@@ -491,6 +551,17 @@ public partial class ChronoJumpWindow
 		image_pulses_zoom.Pixbuf = pixbuf;
 		image_multi_chronopic_zoom.Pixbuf = pixbuf;
 
+		//video play icons
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "video_play.png");
+		image_video_play_this_test.Pixbuf = pixbuf;
+		image_video_play_this_test_encoder.Pixbuf = pixbuf;
+		image_video_play_selected_jump.Pixbuf = pixbuf;
+		image_video_play_selected_jump_rj.Pixbuf = pixbuf;
+		image_video_play_selected_run.Pixbuf = pixbuf;
+		image_video_play_selected_run_interval.Pixbuf = pixbuf;
+		image_video_play_selected_pulse.Pixbuf = pixbuf;
+		image_video_play_selected_reaction_time.Pixbuf = pixbuf;
+		image_video_play_selected_multi_chronopic.Pixbuf = pixbuf;
 
 		//white background in chronopic viewports
 		UtilGtk.DeviceColors(viewport_chronopics, true);
@@ -512,18 +583,35 @@ public partial class ChronoJumpWindow
 		UtilGtk.ColorsCheckbox(viewport_chronopics, check_encoder_analyze_show_range);
 		UtilGtk.ColorsCheckbox(viewport_chronopics, check_encoder_analyze_show_time_to_peak_power);
 
-
-		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "gpm-statistics.png");
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_analyze.png");
 		image_encoder_analyze_stats.Pixbuf = pixbuf;
 		image_encoder_analyze_image_save.Pixbuf = pixbuf;
-		image_forcesensor_analyze_image_save.Pixbuf = pixbuf;
-		image_forcesensor_analyze_image_save1.Pixbuf = pixbuf;
+		image_forcesensor_analyze_save_signal.Pixbuf = pixbuf;
+		image_forcesensor_analyze_save_rfd_auto.Pixbuf = pixbuf;
+		image_forcesensor_analyze_save_rfd_manual.Pixbuf = pixbuf;
 		image_jumps_profile_save.Pixbuf = pixbuf;
+		image_encoder_analyze_image_compujump_send_email_image.Pixbuf = pixbuf;
+
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "save.png");
+		image_encoder_analyze_table_save_1.Pixbuf = pixbuf;
+		image_encoder_analyze_image_save_1.Pixbuf = pixbuf;
+		image_encoder_analyze_1RM_save_1.Pixbuf = pixbuf;
+		image_encoder_analyze_image_save_2.Pixbuf = pixbuf;
+		image_forcesensor_analyze_image_save2.Pixbuf = pixbuf;
+		image_forcesensor_analyze_image_save3.Pixbuf = pixbuf;
+		image_forcesensor_analyze_image_save5.Pixbuf = pixbuf;
+		image_forcesensor_analyze_image_save6.Pixbuf = pixbuf;
+		image_forcesensor_analyze_image_save7.Pixbuf = pixbuf;
+		image_sprint_analyze_image_save.Pixbuf = pixbuf;
+
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "grid.png");
+		image_encoder_analyze_table_save.Pixbuf = pixbuf;
+
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_email.png");
+		image_encoder_analyze_image_compujump_send_email_send.Pixbuf = pixbuf;
+
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "stock_delete.png");
 		image_encoder_signal_delete.Pixbuf = pixbuf;
-	
-		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "spreadsheet.png");
-		image_encoder_analyze_table_save.Pixbuf = pixbuf;
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_analyze_general.png");
 		image_tests_analyze_general.Pixbuf = pixbuf;
@@ -538,7 +626,8 @@ public partial class ChronoJumpWindow
 		image_encoder_capture_execute.Pixbuf = pixbuf;
 		*/
 
-		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "finish.png"); //gnome (white)
+		//pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "finish.png"); //gnome (white)
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "floppy.png");
 		image_button_finish.Pixbuf = pixbuf;
 		image_encoder_capture_finish.Pixbuf = pixbuf;
 
@@ -607,7 +696,8 @@ public partial class ChronoJumpWindow
 		image_encoder_analyze_mean.Pixbuf = pixbuf;
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + Constants.FileNameEncoderAnalyzeMaxIcon);
 		image_encoder_analyze_max.Pixbuf = pixbuf;
-		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + Constants.FileNameEncoderAnalyzeRangeIcon);
+		//pixbuf = new Pixbuf (null, Util.GetImagePath(false) + Constants.FileNameEncoderAnalyzeRangeIcon);
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + Constants.FileNameEncoderAnalyzePositionIcon);
 		image_encoder_analyze_range.Pixbuf = pixbuf;
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + Constants.FileNameEncoderAnalyzeTimeToPPIcon);
 		image_encoder_analyze_time_to_pp.Pixbuf = pixbuf;
@@ -616,6 +706,8 @@ public partial class ChronoJumpWindow
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_encoder_triggers.png");
 		image_encoder_triggers.Pixbuf = pixbuf;
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_check.png");
+		image_encoder_analyze_check.Pixbuf = pixbuf;
 
 		//auto mode
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + Constants.FileNameAutoPersonSkipIcon);
