@@ -80,11 +80,13 @@ public partial class ChronoJumpWindow
 			Pixbuf pixbuf = new Pixbuf (filenameMini);
 			image_current_person.Pixbuf = pixbuf;
 			button_image_current_person_zoom.Sensitive = true;
+			button_image_current_person_zoom_h.Sensitive = true;
 		} else {
 			//image_current_person.Pixbuf = null;
 			Pixbuf pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_no_photo.png");
 			image_current_person.Pixbuf = pixbuf;
 			button_image_current_person_zoom.Sensitive = false;
+			button_image_current_person_zoom_h.Sensitive = false;
 		}
 	}
 
