@@ -168,7 +168,7 @@ public partial class ChronoJumpWindow
 		crt.Visible = true;
 		crt.Activatable = true;
 		crt.Active = true;
-		crt.Toggled += ItemToggled;
+		crt.Toggled += EncoderCaptureItemToggled;
 		Gtk.TreeViewColumn column = new Gtk.TreeViewColumn ();
 
 		column.Title = Catalog.GetString("Saved");
@@ -265,18 +265,31 @@ public partial class ChronoJumpWindow
 		}
 	}
 
-	void ItemToggled(object o, ToggledArgs args) 
+	void EncoderCaptureItemToggled(object o, ToggledArgs args)
 	{
 		//cannot toggle item while capturing or recalculating
 		if(capturingCsharp == encoderCaptureProcess.CAPTURING ||
 				encoderRProcAnalyze.status == EncoderRProc.Status.RUNNING)
 			return;
 
+		int inertialStart = 0;
+		if( current_menuitem_mode == Constants.Menuitem_modes.POWERINERTIAL)
+		{
+			if(ecconLast == "c")
+				inertialStart = preferences.encoderCaptureInertialDiscardFirstN;
+			else
+				inertialStart = 2 * preferences.encoderCaptureInertialDiscardFirstN;
+		}
+
 		TreeIter iter;
 		int column = 0;
 		if (encoderCaptureListStore.GetIterFromString (out iter, args.Path)) 
 		{
 			int rowNum = Convert.ToInt32(args.Path); //starts at zero
+
+			//do not allow to click a discarded repetition
+			if(rowNum < inertialStart)
+				return;
 			
 			//on "ecS" don't pass the 2nd row, pass always the first
 			//then need to move the iter to previous row
@@ -343,15 +356,25 @@ public partial class ChronoJumpWindow
 	{
 		int bestRow = 0;
 		int numRows = 0;
+
+		int inertialStart = 0;
+		if( current_menuitem_mode == Constants.Menuitem_modes.POWERINERTIAL)
+		{
+			if(ecconLast == "c")
+				inertialStart = preferences.encoderCaptureInertialDiscardFirstN;
+			else
+				inertialStart = 2 * preferences.encoderCaptureInertialDiscardFirstN;
+		}
+
 		if(saveOption == Constants.EncoderAutoSaveCurve.BEST || saveOption == Constants.EncoderAutoSaveCurve.FROM4TOPENULTIMATE) {
 			if(ecconLast == "c") {
 				//get the concentric curves
 				EncoderSignal encoderSignal = new EncoderSignal(treeviewEncoderCaptureCurvesGetCurves(AllEccCon.CON));
-				bestRow = encoderSignal.FindPosOfBest(mainVariable);
+				bestRow = encoderSignal.FindPosOfBest(inertialStart, mainVariable);
 				numRows = encoderSignal.CurvesNum();
 			} else {
 				EncoderSignal encoderSignal = new EncoderSignal(treeviewEncoderCaptureCurvesGetCurves(AllEccCon.ALL));
-				bestRow = encoderSignal.FindPosOfBestEccCon(mainVariable); //will be pos of the ecc
+				bestRow = encoderSignal.FindPosOfBestEccCon(inertialStart, mainVariable); //will be pos of the ecc
 				numRows = encoderSignal.CurvesNum();
 			}
 		}
@@ -371,23 +394,33 @@ public partial class ChronoJumpWindow
 		Sqlite.Open();
 
 		bool changeTo;
-		while(iterOk) {
+		while(iterOk)
+		{
 			TreePath path = encoderCaptureListStore.GetPath(iter);
 			
-			bool from4ToPenult = false;
+			//discard first rows
+			bool thisRowDiscarded = false;
+			if( current_menuitem_mode == Constants.Menuitem_modes.POWERINERTIAL &&
+					( (ecconLast == "c" && i < preferences.encoderCaptureInertialDiscardFirstN) ||
+					(ecconLast != "c" && i < 2 * preferences.encoderCaptureInertialDiscardFirstN) ) )
+			{
+				thisRowDiscarded = true;
+			}
+
+			bool fromValidToPenult = false;
 			if( saveOption == Constants.EncoderAutoSaveCurve.FROM4TOPENULTIMATE &&
-					( (ecconLast == "c" && i > 2 && i < numRows -1) ||
-					(ecconLast != "c" && i > 4 && i < numRows -2) ) )
-				from4ToPenult = true;
+					( (ecconLast == "c" && i < numRows -1) ||
+					(ecconLast != "c" && i < numRows -2) ) )
+				fromValidToPenult = true;
 			
 			EncoderCurve curve = (EncoderCurve) encoderCaptureListStore.GetValue (iter, 0);
 			if(
-					(! curve.Record && saveOption == Constants.EncoderAutoSaveCurve.ALL) ||
-					(! curve.Record && saveOption == Constants.EncoderAutoSaveCurve.BEST && i == bestRow) ||
-					(! curve.Record && saveOption == Constants.EncoderAutoSaveCurve.FROM4TOPENULTIMATE && from4ToPenult) ||
-					(curve.Record && saveOption == Constants.EncoderAutoSaveCurve.BEST && i != bestRow) ||
-					(curve.Record && saveOption == Constants.EncoderAutoSaveCurve.NONE) ||
-					(curve.Record && saveOption == Constants.EncoderAutoSaveCurve.FROM4TOPENULTIMATE && ! from4ToPenult) )
+					(! curve.Record && ! thisRowDiscarded && saveOption == Constants.EncoderAutoSaveCurve.ALL) ||
+					(! curve.Record && ! thisRowDiscarded && saveOption == Constants.EncoderAutoSaveCurve.BEST && i == bestRow) ||
+					(! curve.Record && ! thisRowDiscarded && saveOption == Constants.EncoderAutoSaveCurve.FROM4TOPENULTIMATE && fromValidToPenult) ||
+					(curve.Record && (thisRowDiscarded || saveOption == Constants.EncoderAutoSaveCurve.BEST && i != bestRow)) ||
+					(curve.Record && (thisRowDiscarded || saveOption == Constants.EncoderAutoSaveCurve.NONE)) ||
+					(curve.Record && (thisRowDiscarded || saveOption == Constants.EncoderAutoSaveCurve.FROM4TOPENULTIMATE && ! fromValidToPenult)) )
 			{ 
 				changeTo = ! curve.Record;
 				
@@ -494,8 +527,12 @@ public partial class ChronoJumpWindow
 	public string [] GetTreeviewEncoderAnalyzeHeaders(bool screenOrCSV)
 	{
 		string timeUnits = "(s)";
+		string distanceUnits = "(cm)";
 		if(! screenOrCSV)
+		{
 			timeUnits = "(ms)";
+			distanceUnits = "(mm)";
+		}
 
 		string [] treeviewEncoderAnalyzeHeaders = {
 			Catalog.GetString("Repetition") + "\n",
@@ -507,7 +544,7 @@ public partial class ChronoJumpWindow
 			Catalog.GetString("Inertia M.") + "\n(Kg*cm^2)",
 			Catalog.GetString("Start") + "\n" + timeUnits,
 			Catalog.GetString("Duration") + "\n" + timeUnits,
-			Catalog.GetString("Distance") + "\n(cm)",
+			Catalog.GetString("Distance") + "\n" + distanceUnits,
 			"v" + "\n(m/s)",
 			"vmax" + "\n(m/s)",
 			"t->vmax" + "\n" + timeUnits,
