@@ -26,9 +26,6 @@ using System.Collections; //ArrayList
 using System.Collections.Generic; //List
 using Mono.Unix;
 using Gdk; //for the EventMask
-using LongoMatch.Gui;
-using LongoMatch.Video.Capturer;
-using LongoMatch.Video.Common;
 
 
 
@@ -249,16 +246,12 @@ public partial class ChronoJumpWindow
 	private ExecutingGraphData event_execute_prepareForTest () 
 	{
 		checkbutton_video.Sensitive = false;
-		if(preferences.videoOn) {
-			capturer.ClickRec();
-			//label_video_feedback.Text = Catalog.GetString("Recording");
-			label_video_feedback.Text = "Rec.";
-		}
 
 		ExecutingGraphData executingGraphData = new ExecutingGraphData(
 				event_execute_button_cancel, event_execute_button_finish, 
 				event_execute_label_message,  
 				event_execute_label_event_value,  event_execute_label_time_value,
+				label_video_feedback,
 				event_execute_progressbar_event,  event_execute_progressbar_time);
 		
 		return executingGraphData;
@@ -1199,7 +1192,7 @@ public partial class ChronoJumpWindow
 		
 		double timeTotal = eventGraph.time;
 		// start of contact chunks
-		if(runPTL != null)
+		if(runPTL != null && runPTL.UseDoubleContacts())
 		{
 			List<RunPhaseTimeListObject> runPTLInListForPainting = runPTL.InListForPainting();
 
@@ -1675,7 +1668,7 @@ public partial class ChronoJumpWindow
 			// start of contact chunks
 			double negativePTLTime = 0;
 			double timeTotalWithExtraPTL = timeTotal;
-			if(runPTL != null)
+			if(runPTL != null && runPTL.UseDoubleContacts())
 			{
 				List<RunPhaseTimeListObject> runPTLInListForPainting = runPTL.InListForPainting();
 
@@ -2263,8 +2256,9 @@ public partial class ChronoJumpWindow
 		checkbutton_video.Sensitive = true;
 		if(preferences.videoOn) {	
 			label_video_feedback.Text = "";
-			capturer.ClickStop();
-			videoCapturePrepare(false); //if error, show message
+			button_video_preview.Visible = true;
+			//capturer.ClickStop();
+			//videoCapturePrepare(false); //if error, show message
 		}
 	}
 	
@@ -2419,8 +2413,9 @@ public partial class ChronoJumpWindow
 		if(preferences.videoOn) {
 			//it will be recorded on temp, but chronojump will move it to chronojump/multimedia folders
 			label_video_feedback.Text = "";
-			capturer.ClickStop();
-			videoCapturePrepare(false); //if error, show message
+			button_video_preview.Visible = true;
+			//capturer.ClickStop();
+			//videoCapturePrepare(false); //if error, show message
 		}
 	}
 	
