@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2014-2016   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2014-2017   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -35,7 +35,6 @@ public class ExecuteAutoWindow
 
 	//1st tab
 	[Widget] Gtk.RadioButton radio_load;
-	[Widget] Gtk.RadioButton radio_new;
 	[Widget] Gtk.Notebook notebook_load_or_new;
 	[Widget] Gtk.TreeView treeview_load;
 	[Widget] Gtk.RadioButton radio_by_persons;
@@ -57,7 +56,6 @@ public class ExecuteAutoWindow
 	[Widget] Gtk.Label label_serie1;
 	[Widget] Gtk.Label label_serie2;
 	[Widget] Gtk.Label label_serie3;
-	[Widget] Gtk.ScrolledWindow scrolled_win_serie1;
 	[Widget] Gtk.ScrolledWindow scrolled_win_serie2;
 	[Widget] Gtk.ScrolledWindow scrolled_win_serie3;
 	[Widget] Gtk.TreeView treeview_serie1;
@@ -79,7 +77,6 @@ public class ExecuteAutoWindow
 	TreeStore store_result;
 	
 	static ExecuteAutoWindow ExecuteAutoWindowBox;
-	Gtk.Window parent;
 	int sessionID;
 
 	ExecuteAuto.ModeTypes mode;
@@ -90,9 +87,9 @@ public class ExecuteAutoWindow
 	
 	public ExecuteAutoWindow (Gtk.Window parent) {
 		Glade.XML gladeXML;
-		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "chronojump.glade", "execute_auto", null);
+		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "execute_auto.glade", "execute_auto", null);
 		gladeXML.Autoconnect(this);
-		this.parent =  parent;
+		execute_auto.Parent = parent;
 		
 		//put an icon to window
 		UtilGtk.IconWindow(execute_auto);
@@ -100,7 +97,7 @@ public class ExecuteAutoWindow
 		FakeButtonAccept = new Gtk.Button();
 	}
 
-	static new public ExecuteAutoWindow Show (Gtk.Window parent, int sessionID)
+	static public ExecuteAutoWindow Show (Gtk.Window parent, int sessionID)
 	{
 		if (ExecuteAutoWindowBox == null) {
 			ExecuteAutoWindowBox = new ExecuteAutoWindow (parent);
@@ -115,7 +112,7 @@ public class ExecuteAutoWindow
 	}
 	
 	//creates and shows the third tab
-	static new public ExecuteAutoWindow ShowJustOrder (Gtk.Window parent, ArrayList orderedData, int orderedDataPos)
+	static public ExecuteAutoWindow ShowJustOrder (Gtk.Window parent, ArrayList orderedData, int orderedDataPos)
 	{
 		if (ExecuteAutoWindowBox == null) {
 			ExecuteAutoWindowBox = new ExecuteAutoWindow (parent);
@@ -233,7 +230,6 @@ public class ExecuteAutoWindow
 
 	private void on_treeview_load_button_release_event (object o, ButtonReleaseEventArgs args) {
 		Gdk.EventButton e = args.Event;
-		Gtk.TreeView myTv = (Gtk.TreeView) o;
 		if (e.Button == 3) {
 			Menu myMenu = new Menu ();
 			Gtk.MenuItem myItem;
