@@ -1,3 +1,4 @@
+
 /*
  * This file is part of ChronoJump
  *
@@ -25,7 +26,34 @@ using Cairo;
 
 public static class JumpsProfileGraph
 {
-	public static void Do (List<JumpsProfileIndex> l_jpi, DrawingArea area) 
+	public static void ShowDoneJumps(List<JumpsProfile.YesNo> jumpsDone,
+			Gtk.Image image_jumps_profile_sj_yes, Gtk.Image image_jumps_profile_sj_no,
+			Gtk.Image image_jumps_profile_sjl_yes, Gtk.Image image_jumps_profile_sjl_no,
+			Gtk.Image image_jumps_profile_cmj_yes, Gtk.Image image_jumps_profile_cmj_no,
+			Gtk.Image image_jumps_profile_abk_yes, Gtk.Image image_jumps_profile_abk_no,
+			Gtk.Image image_jumps_profile_dja_yes, Gtk.Image image_jumps_profile_dja_no
+			)
+	{
+		showDoneJump(jumpsDone[0] == JumpsProfile.YesNo.YES, image_jumps_profile_sj_yes, image_jumps_profile_sj_no);
+		showDoneJump(jumpsDone[1] == JumpsProfile.YesNo.YES, image_jumps_profile_sjl_yes, image_jumps_profile_sjl_no);
+		showDoneJump(jumpsDone[2] == JumpsProfile.YesNo.YES, image_jumps_profile_cmj_yes, image_jumps_profile_cmj_no);
+		showDoneJump(jumpsDone[3] == JumpsProfile.YesNo.YES, image_jumps_profile_abk_yes, image_jumps_profile_abk_no);
+		showDoneJump(jumpsDone[4] == JumpsProfile.YesNo.YES, image_jumps_profile_dja_yes, image_jumps_profile_dja_no);
+	}
+
+	private static void showDoneJump(bool done, Gtk.Image image_yes, Gtk.Image image_no)
+	{
+		if(done) {
+			image_yes.Visible = true;
+			image_no.Visible = false;
+		}
+		else {
+			image_yes.Visible = false;
+			image_no.Visible = true;
+		}
+	}
+
+	public static void Do (List<JumpsProfileIndex> l_jpi, DrawingArea area, string title, string date)
 	{
 		//1 create context
 		Cairo.Context g = Gdk.CairoHelper.Create (area.GdkWindow);
@@ -37,43 +65,72 @@ public static class JumpsProfileGraph
 		//3 calculate sum
 		double sum = 0;
 		foreach(JumpsProfileIndex jpi in l_jpi)
-			sum += jpi.Result;
-		
+			if(jpi.Result >= 0)
+				sum += jpi.Result;
+
 		//4 prepare font
 		g.SelectFontFace("Helvetica", Cairo.FontSlant.Normal, Cairo.FontWeight.Normal);
 		int textHeight = 12;
 		g.SetFontSize(textHeight);
 
+		if(sum == 0)
+		{
+			g.SetSourceRGB(0,0,0);
+			g.SetFontSize(16);
+			printText(100, 100, 24, textHeight, Constants.JumpsProfileNeededJumps, g, false);
+			g.GetTarget().Dispose ();
+			g.Dispose ();
+			return;
+		}
+
+
 		//5 plot arcs
 		if(sum > 0 ) {
 			double acc = 0; //accumulated
 			foreach(JumpsProfileIndex jpi in l_jpi) {
 				double percent = 2 * jpi.Result / sum; //*2 to be in range 0*pi - 2*pi
-				plotArc(200, 200, 150, acc -.5, acc + percent -.5, g, jpi.Color); //-.5 to start at top of the pie
-				acc += percent;
+				if(percent > 0)
+				{
+					plotArc(200, 200, 150, acc -.5, acc + percent -.5, g, jpi.Color); //-.5 to start at top of the pie
+					acc += percent;
+				}
 			}
+			//fix last radius line, because ClosePath has been disabled
+			g.MoveTo (200,50);
+			g.LineTo (200, 200);
+			g.LineWidth = 2;
+			g.Stroke ();
 		}
 
 		//6 draw legend at right
-		int y = 50;
+		int legendX = findLegendTextXPos(l_jpi, sum, 400);
+		int y = 40;
 		//R seq(from=50,to=(350-24),length.out=5)
 		//[1] 50 119 188 257 326 #difference is 69
-		foreach(JumpsProfileIndex jpi in l_jpi) {
-			drawRoundedRectangle (400,  y, 40, 24, 6, g, jpi.Color);
-			
-			double percent = 0;
-			if(sum > 0)
-				percent = 100 * jpi.Result / sum;
+		//g.SelectFontFace("Helvetica", Cairo.FontSlant.Normal, Cairo.FontWeight.Bold);
+		foreach(JumpsProfileIndex jpi in l_jpi)
+		{
+			double percent = 100 * Util.DivideSafe(jpi.Result, sum);
+			printText(legendX,  y, 24, textHeight, Util.TrimDecimals(percent, 1) + jpi.Text, g, false);
+			if(percent != 0)
+				drawRoundedRectangle (legendX,  y+30 , Convert.ToInt32(2 * percent), 20, 4, g, jpi.Color);
 
-			printText(460,  y, 24, textHeight, Util.TrimDecimals(percent, 1) + jpi.Text, g);
 			y += 69;
 		}
+		//print title and date
+		g.SetFontSize(18);
+		printText(200, y, 0, textHeight, title, g, true);
+		g.SetFontSize(textHeight);
+		printText(200, y+20, 0, textHeight, "Chronojump profile (" + date + ")", g, true);
+
+		//g.SelectFontFace("Helvetica", Cairo.FontSlant.Normal, Cairo.FontWeight.Normal);
 	
 		//7 print errors (if any)
 		g.SetSourceRGB(0.5, 0, 0);
 		y = 70;
 		foreach(JumpsProfileIndex jpi in l_jpi) {
-			printText(460,  y, 24, textHeight, jpi.ErrorMessage, g);
+			if(jpi.ErrorMessage != "")
+				printText(legendX +12,  y, 24, textHeight, jpi.ErrorMessage, g, false);
 			y += 69;
 		}
 		
@@ -88,7 +145,9 @@ public static class JumpsProfileGraph
 		//pie chart
 		g.MoveTo (centerx,  centery);
 		g.Arc(centerx, centery, radius, start * Math.PI, end * Math.PI);
-		g.ClosePath();
+
+		//commented because gets ugly on last radius line (specially if angle is low)
+		//g.ClosePath();
 		g.SetSourceRGB(color.R, color.G, color.B);
 		g.FillPreserve ();
 
@@ -96,10 +155,17 @@ public static class JumpsProfileGraph
 		g.LineWidth = 2;
 		g.Stroke ();
 	}
-	
-	private static void printText (int x, int y, int height, int textHeight, string text, Cairo.Context g) 
+
+	private static void printText (int x, int y, int height, int textHeight, string text, Cairo.Context g, bool centered)
 	{
-		g.MoveTo(x, ((y+y+height)/2) + textHeight/2.0);
+		int moveToLeft = 0;
+		if(centered)
+		{
+			Cairo.TextExtents te;
+			te = g.TextExtents(text);
+			moveToLeft = Convert.ToInt32(te.Width/2);
+		}
+		g.MoveTo( x - moveToLeft, ((y+y+height)/2) + textHeight/2 );
 		g.ShowText(text);
 	}
 
@@ -109,6 +175,13 @@ public static class JumpsProfileGraph
 	{
 		g.Save ();
 
+		//manage negative widths
+		if(width < 0)
+		{
+			x += width; //it will shift to the left (width is negative)
+			width *= -1;
+		}
+
 		if ((radius > height / 2) || (radius > width / 2))
 			radius = min (height / 2, width / 2);
 
@@ -140,6 +213,22 @@ public static class JumpsProfileGraph
 		return arr[minp];
 	}
 
+	//if there are negative values, move legendXPos to the right to not overpolot the pie chart
+	private static int findLegendTextXPos(List<JumpsProfileIndex> l_jpi, double sum, int defaultValue)
+	{
+		if(sum == 0)
+			return defaultValue;
+
+		int min = 0;
+		foreach(JumpsProfileIndex jpi in l_jpi)
+		{
+			int percent = Convert.ToInt32(2 * 100 * jpi.Result / sum);
+			if(percent < min)
+				min = percent;
+		}
+		return defaultValue + Math.Abs(min);
+	}
+
 	//save to png with http://www.mono-project.com/docs/tools+libraries/libraries/Mono.Cairo/tutorial/ stroke
 	/*
 	ImageSurface surface = new ImageSurface(Format.ARGB32, 120, 120);
