@@ -57,6 +57,7 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Label label_top_person_name;
 	[Widget] Gtk.Label label_top_encoder_person_name;
 	[Widget] Gtk.Button button_image_current_person_zoom;
+	[Widget] Gtk.Button button_image_current_person_zoom_h;
 	[Widget] Gtk.Image image_current_person;
 	[Widget] Gtk.Button button_contacts_person_change;
 	[Widget] Gtk.Button button_encoder_person_change;
@@ -73,6 +74,10 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Notebook notebook_encoder_capture_main;
 	[Widget] Gtk.VBox vbox_treeview_encoder_at_second_page;
 
+	//encoder ...
+	[Widget] Gtk.Button button_encoder_monthly_change_current_session;
+	[Widget] Gtk.Button button_encoder_analyze_image_compujump_send_email;
+
 	//runsInterval
 	[Widget] Gtk.HBox hbox_runs_interval_compujump;
 	[Widget] Gtk.RadioButton radio_run_interval_compujump_5m;
@@ -103,6 +108,8 @@ public partial class ChronoJumpWindow
 	//private static CompujumpAutologout compujumpAutologout;
 	private CompujumpAutologout compujumpAutologout;
 
+	private static RFIDWaitingAdminGuiObjects rfidWaitingAdminGuiObjects;
+
 	DialogPersonPopup dialogPersonPopup;
 		
 	Config configChronojump;
@@ -136,7 +143,6 @@ public partial class ChronoJumpWindow
 
 			//don't allow to change encoderConfiguration
 			label_encoder_exercise_encoder.Visible = false;
-			vseparator_encoder_exercise_encoder.Visible = false;
 			hbox_encoder_exercise_encoder.Visible = false;
 
 			//don't show encoder 1-cont buttons
@@ -146,6 +152,21 @@ public partial class ChronoJumpWindow
 			button_encoder_exercise_edit.Visible = false;
 			button_encoder_exercise_add.Visible = false;
 
+			//on networks do not allow to change devices until preferences option is checked
+			viewport_chronopics.Sensitive = false;
+			button_activate_chronopics_encoder.Sensitive = false;
+
+			//do not allow camera controls
+			showWebcamCaptureContactsControls (false); //contacts
+			hbox_video_encoder.Visible = false;
+
+			//networks always without lateral person win
+			//also this is important for seing label_rfid_encoder_wait
+			SqlitePreferences.Update("personWinHide", "True", false);
+			preferences.personWinHide = true;
+			configChronojump.PersonWinHide = true;
+			showPersonsOnTop(true);
+
 			if(configChronojump.CompujumpStationMode != Constants.Menuitem_modes.UNDEFINED)
 			{
 				//select_menuitem_mode_toggled(configChronojump.CompujumpStationMode);
@@ -180,6 +201,7 @@ public partial class ChronoJumpWindow
 				rfid.FakeButtonChange.Clicked += new EventHandler(rfidChanged);
 				rfid.FakeButtonReopenDialog.Clicked += new EventHandler(rfidReopenDialog);
 				rfid.FakeButtonDisconnected.Clicked += new EventHandler(rfidDisconnected);
+				rfid.FakeButtonAdminDetected.Clicked += new EventHandler(rfidAdminDetectedSendMail);
 
 				threadRFID = new Thread (new ThreadStart (RFIDStart));
 				GLib.Idle.Add (new GLib.IdleHandler (pulseRFID));
@@ -187,53 +209,75 @@ public partial class ChronoJumpWindow
 				LogB.ThreadStart();
 				threadRFID.Start();
 			}
+
+			if(configChronojump.CompujumpAdminEmail != "")
+				button_encoder_analyze_image_compujump_send_email.Visible = true;
+		}
+
+		if(configChronojump.Exhibition)
+		{
+			exhibitionGuiAtStart(configChronojump.ExhibitionStationType);
+			SqliteJson.UploadExhibitionTestsPending();
 		}
 
 		configDo();
 	}
 	private void RFIDStart()
 	{
+		startedRFIDWait = DateTime.MinValue;
+		rfidWaitingAdminGuiObjects = new RFIDWaitingAdminGuiObjects();
+		LogB.Information("networksRI: " + networksRunIntervalCanChangePersonSQLReady.ToString());
+
 		LogB.Information("RFID Start");
 		rfid.Start();
-		startedRFIDWait = DateTime.MinValue;
-		LogB.Information("networksRI: " + networksRunIntervalCanChangePersonSQLReady.ToString());
-		//rfid.ChangedEvent += new EventHandler(this.rfidChanged);
 	}
 	private void rfidChanged(object sender, EventArgs e)
 	{
+		LogB.Information("at rfidChanged");
 		/*
 		 * TODO: only if we are not in the middle of capture, or in cont mode without repetitions
 		 */
-		if(currentSession != null && rfid.Captured != capturedRFID)
+		if(currentSession == null)
+			return;
+
+		if(rfid.Captured != capturedRFID)
+			LogB.Information("detected different RFID: " + rfid.Captured);
+
+		if(isCompujumpCapturing ())
 		{
-			LogB.Information("RFID changed to: " + rfid.Captured);
+			startedRFIDWait = DateTime.Now;
+			LogB.Information("... but we are on the middle of capture");
+			return;
+		}
 
-			if(isCompujumpCapturing ())
-			{
-				startedRFIDWait = DateTime.Now;
-				LogB.Information("... but we are on the middle of capture");
-			} else {
-				capturedRFID = rfid.Captured;
-				rfidIsDifferent = true;
-
-				shouldUpdateRFIDGui = true;
-			}
+		if(rfid.Captured != capturedRFID)
+		{
+			capturedRFID = rfid.Captured;
+			rfidIsDifferent = true;
+			shouldUpdateRFIDGui = true;
 		}
 	}
 
 	private void rfidReopenDialog(object sender, EventArgs e)
 	{
-		if(currentSession != null && rfid.Captured == capturedRFID)
+		if(currentSession == null || rfid.Captured != capturedRFID)
+			return;
+
+		if(isCompujumpCapturing ())
 		{
-			if(isCompujumpCapturing ())
-			{
-				startedRFIDWait = DateTime.Now;
-				LogB.Information("... but we are on the middle of capture");
-			} else {
-				rfidIsDifferent = false;
-				shouldUpdateRFIDGui = true;
-			}
+			startedRFIDWait = DateTime.Now;
+			LogB.Information("... but we are on the middle of capture");
+			return;
 		}
+
+		rfidIsDifferent = false;
+		shouldUpdateRFIDGui = true; //this opens the task window
+	}
+
+	private void rfidAdminDetectedSendMail(object sender, EventArgs e)
+	{
+		checkFile(Constants.CheckFileOp.ENCODER_ANALYZE_SEND_IMAGE);
+		compujumpSendEmail(Constants.CheckFileOp.ENCODER_ANALYZE_SEND_IMAGE);
 	}
 
 	private void rfidDisconnected(object sender, EventArgs e)
@@ -311,9 +355,11 @@ public partial class ChronoJumpWindow
 			hbox_encoder_analyze_signal_or_curves.HeightRequest = 40;
 			button_encoder_analyze.SetSizeRequest(120,40);
 		}
+		/*
 		if(! configChronojump.UseVideo) {
 			alignment_video_encoder.Visible = false;
 		}
+		*/
 		//restriction for configured Compujump clients
 		//if(configChronojump.Compujump)
 		//	hbox_encoder_im_weights_n.Sensitive = false;
@@ -383,37 +429,9 @@ public partial class ChronoJumpWindow
 				//configChronojump.SessionMode == Config.SessionModeEnum.MONTHLY
 
 				string yearMonthStr = UtilDate.GetCurrentYearMonthStr();
-				LogB.Information("yearMonthStr: " + yearMonthStr);
-				if(! Sqlite.Exists(false, Constants.SessionTable, yearMonthStr))
-				{
-					//this creates the session and inserts at DB
-					currentSession = new Session(
-							yearMonthStr, "", DateTime.Today,	//name, place, dateTime
-							Constants.SportUndefinedID, Constants.SpeciallityUndefinedID, Constants.LevelUndefinedID,
-							"", Constants.ServerUndefinedID); //comments, serverID
-
-					//insert personSessions from last month
-					string yearLastMonthStr = UtilDate.GetCurrentYearLastMonthStr();
-					if(Sqlite.Exists(false, Constants.SessionTable, yearLastMonthStr))
-					{
-						Session s = SqliteSession.SelectByName(yearLastMonthStr);
-
-						//import all persons from last session
-						List<PersonSession> personSessions = SqlitePersonSession.SelectPersonSessionList(s.UniqueID);
-
-						//convert all personSessions to currentSession
-						//and nullify UniqueID in order to be inserted incrementally by SQL
-						foreach(PersonSession ps in personSessions)
-						{
-							ps.UniqueID = -1;
-							ps.SessionID = currentSession.UniqueID;
-						}
-
-
-						//insert personSessions using a transaction
-						new SqlitePersonSessionTransaction(personSessions);
-					}
-				} else
+				if(needToCreateMonthlySession(yearMonthStr))
+					createMonthlySession(yearMonthStr);
+				else
 					currentSession = SqliteSession.SelectByName(yearMonthStr);
 			}
 			
@@ -451,6 +469,45 @@ public partial class ChronoJumpWindow
 		label_rfid_encoder_wait.Visible = false;
 	}
 
+	private bool needToCreateMonthlySession(string yearMonthStr)
+	{
+		LogB.Information("yearMonthStr: " + yearMonthStr);
+
+		return(! Sqlite.Exists(false, Constants.SessionTable, yearMonthStr));
+	}
+
+	private void createMonthlySession(string yearMonthStr)
+	{
+		//this creates the session and inserts at DB
+		currentSession = new Session(
+				yearMonthStr, "", DateTime.Today,	//name, place, dateTime
+				Constants.SportUndefinedID, Constants.SpeciallityUndefinedID, Constants.LevelUndefinedID,
+				"", Constants.ServerUndefinedID); //comments, serverID
+
+		setApp1Title(currentSession.Name, current_menuitem_mode);
+
+		//insert personSessions from last month
+		string yearLastMonthStr = UtilDate.GetCurrentYearLastMonthStr();
+		if(Sqlite.Exists(false, Constants.SessionTable, yearLastMonthStr))
+		{
+			Session s = SqliteSession.SelectByName(yearLastMonthStr);
+
+			//import all persons from last session
+			List<PersonSession> personSessions = SqlitePersonSession.SelectPersonSessionList(s.UniqueID);
+
+			//convert all personSessions to currentSession
+			//and nullify UniqueID in order to be inserted incrementally by SQL
+			foreach(PersonSession ps in personSessions)
+			{
+				ps.UniqueID = -1;
+				ps.SessionID = currentSession.UniqueID;
+			}
+
+			//insert personSessions using a transaction
+			new SqlitePersonSessionTransaction(personSessions);
+		}
+	}
+
 	DialogMessage dialogMessageNotAtServer;
 	private bool pulseRFID ()
 	{
@@ -485,19 +542,58 @@ public partial class ChronoJumpWindow
 			label_rfid_encoder_wait.Visible = false;
 		}
 
-		if(isCompujumpCapturing ())
+		if(isCompujumpCapturing ()) {
+			Thread.Sleep (100);
 			return true;
+		}
 
 		//---- end of checking if we are on the middle of capture.
 
+		//to send email with analyzed image to the admin
+		if(rfidWaitingAdminGuiObjects != null)
+		{
+			if(rfidWaitingAdminGuiObjects.ShowGuiMessageSuccess)
+			{
+				new DialogMessage(Constants.MessageTypes.INFO,
+						"Sent Email to: " + configChronojump.CompujumpAdminEmail);
+				rfidWaitingAdminGuiObjects = new RFIDWaitingAdminGuiObjects();
+			}
+			if(rfidWaitingAdminGuiObjects.ShowGuiMessageFailed)
+			{
+				new DialogMessage(Constants.MessageTypes.WARNING, "Could not send email\nProbably need to install mailutils package.");
+				rfidWaitingAdminGuiObjects = new RFIDWaitingAdminGuiObjects();
+			}
+
+			if(rfidWaitingAdminGuiObjects.Waiting)
+			{
+				LogB.Information("rest seconds: " + rfidWaitingAdminGuiObjects.RestSeconds().ToString());
+				if(rfidWaitingAdminGuiObjects.RestSeconds() != -1) {
+					label_rfid_encoder_wait.Text =
+						string.Format("Identify with admin ID wristband before {0} s.", rfidWaitingAdminGuiObjects.RestSeconds());
+					label_rfid_encoder_wait.Visible = true;
+				} else {
+					rfidWaitingAdminGuiObjects = new RFIDWaitingAdminGuiObjects();
+					label_rfid_encoder_wait.Text = "";
+					label_rfid_encoder_wait.Visible = false;
+				}
+				Thread.Sleep (100);
+				return true;
+			} else
+				label_rfid_encoder_wait.Text = "";
+		}
+
 
 		//don't allow this method to be called again until ended
 		//Note RFID detection can send many cards (the same) per second
-		if(updatingRFIDGuiStuff)
+		if(updatingRFIDGuiStuff) {
+			Thread.Sleep (100);
 			return true;
+		}
 
-		if(! shouldUpdateRFIDGui)
+		if(! shouldUpdateRFIDGui) {
+			Thread.Sleep (100);
 			return true;
+		}
 
 		shouldUpdateRFIDGui = false;
 		updatingRFIDGuiStuff = true;
@@ -512,7 +608,7 @@ public partial class ChronoJumpWindow
 
 		bool currentPersonWasNull = (currentPerson == null);
 		bool pChangedShowTasks = false;
-		Json json = new Json();
+		JsonCompujump json = new JsonCompujump(configChronojump.CompujumpDjango);
 
 		//select person by RFID
 		Person pLocal = SqlitePerson.SelectByRFID(capturedRFID);
@@ -561,6 +657,10 @@ public partial class ChronoJumpWindow
 					SqlitePerson.Update(pLocal);
 				}
 
+				string yearMonthStr = UtilDate.GetCurrentYearMonthStr();
+				if(needToCreateMonthlySession(yearMonthStr))
+					createMonthlySession(yearMonthStr);
+
 				currentPerson = pLocal;
 				insertAndAssignPersonSessionIfNeeded(json);
 
@@ -593,6 +693,10 @@ public partial class ChronoJumpWindow
 			LogB.Information("RFID person exists locally!!");
 			if(rfidIsDifferent || dialogPersonPopup == null || ! dialogPersonPopup.Visible)
 			{
+				string yearMonthStr = UtilDate.GetCurrentYearMonthStr();
+				if(needToCreateMonthlySession(yearMonthStr))
+					createMonthlySession(yearMonthStr);
+
 				currentPerson = pLocal;
 				insertAndAssignPersonSessionIfNeeded(json);
 
@@ -650,6 +754,13 @@ public partial class ChronoJumpWindow
 				selectRowTreeView_persons(treeview_persons, rowToSelect);
 			*/
 			getTasksExercisesAndPopup();
+
+			//load current session if MONTHLY and current session is not current month and currentPerson is not compumpAdminID
+			compujumpPersonChangedShouldChangeSession();
+
+			//not allow to change devices if person changed. If you want to change again, go to preferences/advanced networksAllowChangeDevices
+			preferences.networksAllowChangeDevices = false;
+			button_activate_chronopics_encoder.Sensitive = false;
 		}
 
 		//Wakeup screen if it's off
@@ -663,7 +774,21 @@ public partial class ChronoJumpWindow
 		return true;
 	}
 
-	private void insertAndAssignPersonSessionIfNeeded(Json json)
+	//load current session if MONTHLY and current session is not current month and currentPerson is not compumpAdminID
+	private void compujumpPersonChangedShouldChangeSession()
+	{
+		string yearMonthStr = UtilDate.GetCurrentYearMonthStr();
+		if(
+				configChronojump.SessionMode == Config.SessionModeEnum.MONTHLY &&
+				currentSession.Name != yearMonthStr &&
+				! configChronojump.CompujumpUserIsAdmin(currentPerson) )
+		{
+			currentSession = SqliteSession.SelectByName(yearMonthStr);
+			on_load_session_accepted();
+		}
+	}
+
+	private void insertAndAssignPersonSessionIfNeeded(JsonCompujump json)
 	{
 		PersonSession ps = SqlitePersonSession.Select(false, currentPerson.UniqueID, currentSession.UniqueID);
 		if(ps.UniqueID == -1)
@@ -693,7 +818,7 @@ public partial class ChronoJumpWindow
 	private void getTasksExercisesAndPopup()
 	{
 		//1) get tasks
-		Json json = new Json();
+		JsonCompujump json = new JsonCompujump(configChronojump.CompujumpDjango);
 		List<Task> tasks = json.GetTasks(currentPerson.UniqueID, configChronojump.CompujumpStationID);
 
 		//2) get exercises and insert if needed (only on encoder)
@@ -740,7 +865,8 @@ public partial class ChronoJumpWindow
 
 		dialogPersonPopup = new DialogPersonPopup(
 				currentPerson.UniqueID, currentPerson.Name, capturedRFID, tasks, stationsCount,
-				serverConnected, compujumpAutologout.Active);
+				serverConnected, compujumpAutologout.Active,
+				configChronojump.CompujumpDjango);
 
 		dialogPersonPopup.Fake_button_start_task.Clicked -= new EventHandler(compujumpTaskStart);
 		dialogPersonPopup.Fake_button_start_task.Clicked += new EventHandler(compujumpTaskStart);
@@ -850,6 +976,10 @@ public partial class ChronoJumpWindow
 		currentPerson = null;
 		currentPersonSession = null;
 		sensitiveGuiNoPerson ();
+
+		//not allow to change devices if person changed. If you want to change again, go to preferences/advanced networksAllowChangeDevices
+		preferences.networksAllowChangeDevices = false;
+		button_activate_chronopics_encoder.Sensitive = false;
 	}
 
 	private void compujumpPersonAutoLogoutChanged(object o, EventArgs args)
@@ -866,6 +996,29 @@ public partial class ChronoJumpWindow
 		return(compujumpAutologout.IsCompujumpCapturing());
 	}
 
+	//no GTK here because can be called from rfidChanged()
+	private void compujumpSendEmail(Constants.CheckFileOp op)
+	{
+		if(op == Constants.CheckFileOp.ENCODER_ANALYZE_SEND_IMAGE)
+		{
+			LogB.Information("Sending Email to: " + configChronojump.CompujumpAdminEmail);
+
+			NetworksSendMail nsm = new NetworksSendMail ();
+			if(nsm.Send(exportFileName, UtilEncoder.GetEncoderGraphTempFileName(), configChronojump.CompujumpAdminEmail))
+			{
+				rfidWaitingAdminGuiObjects.ShowGuiMessageSuccess = true;
+				LogB.Information("Done!");
+			} else {
+				rfidWaitingAdminGuiObjects.ShowGuiMessageFailed = true;
+				//no GTK here
+				//new DialogMessage(Constants.MessageTypes.WARNING, nsm.ErrorStr);
+				LogB.Information(nsm.ErrorStr);
+			}
+
+		}
+		//other future send email send objects
+	}
+
 	/*
 	 *
 	 * This code uses a watcher to see changes on a filename
@@ -1168,3 +1321,41 @@ public class CompujumpAutologout
 			return "Logout in\n" + Math.Round(maxTime, 2) + " min.";
 	}
 }
+
+//this class manages the wating of admin wristband in tasks like sending an email with the analyze image
+public class RFIDWaitingAdminGuiObjects
+{
+	public bool Waiting;
+	public bool ShowGuiMessageSuccess;
+	public bool ShowGuiMessageFailed;
+	//public string AdminRFID;
+
+	private static DateTime startedDT; //time to wait ID of the admin to have access to "higher" methods
+	private const int secondsLimit = 10; //10 seconds to use the admin ID
+
+	//constructor
+	public RFIDWaitingAdminGuiObjects()
+	{
+		Waiting = false;
+		ShowGuiMessageSuccess = false;
+		ShowGuiMessageFailed = false;
+		startedDT = DateTime.MinValue;
+		LogB.Information("RFIDWaitingAdminGuiObjects constructed!");
+	}
+
+	public void Start()
+	{
+		startedDT = DateTime.Now; //start countdown
+		Waiting = true;
+	}
+
+	//we have to capture before this time in seconds
+	public int RestSeconds()
+	{
+		TimeSpan span = DateTime.Now - startedDT;
+		if (Waiting && span.TotalSeconds < secondsLimit)
+			return Convert.ToInt32(Math.Round(secondsLimit - span.TotalSeconds, 0));
+		else
+			return -1;
+	}
+}
