@@ -29,9 +29,6 @@ using System.Collections.Generic; //List
 using Mono.Unix;
 using System.Threading;
 using System.IO; 
-using LongoMatch.Gui;
-using LongoMatch.Video.Capturer;
-using LongoMatch.Video.Common;
 
 //load person (jumper)
 public class PersonRecuperateWindow {
@@ -813,8 +810,13 @@ public class PersonAddModifyWindow
 	[Widget] Gtk.Button button_load_person;
 	[Widget] Gtk.Image image_load_person;
 
+	[Widget] Gtk.Image image_photo_from_file;
+	[Widget] Gtk.Image image_photo_preview;
+	[Widget] Gtk.Image image_photo_do;
+
 	[Widget] Gtk.Button button_add_photo_file;
-	[Widget] Gtk.Button button_take_photo;
+	[Widget] Gtk.Button button_take_photo_do;
+	[Widget] Gtk.HBox hbox_camera;
 	
 	[Widget] Gtk.Label label_date;
 	//[Widget] Gtk.Button button_change_date;
@@ -874,6 +876,7 @@ public class PersonAddModifyWindow
 
 	private Person currentPerson;
 	private Session currentSession;
+	private string videoDevice;
 	private PersonSession currentPersonSession;
 	private string sex = Constants.M;
 	private double weightIni;
@@ -886,7 +889,8 @@ public class PersonAddModifyWindow
 	//if we are adding a person, currentPerson.UniqueID it's -1
 	//if we are modifying a person, currentPerson.UniqueID is obviously it's ID
 	//showCapturePhoto is false on raspberry to not use camera
-	PersonAddModifyWindow (Gtk.Window parent, Session currentSession, Person currentPerson, bool showCapturePhoto)
+	//PersonAddModifyWindow (Gtk.Window parent, Session currentSession, Person currentPerson, bool showCapturePhoto)
+	PersonAddModifyWindow (Gtk.Window parent, Session currentSession, Person currentPerson)
 	{
 		Glade.XML gladeXML;
 		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "person_win.glade", "person_win", null);
@@ -916,13 +920,15 @@ public class PersonAddModifyWindow
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "calendar.png"); //from asssembly
 		image_calendar.Pixbuf = pixbuf;
 
-		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + Constants.FileNameZoomInIcon);
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "portrait_zoom.png");
 		image_zoom.Pixbuf = pixbuf;
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_person_outline.png");
 		image_load_person.Pixbuf = pixbuf;
 
-		button_take_photo.Visible = showCapturePhoto;
+		image_photo_from_file.Pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_attachment.png");
+		image_photo_preview.Pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_photo_preview.png");
+		image_photo_do.Pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_photo_do.png");
 
 		//delete a -1.png or -1.jpg added before on a new user where "accept" button was not pressed and window was closed
 		deleteOldPhotosIfAny(-1);
@@ -946,7 +952,7 @@ public class PersonAddModifyWindow
 		if(photoBigFile != "")
 		{
 			button_zoom.Sensitive = true;
-			button_add_photo_file.Label = Catalog.GetString("Change photo");
+			//button_add_photo_file.Label = Catalog.GetString("Change photo");
 		}
 		else
 			button_zoom.Sensitive = false;
@@ -1037,58 +1043,71 @@ public class PersonAddModifyWindow
 				//mini will be always png from now on (after 1.7.1-213)
 				string filenameMini = Util.GetPhotoPngFileName(true, currentPerson.UniqueID);
 				bool miniSuccess = UtilMultimedia.LoadAndResizeImage(fc.Filename, filenameMini, 150, -1); //-1: maintain aspect ratio
-
 				if(miniSuccess)
-				{
-					Pixbuf pixbuf = new Pixbuf (filenameMini);
-					image_photo_mini.Pixbuf = pixbuf;
-					button_add_photo_file.Label = Catalog.GetString("Change photo");
-					button_zoom.Sensitive = true;
-				}
+					showMiniPhoto(filenameMini);
 			}
 		}
 		//Don't forget to call Destroy() or the FileChooserDialog window won't get closed.
 		fc.Destroy();
 	}
 
-	Gtk.Window capturerWindow;
-	CapturerBin capturer;
-	void on_button_take_photo_clicked (object o, EventArgs args) 
+	private void showMiniPhoto(string filenameMini)
 	{
-		List<LongoMatch.Video.Utils.Device> devices = LongoMatch.Video.Utils.Device.ListVideoDevices();
-		if(devices.Count == 0) {
-			new DialogMessage(Constants.MessageTypes.WARNING, Constants.CameraNotFound);
-			return;
+		Pixbuf pixbuf = new Pixbuf (filenameMini);
+		image_photo_mini.Pixbuf = pixbuf;
+		//button_add_photo_file.Label = Catalog.GetString("Change photo");
+		button_zoom.Sensitive = true;
+	}
+
+	Gtk.Window capturerWindow;
+	Webcam webcam;
+	//CapturerBin capturer;
+	void on_button_take_photo_preview_camera_clicked (object o, EventArgs args)
+	{
+		// A) end if it's running
+		if(webcam != null && webcam.Running)
+		{
+			webcam.ExitCamera();
+			//return;
 		}
 
-		//deactivate camera to allow camera on edit person. videoOn will have same value to light checkbutton again later
-		app1_checkbutton_video.Active = false;
+		// B) start if it's not running
+		//webcam = new WebcamMplayer (videoDevice);
+		//Webcam.Result result = webcam.CapturePrepare (Webcam.CaptureTypes.PHOTO);
+		//constructor for playpreview
+		webcam = new WebcamFfmpeg (Webcam.Action.PLAYPREVIEW, UtilAll.GetOSEnum(), videoDevice, "", "", "");
+		//Webcam.Result result = webcam.PlayPreviewNoBackground ();
+		Webcam.Result result = webcam.PlayPreview ();
 
-		capturer = new CapturerBin();
-		CapturePropertiesStruct s = new CapturePropertiesStruct();
+		if (! result.success)
+		{
+			LogB.Debug ("Webcam Ffmpeg error: ", result.error);
+			new DialogMessage (Constants.MessageTypes.WARNING, result.error);
+			return;
+		}
+	}
+	void on_button_take_photo_do_clicked (object o, EventArgs args)
+	{
+		if(webcam == null)
+			webcam = new WebcamFfmpeg (Webcam.Action.PLAYPREVIEW, UtilAll.GetOSEnum(), videoDevice, "", "", "");
+		else if(webcam != null && webcam.Running)
+		{
+			webcam.ExitCamera();
+		}
 
-		s.DeviceID = devices[0].ID;
+		if(webcam.Snapshot())
+		{
+			File.Copy(Util.GetWebcamPhotoTempFileNamePost(Util.ChangeChars(videoDevice, "/", "_")),
+						Util.GetPhotoPngFileName(false, currentPerson.UniqueID), true); //overwrite
 
-		s.CaptureSourceType = CaptureSourceType.System;
+			string filenameMini = Util.GetPhotoPngFileName(true, currentPerson.UniqueID);
+			bool miniSuccess = UtilMultimedia.LoadAndResizeImage(
+					Util.GetPhotoPngFileName(false, currentPerson.UniqueID),
+					filenameMini, 150, -1); //-1: maintain aspect ratio
+			if(miniSuccess)
+				showMiniPhoto(filenameMini);
+		}
 
-		capturer.CaptureProperties = s;
-		capturer.Type = CapturerType.Snapshot;
-		capturer.Visible=true;
-		capturer.NewSnapshot += on_snapshot_done;
-		capturer.NewSnapshotMini += on_snapshot_mini_done;
-
-		capturerWindow = new Gtk.Window("Capturer");
-		capturerWindow.Add(capturer);
-		capturerWindow.Modal=true;
-		capturerWindow.SetDefaultSize(400,400);
-
-		person_win.Hide();
-
-		capturerWindow.ShowAll();
-		capturerWindow.Present();
-		capturerWindow.DeleteEvent += delegate(object sender, DeleteEventArgs e) {capturer.Close(); capturer.Dispose(); person_win.Show(); };
-		
-		capturer.Run();
 	}
 
 	//libCesarplayer method, jpeg
@@ -1120,8 +1139,10 @@ public class PersonAddModifyWindow
 		if(!adding)
 			File.Copy(tempSmallFileName, Util.GetPhotoFileName(true, currentPerson.UniqueID), true); //overwrite
 		
+		/*
 		capturer.Close();
 		capturer.Dispose();
+		*/
 		capturerWindow.Hide();
 
 		person_win.Show();
@@ -1196,14 +1217,20 @@ public class PersonAddModifyWindow
 	
 	static public PersonAddModifyWindow Show (Gtk.Window parent, 
 			Session mySession, Person currentPerson, int pDN, 
-			Gtk.CheckButton app1_checkbutton_video, bool showCapturePhoto)
+			//Gtk.CheckButton app1_checkbutton_video, bool showCapturePhoto,
+			Gtk.CheckButton app1_checkbutton_video,
+			string videoDevice, bool compujump)
 	{
 		if (PersonAddModifyWindowBox == null) {
-			PersonAddModifyWindowBox = new PersonAddModifyWindow (parent, mySession, currentPerson, showCapturePhoto);
+			//PersonAddModifyWindowBox = new PersonAddModifyWindow (parent, mySession, currentPerson, showCapturePhoto);
+			PersonAddModifyWindowBox = new PersonAddModifyWindow (parent, mySession, currentPerson);
 		}
 
 		PersonAddModifyWindowBox.pDN = pDN;
 		PersonAddModifyWindowBox.app1_checkbutton_video = app1_checkbutton_video;
+		PersonAddModifyWindowBox.videoDevice = videoDevice;
+		//do not allow camera on compujump
+		PersonAddModifyWindowBox.hbox_camera.Visible = ! compujump;
 
 		PersonAddModifyWindowBox.person_win.Show ();
 
@@ -1867,6 +1894,8 @@ public class PersonAddModifyWindow
 			SqlitePersonSession.Update (currentPersonSession); 
 		}
 
+		if(webcam != null && webcam.Running)
+			webcam.ExitCamera();
 
 		PersonAddModifyWindowBox.person_win.Hide();
 		PersonAddModifyWindowBox = null;
@@ -1876,6 +1905,9 @@ public class PersonAddModifyWindow
 	
 	void on_button_cancel_clicked (object o, EventArgs args)
 	{
+		if(webcam != null && webcam.Running)
+			webcam.ExitCamera();
+
 		PersonAddModifyWindowBox.person_win.Hide();
 		PersonAddModifyWindowBox = null;
 	}
@@ -1883,8 +1915,11 @@ public class PersonAddModifyWindow
 	//void on_person_modify_delete_event (object o, EventArgs args)
 	void on_person_win_delete_event (object o, DeleteEventArgs args)
 	{
-			PersonAddModifyWindowBox.person_win.Hide();
-			PersonAddModifyWindowBox = null;
+		if(webcam != null && webcam.Running)
+			webcam.ExitCamera();
+
+		PersonAddModifyWindowBox.person_win.Hide();
+		PersonAddModifyWindowBox = null;
 	}
 	
 	
@@ -1954,7 +1989,9 @@ public class PersonAddMultipleWindow {
 
 	[Widget] Gtk.CheckButton check_headers;
 	[Widget] Gtk.CheckButton check_name_1_column;
-	
+
+	[Widget] Gtk.Label label_column_separator;
+
 	//use this to read/write table
 	ArrayList entries;
 	ArrayList radiosM;
@@ -1973,13 +2010,15 @@ public class PersonAddMultipleWindow {
 
 	private Person currentPerson;
 	Session currentSession;
+	char columnDelimiter;
 	int personsCreatedCount;
 	string errorExistsString;
 	string errorWeightString;
 	string errorRepeatedEntryString;
 
 	
-	PersonAddMultipleWindow (Gtk.Window parent, Session currentSession) {
+	PersonAddMultipleWindow (Gtk.Window parent, Session currentSession, char columnDelimiter)
+	{
 		Glade.XML gladeXML;
 		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "person_multiple_infinite.glade", "person_multiple_infinite", null);
 		gladeXML.Autoconnect(this);
@@ -1989,12 +2028,13 @@ public class PersonAddMultipleWindow {
 	
 		person_multiple_infinite.Parent = parent;
 		this.currentSession = currentSession;
+		this.columnDelimiter = columnDelimiter;
 	}
 	
-	static public PersonAddMultipleWindow Show (Gtk.Window parent, Session currentSession)
+	static public PersonAddMultipleWindow Show (Gtk.Window parent, Session currentSession, char columnDelimiter)
 	{
 		if (PersonAddMultipleWindowBox == null) {
-			PersonAddMultipleWindowBox = new PersonAddMultipleWindow (parent, currentSession);
+			PersonAddMultipleWindowBox = new PersonAddMultipleWindow (parent, currentSession, columnDelimiter);
 		}
 		
 		PersonAddMultipleWindowBox.putNonStandardIcons ();
@@ -2036,6 +2076,11 @@ public class PersonAddMultipleWindow {
 		label_csv.Text = Catalog.GetString("CSV file has headers");
 		label_name.Text = Catalog.GetString("Full name in one column");
 
+		label_column_separator.Text = string.Format(Catalog.GetString(
+					"Expected column separator character is '<b>{0}</b>'"), columnDelimiter) +
+			"\n" + Catalog.GetString("You can change this on Preferences / Language.");
+		label_column_separator.UseMarkup = true;
+
 		//label_csv_help.Text =
 			//"<b>" + Catalog.GetString("Import persons from an spreadsheet. Eg. Excel, LibreOffice, Google Drive.") + "</b>\n\n" +
 			//Catalog.GetString("Open the spreadsheet with the persons data to be added.") + "\n" +
@@ -2130,7 +2175,7 @@ public class PersonAddMultipleWindow {
 			} catch {
 				LogB.Warning("Catched, maybe is used by another program");
 				new DialogMessage(Constants.MessageTypes.WARNING, 
-						Catalog.GetString("Sorry, video cannot be stored.") + "\n\n" +
+						Constants.FileCannotSave + "\n\n" +
 						Catalog.GetString("Maybe this file is opened by an SpreadSheet software like Excel. Please, close that program.")
 						);
 				fc.Destroy();
@@ -2140,6 +2185,7 @@ public class PersonAddMultipleWindow {
 			List<string> columns = new List<string>();
 			using (var reader = new CsvFileReader(fc.Filename))
 			{
+				reader.ChangeDelimiter(columnDelimiter);
 				bool headersActive = check_headers.Active;
 				bool name1Column = check_name_1_column.Active;
 				int row = 0;
