@@ -51,9 +51,7 @@ public class PreferencesWindow
 	[Widget] Gtk.CheckButton check_appearance_maximized_undecorated;
 	[Widget] Gtk.CheckButton check_appearance_person_win_hide;
 	[Widget] Gtk.CheckButton check_appearance_person_photo;
-	[Widget] Gtk.CheckButton check_appearance_encoder_only_bars;
 	[Widget] Gtk.Alignment alignment_undecorated;
-	[Widget] Gtk.Alignment alignment_restart;
 
 	//database tab
 	[Widget] Gtk.Button button_data_folder_open;
@@ -61,8 +59,11 @@ public class PreferencesWindow
 	[Widget] Gtk.CheckButton check_backup_multimedia_and_encoder;
 	
 	[Widget] Gtk.Button button_db_backup;
-	[Widget] Gtk.Box hbox_backup_doing;
-	[Widget] Gtk.ProgressBar pulsebar;
+	[Widget] Gtk.HBox hbox_backup_doing;
+	[Widget] Gtk.Label label_backup;
+	[Widget] Gtk.ProgressBar pulsebarBackupActivity;
+	[Widget] Gtk.ProgressBar pulsebarBackupDirs;
+	[Widget] Gtk.ProgressBar pulsebarBackupSecondDirs;
 
 	
 	//jumps tab	
@@ -99,6 +100,8 @@ public class PreferencesWindow
 	
 	//encoder capture tab
 	[Widget] Gtk.SpinButton spin_encoder_capture_time;
+	[Widget] Gtk.CheckButton check_encoder_capture_inactivity_end_time;
+	[Widget] Gtk.HBox hbox_encoder_capture_inactivity_time;
 	[Widget] Gtk.SpinButton spin_encoder_capture_inactivity_end_time;
 	[Widget] Gtk.Image image_encoder_gravitatory;
 	[Widget] Gtk.Image image_encoder_inertial;
@@ -107,11 +110,19 @@ public class PreferencesWindow
 	[Widget] Gtk.VBox vbox_encoder_inertial; //change Visible param to not have a vertical big first page with only one row of info
 	[Widget] Gtk.SpinButton spin_encoder_capture_min_height_gravitatory;
 	[Widget] Gtk.SpinButton spin_encoder_capture_min_height_inertial;
+	[Widget] Gtk.CheckButton checkbutton_encoder_capture_inertial_discard_first_n;
+	[Widget] Gtk.HBox hbox_encoder_capture_inertial_discard_first_n;
+	[Widget] Gtk.SpinButton spin_encoder_capture_inertial_discard_first_n;
+	[Widget] Gtk.CheckButton check_appearance_encoder_only_bars;
+	[Widget] Gtk.HBox hbox_restart;
+	[Widget] Gtk.SpinButton spin_encoder_capture_show_only_some_bars;
+	[Widget] Gtk.RadioButton radio_encoder_capture_show_all_bars;
+	[Widget] Gtk.RadioButton radio_encoder_capture_show_only_some_bars;
+	[Widget] Gtk.SpinButton spin_encoder_capture_barplot_font_size;
 	[Widget] Gtk.RadioButton radio_encoder_auto_save_curve_best;
 	[Widget] Gtk.RadioButton radio_encoder_auto_save_curve_4top;
 	[Widget] Gtk.RadioButton radio_encoder_auto_save_curve_all;
 	[Widget] Gtk.RadioButton radio_encoder_auto_save_curve_none;
-	[Widget] Gtk.SpinButton spin_encoder_capture_barplot_font_size;
 	[Widget] Gtk.CheckButton check_show_start_and_duration;
 	[Widget] Gtk.RadioButton radio_encoder_triggers_no;
 	[Widget] Gtk.RadioButton radio_encoder_triggers_yes;
@@ -120,7 +131,7 @@ public class PreferencesWindow
 	[Widget] Gtk.RadioButton radio_encoder_triggers_yes_start_at_first_trigger;
 	[Widget] Gtk.Image image_encoder_inactivity_help;
 	[Widget] Gtk.Image image_encoder_capture_cut_by_triggers_help;
-	
+
 	//encoder other tab
 	[Widget] Gtk.CheckButton checkbutton_encoder_propulsive;
 	[Widget] Gtk.SpinButton spin_encoder_smooth_con;
@@ -138,8 +149,46 @@ public class PreferencesWindow
 	[Widget] Gtk.RadioButton radio_sound_systemsounds;
 	[Widget] Gtk.HBox hbox_not_recommended_when_not_on_windows;
 	[Widget] Gtk.Label label_test_sound_result;
+	[Widget] Gtk.Notebook notebook_multimedia;
 	[Widget] Gtk.Box hbox_combo_camera;
 	[Widget] Gtk.ComboBox combo_camera;
+	[Widget] Gtk.HBox hbox_camera_resolution_framerate;
+	[Widget] Gtk.HBox hbox_camera_resolution_custom;
+	[Widget] Gtk.SpinButton spin_camera_resolution_custom_width;
+	[Widget] Gtk.SpinButton spin_camera_resolution_custom_height;
+	[Widget] Gtk.HBox hbox_camera_framerate_custom;
+	[Widget] Gtk.SpinButton spin_camera_framerate_custom;
+	[Widget] Gtk.Entry entry_camera_framerate_custom_decimals;
+	[Widget] Gtk.Label label_camera_pixel_format;
+	[Widget] Gtk.Label label_camera_pixel_format_current;
+	[Widget] Gtk.Label label_camera_resolution_current;
+	[Widget] Gtk.Label label_camera_framerate_current;
+	[Widget] Gtk.HBox hbox_combo_camera_pixel_format;
+	[Widget] Gtk.ComboBox combo_camera_pixel_format;
+	[Widget] Gtk.Box hbox_combo_camera_resolution;
+	[Widget] Gtk.ComboBox combo_camera_resolution;
+	[Widget] Gtk.Box hbox_combo_camera_framerate;
+	[Widget] Gtk.ComboBox combo_camera_framerate;
+	[Widget] Gtk.Label label_camera_error;
+	[Widget] Gtk.Label label_webcam_windows;
+	[Widget] Gtk.Image image_multimedia_audio;
+	[Widget] Gtk.Image image_multimedia_video;
+	[Widget] Gtk.Image image_video_preview;
+	[Widget] Gtk.Button button_video_preview;
+	[Widget] Gtk.Label label_video_preview_error;
+	[Widget] Gtk.CheckButton check_camera_stop_after;
+	[Widget] Gtk.CheckButton check_camera_advanced;
+	[Widget] Gtk.Frame frame_camera_advanced;
+	[Widget] Gtk.VBox vbox_camera_stop_after_all;
+	//[Widget] Gtk.VBox vbox_camera_stop_after;
+	[Widget] Gtk.HBox hbox_camera_stop_after_seconds;
+	[Widget] Gtk.SpinButton spin_camera_stop_after;
+	[Widget] Gtk.Table table_video_advanced_actions;
+	[Widget] Gtk.Label label_video_check_ffmpeg_running;
+	[Widget] Gtk.Label label_video_check_ffplay_running;
+	[Widget] Gtk.Button button_video_ffmpeg_kill;
+	[Widget] Gtk.Button button_video_ffplay_kill;
+	[Widget] Gtk.Label label_camera_check_running;
 
 	//language tab
 	[Widget] Gtk.Box hbox_combo_language;
@@ -161,6 +210,8 @@ public class PreferencesWindow
 	[Widget] Gtk.ToggleButton toggle_never_close;
 	[Widget] Gtk.VBox vbox_version;
 	[Widget] Gtk.Label label_progVersion;
+	[Widget] Gtk.Frame frame_networks;
+	[Widget] Gtk.CheckButton check_networks_devices;
 
 
 	[Widget] Gtk.Button button_accept;
@@ -169,7 +220,8 @@ public class PreferencesWindow
 	public Gtk.Button FakeButtonDebugModeStart;
 	
 	static PreferencesWindow PreferencesWindowBox;
-	
+
+	private UtilAll.OperatingSystems operatingSystem;
 	private Preferences preferences; //stored to update SQL if anything changed
 	private Thread thread;
 
@@ -183,6 +235,9 @@ public class PreferencesWindow
 	const int ENCODERCAPTUREPAGE = 4;
 	const int ENCODEROTHERPAGE = 5;
 
+	static private WebcamDeviceList wd_list;
+	private WebcamFfmpegSupportedModes wfsm;
+
 
 	PreferencesWindow () {
 		Glade.XML gladeXML;
@@ -200,13 +255,16 @@ public class PreferencesWindow
 		FakeButtonDebugModeStart = new Gtk.Button();
 	}
 
-	static public PreferencesWindow Show (Preferences preferences,
+	static public PreferencesWindow Show (
+			Preferences preferences,
 			Constants.Menuitem_modes menu_mode, bool compujump, string progVersion)
 	{
 		if (PreferencesWindowBox == null) {
 			PreferencesWindowBox = new PreferencesWindow ();
 		}
 
+		PreferencesWindowBox.operatingSystem = UtilAll.GetOSEnum();
+
 		if(compujump)
 		{
 			PreferencesWindowBox.check_appearance_person_win_hide.Sensitive = false;
@@ -215,7 +273,9 @@ public class PreferencesWindow
 			PreferencesWindowBox.vbox_version.Visible = true;
 			PreferencesWindowBox.label_progVersion.Text = "<b>" + progVersion + "</b>";
 			PreferencesWindowBox.label_progVersion.UseMarkup = true;
+			PreferencesWindowBox.check_networks_devices.Active = preferences.networksAllowChangeDevices;
 		}
+		PreferencesWindowBox.frame_networks.Visible = compujump;
 
 		if(menu_mode !=	Constants.Menuitem_modes.JUMPSSIMPLE && menu_mode != Constants.Menuitem_modes.JUMPSREACTIVE)
 			PreferencesWindowBox.notebook.GetNthPage(JUMPSPAGE).Hide();
@@ -229,6 +289,7 @@ public class PreferencesWindow
 		PreferencesWindowBox.preferences = preferences;
 
 		PreferencesWindowBox.createComboLanguage();
+		Pixbuf pixbuf;
 
 		//appearence tab
 		if(preferences.maximized == Preferences.MaximizedTypes.NO)
@@ -255,18 +316,21 @@ public class PreferencesWindow
 		else
 			PreferencesWindowBox.check_appearance_person_photo.Active = false;
 
-		if(preferences.encoderCaptureShowOnlyBars)
-			PreferencesWindowBox.check_appearance_encoder_only_bars.Active = true;
-		else
-			PreferencesWindowBox.check_appearance_encoder_only_bars.Active = false;
-
-
 		//multimedia tab
 		if(preferences.volumeOn)  
 			PreferencesWindowBox.checkbutton_volume.Active = true; 
 		else 
 			PreferencesWindowBox.checkbutton_volume.Active = false; 
 
+		//hide video for compujump
+		if(compujump)
+			PreferencesWindowBox.notebook_multimedia.GetNthPage(1).Hide();
+
+		PreferencesWindowBox.label_camera_error.Visible = false;
+
+		if(UtilAll.IsWindows())
+			PreferencesWindowBox.label_webcam_windows.Visible = true;
+
 		if(UtilAll.IsWindows())
 		{
 			PreferencesWindowBox.table_gstreamer.Visible = false;
@@ -284,8 +348,21 @@ public class PreferencesWindow
 			PreferencesWindowBox.radio_sound_systemsounds.Active = true;
 		PreferencesWindowBox.label_test_sound_result.Text = "";
 
-		PreferencesWindowBox.createComboCamera(UtilMultimedia.GetVideoDevices(), preferences.videoDeviceNum);
-	
+		wd_list = UtilMultimedia.GetVideoDevices();
+		PreferencesWindowBox.createComboCamera(preferences.videoDevice,
+				preferences.videoDevicePixelFormat, preferences.videoDeviceResolution, preferences.videoDeviceFramerate);
+
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "audio.png");
+		PreferencesWindowBox.image_multimedia_audio.Pixbuf = pixbuf;
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "videocamera_on.png");
+		PreferencesWindowBox.image_multimedia_video.Pixbuf = pixbuf;
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_photo_preview.png");
+		PreferencesWindowBox.image_video_preview.Pixbuf = pixbuf;
+
+		PreferencesWindowBox.spin_camera_stop_after.Value = preferences.videoStopAfter;
+		//PreferencesWindowBox.vbox_camera_stop_after.Visible = (preferences.videoStopAfter > 0);
+		PreferencesWindowBox.hbox_camera_stop_after_seconds.Visible = (preferences.videoStopAfter > 0);
+		PreferencesWindowBox.check_camera_stop_after.Active = (preferences.videoStopAfter > 0);
 
 		string [] decs = {"1", "2", "3"};
 		PreferencesWindowBox.combo_decimals.Active = UtilGtk.ComboMakeActive(
@@ -363,7 +440,6 @@ public class PreferencesWindow
 
 		//start of double contacts stuff ----
 
-		Pixbuf pixbuf;
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_run_simple.png");
 		PreferencesWindowBox.image_races_simple.Pixbuf = pixbuf;
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_run_multiple.png");
@@ -399,8 +475,19 @@ public class PreferencesWindow
 
 	
 		//encoder capture -->
+
 		PreferencesWindowBox.spin_encoder_capture_time.Value = preferences.encoderCaptureTime;
-		PreferencesWindowBox.spin_encoder_capture_inactivity_end_time.Value = preferences.encoderCaptureInactivityEndTime;
+
+		if(preferences.encoderCaptureInactivityEndTime < 0) {
+			PreferencesWindowBox.check_encoder_capture_inactivity_end_time.Active = false;
+			PreferencesWindowBox.hbox_encoder_capture_inactivity_time.Sensitive = false;
+			PreferencesWindowBox.spin_encoder_capture_inactivity_end_time.Value = 3;
+		} else {
+			PreferencesWindowBox.check_encoder_capture_inactivity_end_time.Active = true;
+			PreferencesWindowBox.hbox_encoder_capture_inactivity_time.Sensitive = true;
+			PreferencesWindowBox.spin_encoder_capture_inactivity_end_time.Value = preferences.encoderCaptureInactivityEndTime;
+		}
+
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_gravity.png");
 		PreferencesWindowBox.image_encoder_gravitatory.Pixbuf = pixbuf;
@@ -422,7 +509,31 @@ public class PreferencesWindow
 
 		PreferencesWindowBox.spin_encoder_capture_min_height_gravitatory.Value = preferences.encoderCaptureMinHeightGravitatory;
 		PreferencesWindowBox.spin_encoder_capture_min_height_inertial.Value = preferences.encoderCaptureMinHeightInertial;
-		
+
+		if(preferences.encoderCaptureInertialDiscardFirstN > 0) {
+			PreferencesWindowBox.checkbutton_encoder_capture_inertial_discard_first_n.Active = true;
+			PreferencesWindowBox.spin_encoder_capture_inertial_discard_first_n.Value = preferences.encoderCaptureInertialDiscardFirstN;
+			PreferencesWindowBox.hbox_encoder_capture_inertial_discard_first_n.Visible = true;
+		} else {
+			PreferencesWindowBox.checkbutton_encoder_capture_inertial_discard_first_n.Active = false;
+			PreferencesWindowBox.spin_encoder_capture_inertial_discard_first_n.Value = 3;
+			PreferencesWindowBox.hbox_encoder_capture_inertial_discard_first_n.Visible = false;
+		}
+
+		if(preferences.encoderCaptureShowOnlyBars)
+			PreferencesWindowBox.check_appearance_encoder_only_bars.Active = true;
+		else
+			PreferencesWindowBox.check_appearance_encoder_only_bars.Active = false;
+
+		if(preferences.encoderCaptureShowNRepetitions < 0) {
+			PreferencesWindowBox.radio_encoder_capture_show_all_bars.Active = true;
+			PreferencesWindowBox.spin_encoder_capture_show_only_some_bars.Value = 10;
+		} else {
+			PreferencesWindowBox.radio_encoder_capture_show_only_some_bars.Active = true;
+			PreferencesWindowBox.spin_encoder_capture_show_only_some_bars.Value = preferences.encoderCaptureShowNRepetitions;
+		}
+
+
 		if(preferences.encoderAutoSaveCurve == Constants.EncoderAutoSaveCurve.BEST)
 			PreferencesWindowBox.radio_encoder_auto_save_curve_best.Active = true;
 		else if(preferences.encoderAutoSaveCurve == Constants.EncoderAutoSaveCurve.FROM4TOPENULTIMATE)
@@ -487,6 +598,20 @@ public class PreferencesWindow
 		return PreferencesWindowBox;
 	}
 
+	private void on_radio_encoder_capture_show_all_bars_toggled (object o, EventArgs args)
+	{
+		spin_encoder_capture_show_only_some_bars.Sensitive = false;
+	}
+	private void on_radio_encoder_capture_show_only_some_bars_toggled (object o, EventArgs args)
+	{
+		spin_encoder_capture_show_only_some_bars.Sensitive = true;
+	}
+
+	private void on_check_encoder_capture_inactivity_end_time_clicked (object o, EventArgs args)
+	{
+		hbox_encoder_capture_inactivity_time.Sensitive = check_encoder_capture_inactivity_end_time.Active;
+	}
+
 	//private void on_notebook_encoder_capture_gi_change_current_page (object o, Gtk.ChangeCurrentPageArgs args)
 	private void on_notebook_encoder_capture_gi_switch_page (object o, Gtk.SwitchPageArgs args)
 	{
@@ -538,24 +663,207 @@ public class PreferencesWindow
 	 * end of triggers stuff
 	 */
 
-	private void createComboCamera(string [] devices, int current) {
+	private void createComboCamera(string current, string pixelFormat, string resolution, string framerate)
+	{
+		// 1) videoDevice
+
 		combo_camera = ComboBox.NewText ();
 
-		if(devices.Length == 0) {
-			devices = Util.StringToStringArray(Constants.CameraNotFound);
-			current = 0;
+		/*
+		 * declare both because there is a return just here and if they are undeclred the method:
+		 * on_button_accept_clicked () will fail
+		 */
+		combo_camera_pixel_format = ComboBox.NewText ();
+		combo_camera_resolution = ComboBox.NewText ();
+		combo_camera_framerate = ComboBox.NewText ();
+
+		if(wd_list.Count() == 0) {
+			//devices = Util.StringToStringArray(Constants.CameraNotFound);
+			label_camera_error.Text = wd_list.Error;
+			label_camera_error.Visible = true;
+			current = "";
+
+			hbox_camera_resolution_framerate.Visible = false;
+			check_camera_advanced.Visible = false;
+
+			return;
 		}
-		
-		UtilGtk.ComboUpdate(combo_camera, devices, "");
+
+		//UtilGtk.ComboUpdate(combo_camera, wd_list.GetCodes());
+		UtilGtk.ComboUpdate(combo_camera, wd_list.GetFullnames());
 		hbox_combo_camera.PackStart(combo_camera, true, true, 0);
 		hbox_combo_camera.ShowAll();
 
-		if(current >= devices.Length)
-			current = 0;
+		//if(current >= devices.Count)
+		//	current = 0;
 		
-		combo_camera.Active = UtilGtk.ComboMakeActive(devices, devices[current]);
+		combo_camera.Active = UtilGtk.ComboMakeActive(combo_camera, current);
+
+		// 2) pixel_format
+
+		List<string> pixelFormats = new List<string>();
+		if(pixelFormat != "")
+		{
+			pixelFormats.Add(pixelFormat);
+			UtilGtk.ComboUpdate(combo_camera_pixel_format, pixelFormats);
+			combo_camera_pixel_format.Active = 0;
+
+			label_camera_pixel_format_current.Text = pixelFormat;
+			label_camera_pixel_format_current.Visible = true;
+			button_video_preview.Sensitive = true;
+		}
+
+		hbox_combo_camera_pixel_format.PackStart(combo_camera_pixel_format, true, true, 0);
+		//not shown because label is shown
+		//hbox_combo_camera_pixel_format.ShowAll();
+		//hbox_combo_camera_pixel_format.Sensitive = false;
+		combo_camera_pixel_format.Changed += new EventHandler (on_combo_camera_pixel_format_changed);
+
+		// 3) resolution
+
+		List<string> resolutions = new List<string>();
+		/*
+		 * do not have this default values, just write the option on sqlite (if any)
+		 *
+		resolutions.Add("320x240");
+		resolutions.Add("640x480");
+		resolutions.Add("1280x720");
+		resolutions.Add(Catalog.GetString("Custom")); //in SQL will be stored the values not "Custom" text
+		UtilGtk.ComboUpdate(combo_camera_resolution, resolutions);
+
+		if(resolution == "") //(first time using this) give a value
+			resolution = "640x480";
+
+
+		bool found = false;
+		foreach(string str in resolutions)
+			if(str == resolution)
+				found = true;
+
+		if(found)
+			combo_camera_resolution.Active = UtilGtk.ComboMakeActive(combo_camera_resolution, resolution);
+		else {
+			combo_camera_resolution.Active = UtilGtk.ComboMakeActive(combo_camera_resolution, Catalog.GetString("Custom"));
+			string [] strFull = resolution.Split('x');
+			if(strFull.Length == 2) {
+				spin_camera_resolution_custom_width.Value = Convert.ToInt32(strFull[0]);
+				spin_camera_resolution_custom_height.Value = Convert.ToInt32(strFull[1]);
+			}
+			hbox_camera_resolution_custom.Visible = true;
+		}
+		*/
+		if(resolution != "")
+		{
+			resolutions.Add(resolution);
+			UtilGtk.ComboUpdate(combo_camera_resolution, resolutions);
+			combo_camera_resolution.Active = 0;
+
+			label_camera_resolution_current.Text = resolution;
+			label_camera_resolution_current.Visible = true;
+		}
+
+		hbox_combo_camera_resolution.PackStart(combo_camera_resolution, true, true, 0);
+		//not shown because label is shown
+		//hbox_combo_camera_resolution.ShowAll();
+		//hbox_combo_camera_resolution.Sensitive = false;
+		combo_camera_resolution.Changed += new EventHandler (on_combo_camera_resolution_changed);
+
+		// 4) framerate
+
+		combo_camera_framerate = ComboBox.NewText ();
+		List<string> framerates = new List<string>();
+		/*
+		 * do not have this default values, just write the option on sqlite (if any)
+		 *
+		framerates.Add("30");
+		framerates.Add("60");
+		framerates.Add(Catalog.GetString("Custom")); //in SQL will be stored the values not "Custom" text
+		UtilGtk.ComboUpdate(combo_camera_framerate, framerates);
+
+		if(framerate == "") //(first time using this) give a value
+			framerate = "30";
+
+		found = false;
+		foreach(string str in framerates)
+			if(str == framerate)
+				found = true;
+
+		if(found)
+			combo_camera_framerate.Active = UtilGtk.ComboMakeActive(combo_camera_framerate, framerate);
+		else {
+			combo_camera_framerate.Active = UtilGtk.ComboMakeActive(combo_camera_framerate, Catalog.GetString("Custom"));
+			string [] strFull = framerate.Split(new char[] {'.'});
+
+			if(strFull.Length == 1)
+			{
+				spin_camera_framerate_custom.Value = Convert.ToInt32(framerate);
+			}
+			else if(strFull.Length == 2)
+			{
+				spin_camera_framerate_custom.Value = Convert.ToInt32(strFull[0]);
+				entry_camera_framerate_custom_decimals.Text = strFull[1];
+			}
+			hbox_camera_framerate_custom.Visible = true;
+		}
+		*/
+		if(framerate != "")
+		{
+			framerates.Add(framerate);
+			UtilGtk.ComboUpdate(combo_camera_framerate, framerates);
+			combo_camera_framerate.Active = 0;
+
+			label_camera_framerate_current.Text = framerate;
+			label_camera_framerate_current.Visible = true;
+		}
+
+		hbox_combo_camera_framerate.PackStart(combo_camera_framerate, true, true, 0);
+		//not shown because label is shown
+		//hbox_combo_camera_framerate.ShowAll();
+		//hbox_combo_camera_framerate.Sensitive = false;
+		combo_camera_framerate.Changed += new EventHandler (on_combo_camera_framerate_changed);
 	}
-		
+
+	private void on_check_camera_stop_after_toggled (object o, EventArgs args)
+	{
+		//vbox_camera_stop_after.Visible = check_camera_stop_after.Active;
+		hbox_camera_stop_after_seconds.Visible = check_camera_stop_after.Active;
+	}
+
+	private void on_combo_camera_pixel_format_changed (object o, EventArgs args)
+	{
+		string pixelFormat = UtilGtk.ComboGetActive(combo_camera_pixel_format);
+
+		if(pixelFormat != "" && wfsm != null)
+		{
+			string currentResolution = getSelectedResolution();
+			UtilGtk.ComboUpdate(combo_camera_resolution, wfsm.PopulateListByPixelFormat(pixelFormat));
+			combo_camera_resolution.Active = UtilGtk.ComboMakeActive(combo_camera_resolution, currentResolution);
+			button_video_preview.Sensitive = true;
+		}
+	}
+	private void on_combo_camera_resolution_changed (object o, EventArgs args)
+	{
+		string pixelFormat = UtilGtk.ComboGetActive(combo_camera_pixel_format);
+		string resolution = UtilGtk.ComboGetActive(combo_camera_resolution);
+		hbox_camera_resolution_custom.Visible = resolution == Catalog.GetString("Custom");
+
+		if(resolution != "" && resolution != Catalog.GetString("Custom") && wfsm != null)
+		{
+			string currentFramerate = getSelectedFramerate();
+			UtilGtk.ComboUpdate(combo_camera_framerate, wfsm.GetFramerates (pixelFormat, resolution));
+			combo_camera_framerate.Active = UtilGtk.ComboMakeActive(combo_camera_framerate, currentFramerate);
+		}
+	}
+	private void on_combo_camera_framerate_changed (object o, EventArgs args)
+	{
+		hbox_camera_framerate_custom.Visible = UtilGtk.ComboGetActive(combo_camera_framerate) == Catalog.GetString("Custom");
+	}
+
+	private void on_check_camera_advanced_toggled (object o, EventArgs args)
+	{
+		frame_camera_advanced.Visible = check_camera_advanced.Active;
+	}
+
 	private void on_check_appearance_maximized_toggled (object obj, EventArgs args)
 	{
 		alignment_undecorated.Visible = check_appearance_maximized.Active;
@@ -568,7 +876,12 @@ public class PreferencesWindow
 
 	private void on_check_appearance_encoder_only_bars_toggled (object obj, EventArgs args) 
 	{
-		alignment_restart.Visible = ! check_appearance_encoder_only_bars.Active;
+		hbox_restart.Visible = ! check_appearance_encoder_only_bars.Active;
+	}
+
+	private void on_checkbutton_encoder_capture_inertial_discard_first_n_toggled (object obj, EventArgs args)
+	{
+		hbox_encoder_capture_inertial_discard_first_n.Visible = (checkbutton_encoder_capture_inertial_discard_first_n.Active);
 	}
 
 
@@ -596,6 +909,169 @@ public class PreferencesWindow
 		Util.TestSound = false;
 	}
 
+	//for mac and maybe windows, because in Linux it founds a default mode and it works
+	private void on_button_video_get_supported_modes_clicked (object o, EventArgs args)
+	{
+		string cameraCode = wd_list.GetCodeOfFullname(UtilGtk.ComboGetActive(combo_camera));
+		if(cameraCode == "")
+			return;
+
+		if(operatingSystem == UtilAll.OperatingSystems.LINUX)
+			wfsm = new WebcamFfmpegSupportedModesLinux();
+		else if(operatingSystem == UtilAll.OperatingSystems.WINDOWS)
+			wfsm = new WebcamFfmpegSupportedModesWindows(cameraCode);
+		else
+			wfsm = new WebcamFfmpegSupportedModesMac(cameraCode);
+
+		wfsm.GetModes();
+
+		if(wfsm.ErrorStr != "")
+		{
+			/*
+			new DialogMessage("Chronojump - Modes of this webcam",
+					Constants.MessageTypes.WARNING, wfsm.ErrorStr);
+			*/
+			label_camera_error.Text = wfsm.ErrorStr;
+			label_camera_error.Visible = true;
+
+			return;
+		}
+
+		/*
+		//display the result (if any)
+		if(wfsm.ModesStr != "")
+			new DialogMessage("Chronojump - Modes of this webcam",
+					Constants.MessageTypes.INFO, wfsm.ModesStr, true); //showScrolledWinBar
+		*/
+
+		bool fillCombos = true;
+		if(fillCombos)
+		{
+			string currentPixelFormat = getSelectedPixelFormat();
+			UtilGtk.ComboUpdate(combo_camera_pixel_format, wfsm.GetPixelFormats());
+			combo_camera_pixel_format.Active = UtilGtk.ComboMakeActive(combo_camera_pixel_format, currentPixelFormat);
+
+			/*
+			//not shown because label is shown
+			hbox_combo_camera_pixel_format.Sensitive = true;
+			hbox_combo_camera_resolution.Sensitive = true;
+			hbox_combo_camera_framerate.Sensitive = true;
+			*/
+			label_camera_pixel_format_current.Visible = false;
+			label_camera_resolution_current.Visible = false;
+			label_camera_framerate_current.Visible = false;
+
+			hbox_combo_camera_pixel_format.ShowAll();
+			hbox_combo_camera_resolution.ShowAll();
+			hbox_combo_camera_framerate.ShowAll();
+		}
+	}
+
+	private void on_button_video_preview_clicked (object o, EventArgs args)
+	{
+		label_video_preview_error.Visible = false;
+
+		//this allows us to update the previous label, if not we have to end camera play
+		GLib.Timeout.Add(100, new GLib.TimeoutHandler(button_video_preview_do));
+	}
+	private bool button_video_preview_do ()
+	{
+		string cameraCode = wd_list.GetCodeOfFullname(UtilGtk.ComboGetActive(combo_camera));
+		if(cameraCode == "")
+			return false; //do not call again
+
+		Webcam webcamPlay = new WebcamFfmpeg (Webcam.Action.PLAYPREVIEW, UtilAll.GetOSEnum(), cameraCode,
+				getSelectedPixelFormat(), getSelectedResolution(), getSelectedFramerate());
+
+		Webcam.Result result = webcamPlay.PlayPreviewNoBackground ();
+		if(! result.success) {
+			label_video_preview_error.Text = result.error;
+			label_video_preview_error.Visible = true;
+		}
+
+		return false; //do not call again
+	}
+
+	private string getSelectedPixelFormat()
+	{
+		string selected = UtilGtk.ComboGetActive(combo_camera_pixel_format);
+		return selected;
+	}
+	private string getSelectedResolution()
+	{
+		string selected = UtilGtk.ComboGetActive(combo_camera_resolution);
+		if(selected == Catalog.GetString("Custom"))
+			selected = string.Format("{0}x{1}", spin_camera_resolution_custom_width.Value, spin_camera_resolution_custom_height.Value);
+
+		return selected;
+	}
+	private string getSelectedFramerate()
+	{
+		string selected = UtilGtk.ComboGetActive(combo_camera_framerate);
+		if(selected == Catalog.GetString("Custom"))
+		{
+			string decStr = entry_camera_framerate_custom_decimals.Text;
+			if(decStr != "0" && Util.IsNumber(decStr, false))
+				selected = string.Format("{0}.{1}", spin_camera_framerate_custom.Value, decStr); //decimal in ffmpeg has to be '.'
+			else
+				selected = string.Format("{0}", spin_camera_framerate_custom.Value);
+		}
+
+		LogB.Information("selected framerate: " + selected);
+		return selected;
+	}
+
+	private void on_button_video_check_ffmpeg_ffplay_running_clicked(object o, EventArgs args)
+	{
+		label_video_check_ffmpeg_running.Text = "Not running";
+		label_video_check_ffplay_running.Text = "Not running";
+		button_video_ffmpeg_kill.Visible = false;
+		button_video_ffplay_kill.Visible = false;
+		label_camera_check_running.Text = "";
+
+		bool runningFfmpeg = false;
+		bool runningFfplay = false;
+
+		if(ExecuteProcess.IsRunning3 (-1, WebcamFfmpeg.GetExecutableCapture(operatingSystem)))
+		{
+			runningFfmpeg = true;
+			label_video_check_ffmpeg_running.Text = "Running";
+			button_video_ffmpeg_kill.Visible = true;
+		}
+
+		if(ExecuteProcess.IsRunning3 (-1, WebcamFfmpeg.GetExecutablePlay(operatingSystem)))
+		{
+			runningFfplay = true;
+			label_video_check_ffplay_running.Text = "Running";
+			button_video_ffplay_kill.Visible = true;
+		}
+
+		table_video_advanced_actions.Visible = true;
+	}
+
+	private void on_button_video_ffmpeg_kill_clicked (object o, EventArgs args)
+	{
+		if(ExecuteProcess.KillExternalProcess (WebcamFfmpeg.GetExecutableCapture(operatingSystem)))
+		{
+			label_camera_check_running.Text = "Killed camera process";
+			label_video_check_ffmpeg_running.Text = "Not running";
+			button_video_ffmpeg_kill.Visible = false;
+		}
+		else
+			label_camera_check_running.Text = "Cannot kill camera process";
+	}
+	private void on_button_video_ffplay_kill_clicked (object o, EventArgs args)
+	{
+		if(ExecuteProcess.KillExternalProcess (WebcamFfmpeg.GetExecutablePlay(operatingSystem)))
+		{
+			label_camera_check_running.Text = "Killed play process";
+			label_video_check_ffplay_running.Text = "Not running";
+			button_video_ffplay_kill.Visible = false;
+		}
+		else
+			label_camera_check_running.Text = "Cannot kill play process";
+	}
+
 	// ---- end of multimedia stuff
 
 	// ---- Language stuff
@@ -851,6 +1327,7 @@ public class PreferencesWindow
 					//if multimedia_and_encoder, then copy the folder. If not checked, then copy only the db file
 					if(check_backup_multimedia_and_encoder.Active)
 					{
+						uc = new UtilCopy();
 						thread = new Thread(new ThreadStart(copyRecursive));
 						GLib.Idle.Add (new GLib.IdleHandler (PulseGTK));
 		
@@ -862,7 +1339,7 @@ public class PreferencesWindow
 						File.Copy(fileDB, fileCopy);
 					
 						string myString = string.Format(Catalog.GetString("Copied to {0}"), fileCopy);
-						new DialogMessage(Constants.MessageTypes.INFO, myString);
+						label_backup.Text = myString;
 					}
 				}
 			} 
@@ -924,6 +1401,7 @@ public class PreferencesWindow
 			//if multimedia_and_encoder, then copy the folder. If not checked, then copy only the db file
 			if(check_backup_multimedia_and_encoder.Active) {
 				Directory.Delete(fileCopy, true);
+				uc = new UtilCopy();
 				thread = new Thread(new ThreadStart(copyRecursive));
 				GLib.Idle.Add (new GLib.IdleHandler (PulseGTK));
 		
@@ -937,7 +1415,7 @@ public class PreferencesWindow
 						
 				fc.Hide ();
 				string myString = string.Format(Catalog.GetString("Copied to {0}"), fileCopy);
-				new DialogMessage(Constants.MessageTypes.INFO, myString);
+				label_backup.Text = myString;
 			}
 		} catch {
 			string myString = string.Format(Catalog.GetString("Cannot copy to {0} "), fileCopy);
@@ -948,8 +1426,20 @@ public class PreferencesWindow
 	/*
 	 * deprecated since 1.6.0. Use backup method below
 	*/
-	private void copyRecursive() {
-		Util.CopyFilesRecursively(new DirectoryInfo(Util.GetParentDir(false)), new DirectoryInfo(fileCopy));
+	static long copyRecursiveElapsedMs;
+	static int backupMainDirsDone;
+	static UtilCopy uc;
+	private void copyRecursive()
+	{
+		copyRecursiveElapsedMs = 0;
+		Stopwatch sw = new Stopwatch();
+		sw.Start();
+
+		//Util.CopyFilesRecursively(new DirectoryInfo(Util.GetParentDir(false)), new DirectoryInfo(fileCopy), out backupMainDirsDone);
+		uc.CopyFilesRecursively(new DirectoryInfo(Util.GetParentDir(false)), new DirectoryInfo(fileCopy), 0);
+		sw.Stop();
+
+		copyRecursiveElapsedMs = sw.ElapsedMilliseconds;
 	}
 
 	/*
@@ -1098,24 +1588,36 @@ public class PreferencesWindow
 			return false;
 		}
 	
-		pulsebar.Pulse();
-		Thread.Sleep (50);
+		pulsebarBackupActivity.Pulse();
+		pulsebarBackupDirs.Fraction = Util.DivideSafeFraction(uc.BackupMainDirsCount, 6); //6 for: database, encoder, forceSensor, logs, multimedia, raceAnalyzer
+		pulsebarBackupDirs.Text = uc.LastMainDir;
+		pulsebarBackupSecondDirs.Fraction = Util.DivideSafeFraction(uc.BackupSecondDirsCount, uc.BackupSecondDirsLength);
+		pulsebarBackupSecondDirs.Text = uc.LastSecondDir;
+
+		Thread.Sleep (30);
 		//LogB.Debug(thread.ThreadState.ToString());
 		return true;
 	}
 
-	private void endPulse() {
-		pulsebar.Fraction = 1;
+	private void endPulse()
+	{
+		pulsebarBackupActivity.Fraction = 1;
+		pulsebarBackupDirs.Fraction = 1;
+		pulsebarBackupSecondDirs.Fraction = 1;
 		backup_doing_sensitive_start_end(false);
 		fc.Hide ();
-		string myString = string.Format(Catalog.GetString("Copied to {0}"), fileCopy);
-		new DialogMessage(Constants.MessageTypes.INFO, myString);
+		string myString = string.Format(Catalog.GetString("Copied to {0} in {1} ms"), fileCopy, copyRecursiveElapsedMs);
+		label_backup.Text = myString;
 	}
 	
 	private void backup_doing_sensitive_start_end(bool start) 
 	{
+		if(start)
+			label_backup.Text = Catalog.GetString("Please, wait.");
+
+		pulsebarBackupActivity.Visible = start;
 		hbox_backup_doing.Visible = start;
-	
+
 		button_db_backup.Sensitive = ! start;
 		button_data_folder_open.Sensitive = ! start;
 		
@@ -1145,10 +1647,6 @@ public class PreferencesWindow
 			SqlitePreferences.Update("personPhoto", PreferencesWindowBox.check_appearance_person_photo.Active.ToString(), true);
 			preferences.personPhoto = PreferencesWindowBox.check_appearance_person_photo.Active;
 		}
-		if( preferences.encoderCaptureShowOnlyBars != PreferencesWindowBox.check_appearance_encoder_only_bars.Active ) {
-			SqlitePreferences.Update("encoderCaptureShowOnlyBars", PreferencesWindowBox.check_appearance_encoder_only_bars.Active.ToString(), true);
-			preferences.encoderCaptureShowOnlyBars = PreferencesWindowBox.check_appearance_encoder_only_bars.Active;
-		}
 		
 		if( preferences.digitsNumber != Convert.ToInt32(UtilGtk.ComboGetActive(combo_decimals)) ) {
 			SqlitePreferences.Update("digitsNumber", UtilGtk.ComboGetActive(combo_decimals), true);
@@ -1198,6 +1696,9 @@ public class PreferencesWindow
 			preferences.muteLogs = PreferencesWindowBox.checkbutton_mute_logs.Active;
 		}
 
+		//this is not stored in SQL
+		preferences.networksAllowChangeDevices = PreferencesWindowBox.check_networks_devices.Active;
+
 		if( preferences.weightStatsPercent != PreferencesWindowBox.radio_weight_percent.Active ) {
 			SqlitePreferences.Update("weightStatsPercent", PreferencesWindowBox.radio_weight_percent.Active.ToString(), true);
 			preferences.weightStatsPercent = PreferencesWindowBox.radio_weight_percent.Active;
@@ -1275,11 +1776,16 @@ public class PreferencesWindow
 				preferences.encoderCaptureTime,
 				(int) PreferencesWindowBox.spin_encoder_capture_time.Value);
 
-		preferences.encoderCaptureInactivityEndTime = preferencesChange(
-				"encoderCaptureInactivityEndTime",
-				preferences.encoderCaptureInactivityEndTime,
-				(int) PreferencesWindowBox.spin_encoder_capture_inactivity_end_time.Value);
-
+		if(! PreferencesWindowBox.check_encoder_capture_inactivity_end_time.Active)
+		{
+			SqlitePreferences.Update("encoderCaptureInactivityEndTime", "-1", true);
+			preferences.encoderCaptureInactivityEndTime = -1;
+		} else {
+			preferences.encoderCaptureInactivityEndTime = preferencesChange(
+					"encoderCaptureInactivityEndTime",
+					preferences.encoderCaptureInactivityEndTime,
+					(int) PreferencesWindowBox.spin_encoder_capture_inactivity_end_time.Value);
+		}
 
 		preferences.encoderCaptureMinHeightGravitatory = preferencesChange(
 				"encoderCaptureMinHeightGravitatory",
@@ -1291,6 +1797,32 @@ public class PreferencesWindow
 				preferences.encoderCaptureMinHeightInertial,
 				(int) PreferencesWindowBox.spin_encoder_capture_min_height_inertial.Value);
 
+		int spinEncoderCaptureDiscardFirstN = Convert.ToInt32(PreferencesWindowBox.spin_encoder_capture_inertial_discard_first_n.Value);
+		if(! checkbutton_encoder_capture_inertial_discard_first_n.Active)
+			spinEncoderCaptureDiscardFirstN = 0;
+		if(spinEncoderCaptureDiscardFirstN != preferences.encoderCaptureInertialDiscardFirstN)
+		{
+			SqlitePreferences.Update("encoderCaptureInertialDiscardFirstN", spinEncoderCaptureDiscardFirstN.ToString(), true);
+			preferences.encoderCaptureInertialDiscardFirstN = spinEncoderCaptureDiscardFirstN;
+		}
+
+		if( preferences.encoderCaptureShowOnlyBars != PreferencesWindowBox.check_appearance_encoder_only_bars.Active ) {
+			SqlitePreferences.Update("encoderCaptureShowOnlyBars", PreferencesWindowBox.check_appearance_encoder_only_bars.Active.ToString(), true);
+			preferences.encoderCaptureShowOnlyBars = PreferencesWindowBox.check_appearance_encoder_only_bars.Active;
+		}
+
+		if( preferences.encoderCaptureShowNRepetitions > 0 && PreferencesWindowBox.radio_encoder_capture_show_all_bars.Active )
+		{
+			SqlitePreferences.Update("encoderCaptureShowNRepetitions", "-1", true);
+			preferences.encoderCaptureShowNRepetitions = -1;
+		}
+		else if( PreferencesWindowBox.radio_encoder_capture_show_only_some_bars.Active &&
+				preferences.encoderCaptureShowNRepetitions != (int) PreferencesWindowBox.spin_encoder_capture_show_only_some_bars.Value) {
+			SqlitePreferences.Update("encoderCaptureShowNRepetitions",
+					PreferencesWindowBox.spin_encoder_capture_show_only_some_bars.Value.ToString(), true);
+			preferences.encoderCaptureShowNRepetitions = (int) PreferencesWindowBox.spin_encoder_capture_show_only_some_bars.Value;
+		}
+
 		if(PreferencesWindowBox.radio_encoder_auto_save_curve_best.Active) {
 			SqlitePreferences.Update("encoderAutoSaveCurve", Constants.EncoderAutoSaveCurve.BEST.ToString(), true);
 			preferences.encoderAutoSaveCurve = Constants.EncoderAutoSaveCurve.BEST;
@@ -1391,11 +1923,41 @@ public class PreferencesWindow
 			preferences.gstreamer = Preferences.GstreamerTypes.SYSTEMSOUNDS;
 		}
 
-		if( preferences.videoDeviceNum != UtilGtk.ComboGetActivePos(combo_camera) ) {
-			SqlitePreferences.Update("videoDevice", UtilGtk.ComboGetActivePos(combo_camera).ToString(), true);
-			preferences.videoDeviceNum = UtilGtk.ComboGetActivePos(combo_camera);
+		//camera stuff
+
+		string cameraCode = wd_list.GetCodeOfFullname(UtilGtk.ComboGetActive(combo_camera));
+		if( cameraCode != "" && preferences.videoDevice != cameraCode ) {
+			SqlitePreferences.Update("videoDevice", cameraCode, true);
+			preferences.videoDevice = cameraCode;
 		}
-		
+
+		string pixelFormat = getSelectedPixelFormat();
+		if( preferences.videoDevicePixelFormat != pixelFormat ) {
+			SqlitePreferences.Update("videoDevicePixelFormat", pixelFormat, true);
+			preferences.videoDevicePixelFormat = pixelFormat;
+		}
+
+		string resolution = getSelectedResolution();
+		if( preferences.videoDeviceResolution != resolution ) {
+			SqlitePreferences.Update("videoDeviceResolution", resolution, true);
+			preferences.videoDeviceResolution = resolution;
+		}
+
+		string framerate = getSelectedFramerate();
+		if( preferences.videoDeviceFramerate != framerate ) {
+			SqlitePreferences.Update("videoDeviceFramerate", framerate, true);
+			preferences.videoDeviceFramerate = framerate; //if it has decimals, separator should be a point
+		}
+
+		int selected_camera_stop_after = Convert.ToInt32(spin_camera_stop_after.Value);
+		if(! check_camera_stop_after.Active)
+			selected_camera_stop_after = 0;
+		if( preferences.videoStopAfter != selected_camera_stop_after) {
+			SqlitePreferences.Update("videoStopAfter", selected_camera_stop_after.ToString(), true);
+			preferences.videoStopAfter = selected_camera_stop_after;
+		}
+
+		//end of camera stuff
 
 		if(PreferencesWindowBox.radio_export_latin.Active) {
 			SqlitePreferences.Update("CSVExportDecimalSeparator","COMMA", true); 
