@@ -34,6 +34,7 @@ public class RepetitiveConditionsWindow
 	[Widget] Gtk.Box hbox_jump_best_worst;
 	[Widget] Gtk.Box hbox_run_best_worst;
 	
+	[Widget] Gtk.VBox vbox_encoder_stuff;
 	[Widget] Gtk.Frame frame_conditions;
 
 	/* jumps */	
@@ -113,7 +114,10 @@ public class RepetitiveConditionsWindow
 	[Widget] Gtk.SpinButton spinbutton_encoder_peakpower_higher;
 	[Widget] Gtk.SpinButton spinbutton_encoder_power_lower;
 	[Widget] Gtk.SpinButton spinbutton_encoder_peakpower_lower;
-	[Widget] Gtk.CheckButton checkbutton_inertial_discard_first_three;
+	[Widget] Gtk.Button button_encoder_automatic_greater_minus_1;
+	[Widget] Gtk.Button button_encoder_automatic_greater_plus_1;
+	[Widget] Gtk.Button button_encoder_automatic_lower_minus_1;
+	[Widget] Gtk.Button button_encoder_automatic_lower_plus_1;
 
 
 	[Widget] Gtk.Button button_test_good;
@@ -256,7 +260,7 @@ public class RepetitiveConditionsWindow
 		frame_encoder_automatic_conditions.Hide();
 		vbox_encoder_manual.Hide();
 		notebook_encoder_conditions.Hide();
-		checkbutton_inertial_discard_first_three.Hide();
+		vbox_encoder_stuff.Hide();
 
 		notebook_main.GetNthPage(RHYTHMPAGE).Hide();
 		notebook_main.ShowTabs = false;
@@ -272,6 +276,7 @@ public class RepetitiveConditionsWindow
 			hbox_run_conditions.Show();
 			frame_conditions.Show();
 		} else { //encoder (grav and inertial)
+			vbox_encoder_stuff.Show();
 			frame_encoder_automatic_conditions.Show();
 			notebook_main.ShowTabs = true;
 
@@ -279,9 +284,6 @@ public class RepetitiveConditionsWindow
 			if(checkbutton_encoder_show_manual_feedback.Active)
 				notebook_encoder_conditions.Show();
 
-			if(bellMode == Constants.BellModes.ENCODERINERTIAL)
-				checkbutton_inertial_discard_first_three.Show();
-
 			combo_encoder_main_variable.Active = UtilGtk.ComboMakeActive(combo_encoder_main_variable,
 					Constants.GetEncoderVariablesCapture(encoderMainVariable));
 
@@ -500,6 +502,23 @@ public class RepetitiveConditionsWindow
 	void on_spinbutton_encoder_automatic_lower_value_changed (object o, EventArgs args) {
 		checkbutton_encoder_automatic_lower.Active = true;
 	}
+
+	void on_button_encoder_automatic_greater_minus_1_clicked (object o, EventArgs args)
+	{
+		spinbutton_encoder_automatic_greater.Value --;
+	}
+	void on_button_encoder_automatic_greater_plus_1_clicked (object o, EventArgs args)
+	{
+		spinbutton_encoder_automatic_greater.Value ++;
+	}
+	void on_button_encoder_automatic_lower_minus_1_clicked (object o, EventArgs args)
+	{
+		spinbutton_encoder_automatic_lower.Value --;
+	}
+	void on_button_encoder_automatic_lower_plus_1_clicked (object o, EventArgs args)
+	{
+		spinbutton_encoder_automatic_lower.Value ++;
+	}
 			
 	void on_checkbutton_encoder_show_manual_feedback_toggled (object o, EventArgs args) {
 		if(checkbutton_encoder_show_manual_feedback.Active)
@@ -1015,10 +1034,5 @@ public class RepetitiveConditionsWindow
 	public int EncoderPeakPowerLowerValue {
 		get { return Convert.ToInt32(spinbutton_encoder_peakpower_lower.Value); }
 	}
-	
-	public bool EncoderInertialDiscardFirstThree {
-		get { return checkbutton_inertial_discard_first_three.Active; }
-	}
-
 }
 
