@@ -669,7 +669,7 @@ public class RepairRunIntervalWindow
 		//myTreeView.AppendColumn ( Catalog.GetString ("Time"), new CellRendererText(), "text", count++);
 
 		Gtk.TreeViewColumn timeColumn = new Gtk.TreeViewColumn ();
-		timeColumn.Title = Catalog.GetString("TF");
+		timeColumn.Title = Catalog.GetString("Lap time");
 		Gtk.CellRendererText timeCell = new Gtk.CellRendererText ();
 		timeCell.Editable = true;
 		timeCell.Edited += timeCellEdited;
@@ -1238,9 +1238,8 @@ public partial class ChronoJumpWindow
 	private void on_button_run_with_reaction_time_help_clicked (object o, EventArgs args)
 	{
 		new DialogMessage(Constants.MessageTypes.INFO,
-				"TODO" +
-				"\nneed new device (introduce name)" +
-				"\ntest will start when person is at start pad and push button is pressed" +
+				"\nThis feature need a new Chronojump device under development." +
+				"\n\nTest will start when person is at start pad and push button is pressed" +
 				"\nreaction time will be in ms and as a comment on Description"
 				);
 	}
