@@ -40,8 +40,8 @@ public class SplashWindow
 
 	[Widget] Gtk.Button fakeButtonClose;
 	public bool FakeButtonCreated = false;
-	string progVersion = "";
-	
+	//string progVersion = "";
+
 	static SplashWindow SplashWindowBox;
 
 	public SplashWindow ()
@@ -110,8 +110,10 @@ public class SplashWindow
 			progressbarSubRate.Fraction = fraction;
 	}
 	
-	public void UpdateLabel (string text) {
+	public void UpdateLabel (string text)
+	{
 		myLabel.Text = text;
+		myLabel.UseMarkup = true;
 	}
 
 	public void Show_button_open_database_folder () {
@@ -193,9 +195,11 @@ public class SplashWindow
 		LogB.Debug("splash_window hide end");
 	}
 
+	/*
 	public string ProgVersion {
-		set { progVersion = value; }
+		set { grogVersion = value; }
 	}
+	*/
 
 	private void on_delete_event (object o, DeleteEventArgs args) {
 		splash_window.Destroy ();
