@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
+ *  Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -135,13 +135,7 @@ public class JumpRj : Jump
 	int jumps; //total number of jumps
 	double time; //time elapsed
 	string limited; //the teorically values, eleven jumps: "11=J" (time recorded in "time"), 10 seconds: "10=T" (jumps recorded in jumps)
-	double limitAsDouble;	//-1 for non limited (unlimited repetitive jump until "finish" is clicked)
 	bool jumpsLimited;
-	bool firstRjValue;
-	private double tcCount;
-	private double tvCount;
-	private double lastTc;
-	private double lastTv;
 	private string angleString;
 	
 	public JumpRj() {
