@@ -33,6 +33,7 @@ public class Preferences
 	public bool personWinHide;
 	public bool personPhoto;
 	public bool encoderCaptureShowOnlyBars;
+	public int encoderCaptureShowNRepetitions;
 
 	public bool showPower;
 	public bool showStiffness;
@@ -56,10 +57,11 @@ public class Preferences
 	
 	//encoder capture
 	public int encoderCaptureTime;
-	public int encoderCaptureInactivityEndTime;
+	public int encoderCaptureInactivityEndTime; // -1 if not automatically end
 	public Constants.EncoderVariablesCapture encoderCaptureMainVariable;
 	public int encoderCaptureMinHeightGravitatory;
 	public int encoderCaptureMinHeightInertial;
+	public int encoderCaptureInertialDiscardFirstN;
 	public bool encoderCaptureCheckFullyExtended;
 	public int encoderCaptureCheckFullyExtendedValue;
 	public Constants.EncoderAutoSaveCurve encoderAutoSaveCurve;
@@ -73,7 +75,11 @@ public class Preferences
 	public double encoderSmoothCon;
 	public Constants.Encoder1RMMethod encoder1RMMethod;
 	
-	public int videoDeviceNum; 		//AKA videoDevice
+	public string videoDevice;
+	public string videoDevicePixelFormat;
+	public string videoDeviceResolution;
+	public string videoDeviceFramerate; //cannot be a double because decimals seem exactly important on mac. if decimal will have always a '.' as needed by ffmpeg
+	public int videoStopAfter;
 	public string CSVExportDecimalSeparator;
 	public string language;
 	public string crashLogLanguage;
@@ -84,6 +90,7 @@ public class Preferences
 	public bool askDeletion;
 	public int digitsNumber;
 	public bool muteLogs;
+	public bool networksAllowChangeDevices; //managed on preferences;
 
 	/*
 	 * these are NOT sent to preferences window
@@ -121,6 +128,8 @@ public class Preferences
 	public GstreamerTypes gstreamer;
 	public static string GstreamerStr = "gstreamer"; //in order to ensure write correctly on SQL
 
+	public bool debugMode;
+
 	/*
 	 * these are unused on SqlitePreferences.SelectAll
 	 */
@@ -292,9 +301,26 @@ public class Preferences
 			"\n\nLast Calibrate:" +
 			"\n\t- internal value: " + forceSensorCalibrationFactor.ToString() +
 			"\n\t- with: " + forceSensorCalibrationWeight.ToString() +
-			" Kg\n\t- at: " + forceSensorCalibrationDateTime;
+			" Kg\n\t- at: " + forceSensorCalibrationDateTime +
+			"\n\nNote this information is related only to the tares and calibrations of any force sensor on this machine.";
 	}
 
+	public char CSVColumnDelimiter
+	{
+		get {
+			char columnDelimiter = ',';
+			if(CSVExportDecimalSeparator == "COMMA")
+				columnDelimiter = ';';
+
+			return columnDelimiter;
+		}
+	}
+
+	public bool IsVideoConfigured()
+	{
+		return (videoDevice != "" && videoDevicePixelFormat != "" &&
+				videoDeviceResolution != "" && videoDeviceFramerate != "");
+	}
 
 	~Preferences() {}
 	   
