@@ -58,40 +58,14 @@ public class Sprint
 	}
 	*/
 
-	public bool CallR(int graphWidth, int graphHeight)
+	public bool CallR(int graphWidth, int graphHeight, string personName)
 	{
-		string executable = UtilEncoder.RProcessBinURL();
-		List<string> parameters = new List<string>();
-
-		//A) photocellsScript
-		string photocellsScript = UtilEncoder.GetSprintPhotocellsScript();
-		if(UtilAll.IsWindows())
-			photocellsScript = photocellsScript.Replace("\\","/");
-
-		parameters.Insert(0, "\"" + photocellsScript + "\"");
-
-		//B) tempPath
-		string tempPath = Path.GetTempPath();
-		if(UtilAll.IsWindows())
-			tempPath = tempPath.Replace("\\","/");
-
-		parameters.Insert(1, "\"" + tempPath + "\"");
-
-		//C) writeOptions
-		writeOptionsFile(graphWidth, graphHeight);
-
-		LogB.Information("\nCalling sprint.R ----->");
-
-		//D) call process
-		//ExecuteProcess.run (executable, parameters);
-		ExecuteProcess.Result execute_result = ExecuteProcess.run (executable, parameters);
-		//LogB.Information("Result = " + execute_result.stdout);
-
-		LogB.Information("\n<------ Done calling sprint.R.");
-		return execute_result.success;
+		LogB.Information("\nsprint CallR ----->");
+		writeOptionsFile(graphWidth, graphHeight, personName);
+		return ExecuteProcess.CallR(UtilEncoder.GetSprintPhotocellsScript());
 	}
 
-	private void writeOptionsFile(int graphWidth, int graphHeight)
+	private void writeOptionsFile(int graphWidth, int graphHeight, string personName)
 	{
 		/*
 		string scriptOptions =
@@ -114,7 +88,8 @@ public class Sprint
 			"#tempC\n" + 		tempC + "\n" +
 			"#os\n" + 		UtilEncoder.OperatingSystemForRGraphs() + "\n" +
 			"#graphWidth\n" + 	graphWidth.ToString() + "\n" +
-			"#graphHeight\n" + 	graphHeight.ToString() + "\n";
+			"#graphHeight\n" + 	graphHeight.ToString() + "\n" +
+			"#personName\n" + 	personName + "\n";
 
 		TextWriter writer = File.CreateText(Path.GetTempPath() + "Roptions.txt");
 		writer.Write(scriptOptions);
