@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -60,9 +60,11 @@ class SqliteJumpRj : SqliteJump
 
 	public static int Insert (bool dbconOpened, string tableName, string uniqueID, int personID, int sessionID, string type, double tvMax, double tcMax, double fall, double weight, string description, double tvAvg, double tcAvg, string tvString, string tcString, int jumps, double time, string limited, string angleString, int simulated )
 	{
+		Console.WriteLine("At SQL insert RJ");
+
 		if(! dbconOpened)
 			Sqlite.Open();
-		
+
 		if(uniqueID == "-1")
 			uniqueID = "NULL";
 
@@ -91,7 +93,7 @@ class SqliteJumpRj : SqliteJump
 		return myLast;
 	}
 
-	public new static string[] SelectJumps(bool dbconOpened, int sessionID, int personID, string filterWeight, string filterType) 
+	public static string[] SelectJumps(bool dbconOpened, int sessionID, int personID, string filterWeight, string filterType) 
 	{
 		if(!dbconOpened)
 			Sqlite.Open();
