@@ -94,6 +94,9 @@ class SqlitePerson : Sqlite
 	public static Person Select(int uniqueID) {
 		return Select(false, " WHERE uniqueID = " + uniqueID);
 	}
+	public static Person SelectByName(string name) {
+		return Select(false, " WHERE name = \"" + name + "\"");
+	}
 	public static Person SelectByRFID(string rfid) {
 		return Select(false, " WHERE future1 = \"" + rfid + "\"");
 	}
