@@ -81,6 +81,7 @@ class SqlitePreferences : Sqlite
 				Insert ("personWinHide", "False", dbcmdTr);
 				Insert ("personPhoto", "True", dbcmdTr);
 				Insert ("encoderCaptureShowOnlyBars", "False", dbcmdTr);
+				Insert ("encoderCaptureShowNRepetitions", "-1", dbcmdTr);
 				Insert ("digitsNumber", "3", dbcmdTr);
 				Insert ("showPower", "True", dbcmdTr);
 				Insert ("showStiffness", "True", dbcmdTr);
@@ -126,6 +127,7 @@ class SqlitePreferences : Sqlite
 				Insert ("encoderCaptureMainVariable", Constants.EncoderVariablesCapture.MeanPower.ToString(), dbcmdTr);
 				Insert ("encoderCaptureMinHeightGravitatory", "20", dbcmdTr);
 				Insert ("encoderCaptureMinHeightInertial", "5", dbcmdTr);
+				Insert ("encoderCaptureInertialDiscardFirstN", "3", dbcmdTr);
 				Insert ("encoderCaptureCheckFullyExtended", "True", dbcmdTr);
 				Insert ("encoderCaptureCheckFullyExtendedValue", "4", dbcmdTr);
 				Insert ("encoderCaptureBarplotFontSize", "14", dbcmdTr);
@@ -169,7 +171,11 @@ class SqlitePreferences : Sqlite
 				Insert (EncoderRhythmRestClustersSecondsStr, Util.ConvertToPoint(er.RestClustersSeconds), dbcmdTr);
 
 
-				Insert ("videoDevice", "0", dbcmdTr); //first
+				Insert ("videoDevice", "", dbcmdTr); //first
+				Insert ("videoDevicePixelFormat", "", dbcmdTr);
+				Insert ("videoDeviceResolution", "", dbcmdTr);
+				Insert ("videoDeviceFramerate", "", dbcmdTr);
+				Insert ("videoStopAfter", "2", dbcmdTr);
 				Insert ("inertialmomentum", "0.01", dbcmdTr);
 				Insert ("CSVExportDecimalSeparator", Util.GetDecimalSeparatorFromLocale(), dbcmdTr);
 				Insert ("RGraphsTranslate", "True", dbcmdTr);
@@ -284,6 +290,8 @@ class SqlitePreferences : Sqlite
 				preferences.personPhoto = reader[1].ToString() == "True";
 			else if(reader[0].ToString() == "encoderCaptureShowOnlyBars")
 				preferences.encoderCaptureShowOnlyBars = reader[1].ToString() == "True";
+			else if(reader[0].ToString() == "encoderCaptureShowNRepetitions")
+				preferences.encoderCaptureShowNRepetitions = Convert.ToInt32(reader[1].ToString());
 			else if(reader[0].ToString() == "showPower")
 				preferences.showPower = reader[1].ToString() == "True";
 			else if(reader[0].ToString() == "showStiffness")
@@ -314,6 +322,8 @@ class SqlitePreferences : Sqlite
 				preferences.encoderCaptureMinHeightGravitatory = Convert.ToInt32(reader[1].ToString());
 			else if(reader[0].ToString() == "encoderCaptureMinHeightInertial")
 				preferences.encoderCaptureMinHeightInertial = Convert.ToInt32(reader[1].ToString());
+			else if(reader[0].ToString() == "encoderCaptureInertialDiscardFirstN")
+				preferences.encoderCaptureInertialDiscardFirstN = Convert.ToInt32(reader[1].ToString());
 			else if(reader[0].ToString() == "encoderCaptureCheckFullyExtended")
 				preferences.encoderCaptureCheckFullyExtended = reader[1].ToString() == "True";
 			else if(reader[0].ToString() == "encoderCaptureCheckFullyExtendedValue")
@@ -365,7 +375,15 @@ class SqlitePreferences : Sqlite
 
 			//video... other
 			else if(reader[0].ToString() == "videoDevice")
-				preferences.videoDeviceNum = Convert.ToInt32(reader[1].ToString());
+				preferences.videoDevice = reader[1].ToString();
+			else if(reader[0].ToString() == "videoDevicePixelFormat")
+				preferences.videoDevicePixelFormat = reader[1].ToString();
+			else if(reader[0].ToString() == "videoDeviceResolution")
+				preferences.videoDeviceResolution = reader[1].ToString();
+			else if(reader[0].ToString() == "videoDeviceFramerate")
+				preferences.videoDeviceFramerate = reader[1].ToString(); //if it is decimal will be always a '.' as needed by ffmpeg
+			else if(reader[0].ToString() == "videoStopAfter")
+				preferences.videoStopAfter = Convert.ToInt32(reader[1].ToString());
 			else if(reader[0].ToString() == "CSVExportDecimalSeparator")
 				preferences.CSVExportDecimalSeparator = reader[1].ToString();
 			else if(reader[0].ToString() == "language")
