@@ -15,13 +15,14 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
 using System.Data;
 using System.IO;
 using System.Collections; //ArrayList
+using System.Collections.Generic; //List<T>
 using Mono.Data.Sqlite;
 
 
@@ -175,6 +176,54 @@ class SqliteRunType : Sqlite
 		return myRunType;
 	}
 
+	//use SelectRunTypes object. Since 1.6.3
+	public static List<object> SelectRunTypesNew(string allRunsName, bool onlyName) 
+	{
+		//allRunsName: add and "allRunsName" value
+		//onlyName: return only type name
+
+		string whereString = "";
+
+		Sqlite.Open();
+		dbcmd.CommandText = "SELECT * " +
+			" FROM " + Constants.RunTypeTable +
+			whereString +
+			" ORDER BY uniqueID";
+
+		LogB.SQL(dbcmd.CommandText.ToString());
+		dbcmd.ExecuteNonQuery();
+
+		SqliteDataReader reader;
+		reader = dbcmd.ExecuteReader();
+
+		List<object> types = new List<object>();
+
+		SelectRunTypes type;
+		if(allRunsName != "") {
+			type = new SelectRunTypes(allRunsName);
+			types.Add(type);
+		}
+
+		while(reader.Read()) {
+			if(onlyName) {
+				type = new SelectRunTypes(reader[1].ToString());
+			} else {
+				type = new SelectRunTypes(
+						Convert.ToInt32(reader[0]), 	//uniqueID
+						reader[1].ToString(),		//nameEnglish
+						Convert.ToDouble(Util.ChangeDecimalSeparator(reader[2].ToString())), 	//distance
+						reader[3].ToString() 		//description
+						);
+			}
+			types.Add(type);
+		}
+
+		reader.Close();
+		Sqlite.Close();
+
+		return types;
+	}
+	//on newly cereated code use above method
 	public static string[] SelectRunTypes(string allRunsName, bool onlyName) 
 	{
 		//allRunsName: add and "allRunsName" value
@@ -461,6 +510,52 @@ class SqliteRunIntervalType : SqliteRunType
 		return myLast;
 	}
 
+	//use SelectRunITypes object. Since 1.6.3
+	public static List<object> SelectRunIntervalTypesNew(string allRunsName, bool onlyName)
+	{
+		Sqlite.Open();
+		dbcmd.CommandText = "SELECT * " +
+			" FROM " + Constants.RunIntervalTypeTable +
+			" ORDER BY uniqueID";
+
+		LogB.SQL(dbcmd.CommandText.ToString());
+		dbcmd.ExecuteNonQuery();
+
+		SqliteDataReader reader;
+		reader = dbcmd.ExecuteReader();
+
+		List<object> types = new List<object>();
+
+		SelectRunITypes type;
+		if(allRunsName != "") {
+			type = new SelectRunITypes(allRunsName);
+			types.Add(type);
+		}
+
+		while(reader.Read()) {
+			if(onlyName) {
+				type = new SelectRunITypes(reader[1].ToString());
+			} else {
+				type = new SelectRunITypes(
+						Convert.ToInt32(reader[0]), 	//uniqueID
+						reader[1].ToString(),		//nameEnglish
+						Convert.ToDouble(Util.ChangeDecimalSeparator(reader[2].ToString())), 	//distance
+						Util.IntToBool(Convert.ToInt32(reader[3].ToString())), 	//tracksLimited
+						Convert.ToInt32(reader[4].ToString()), 			//fixedValue
+						Util.IntToBool(Convert.ToInt32(reader[5].ToString())), 	//unlimited
+						reader[6].ToString(),					//description
+						Util.ChangeDecimalSeparator(reader[7].ToString())	//distancesString
+					    );
+			}
+			types.Add(type);
+		}
+
+		reader.Close();
+		Sqlite.Close();
+
+		return types;
+	}
+	//on newly cereated code use above method
 	public static string[] SelectRunIntervalTypes(string allRunsName, bool onlyName) 
 	{
 		Sqlite.Open();
@@ -577,7 +672,7 @@ class SqliteRunIntervalType : SqliteRunType
 		}
 	}
 	
-	public static void Delete(string name)
+	public static new void Delete(string name)
 	{
 		Sqlite.Open();
 		dbcmd.CommandText = "Delete FROM " + Constants.RunIntervalTypeTable +
