@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -55,11 +55,11 @@ class SqliteStat : Sqlite
 		//if there's more than one session, it sends the avg or max
 		string groupByString = "";
 		if (ini.Length > 0) {
-			groupByString = " GROUP BY jump.personID, jump.sessionID ";
+			groupByString = " GROUP BY jump.type, jump.personID, jump.sessionID ";
 		}
 		//if multisession, order by person.name, sessionID for being able to present results later
 		if(multisession) {
-			orderByString = orderByString + tp + ".name, sessionID, ";
+			orderByString = orderByString + tp + ".name, jump.type, sessionID, ";
 		}
 		
 		Sqlite.Open();
@@ -146,11 +146,11 @@ class SqliteStat : Sqlite
 		//there's no chance of mixing tv and weight of different jumps in multisessions because only tv is returned
 		string groupByString = "";
 		if (ini.Length > 0) {
-			groupByString = " GROUP BY jump.personID, jump.sessionID ";
+			groupByString = " GROUP BY jump.type, jump.personID, jump.sessionID ";
 		}
 		//if multisession, order by person.name, sessionID for being able to present results later
 		if(multisession) {
-			orderByString = orderByString + "" + tp + ".name, jump.sessionID, ";
+			orderByString = orderByString + "" + tp + ".name, jump.type, jump.sessionID, ";
 		}
 		
 		Sqlite.Open();
