@@ -198,6 +198,11 @@ public class TreeViewPersons
 		return found;
 	}
 
+	public void SelectRowByUniqueID(int personID)
+	{
+		SelectRow(FindRow(personID));
+	}
+
 	public void SelectNextRow(int personID)
 	{
 		SelectRow(FindRow(personID) +1);
