@@ -103,7 +103,7 @@ public class Util
 		else 
 			return("OTHER");
 	}
-	
+
 	//used for load from the database all numbers with correct decimal separator (locale defined)
 	//used also for the tvString, tcString, and runIntervalTimesString
 	//also used for reading . data coming from force sensor
@@ -438,10 +438,10 @@ public class Util
 		return myStringBuilder.ToString();
 	}
 	
-	public static string ChangeChars(string str, string charIni, string charEnd) 
+	public static string ChangeChars(string str, string charBefore, string charAfter)
 	{
 		StringBuilder myStringBuilder = new StringBuilder(str);
-		myStringBuilder.Replace(charIni, charEnd);
+		myStringBuilder.Replace(charBefore, charAfter);
 		return myStringBuilder.ToString();
 	}
 
@@ -971,6 +971,44 @@ public class Util
 		}
 	}
 
+	/*
+	 * <--------------- end of force sensor suff
+	 */
+
+	/*
+	 * run encoder suff ------------------>
+	 */
+
+	//to store run encoder data and graphs
+	public static string GetRaceAnalyzerDir()
+	{
+		return Path.Combine(
+				Environment.GetFolderPath(Environment.SpecialFolder.LocalApplicationData),
+				"Chronojump" + Path.DirectorySeparatorChar + "raceAnalyzer");
+	}
+	public static void CreateRaceAnalyzerDirIfNeeded ()
+	{
+		string dir = GetRaceAnalyzerDir();
+		if( ! Directory.Exists(dir)) {
+			Directory.CreateDirectory (dir);
+			LogB.Information ("created dir:", dir);
+		}
+	}
+
+	//runEncoder organized by sessions.
+	public static string GetRaceAnalyzerSessionDir (int sessionID)
+	{
+		return GetRaceAnalyzerDir() + Path.DirectorySeparatorChar + sessionID.ToString();
+	}
+	public static void CreateRaceAnalyzerSessionDirIfNeeded (int sessionID)
+	{
+		string dir = GetRaceAnalyzerSessionDir(sessionID);
+		if( ! Directory.Exists(dir)) {
+			Directory.CreateDirectory (dir);
+			LogB.Information ("created dir:", dir);
+		}
+	}
+
 	/*
 	 * <--------------- end of force sensor suff
 	 */
@@ -989,6 +1027,8 @@ public class Util
 		}
 	}
 
+//TODO: now using mp4, ensure old avi can be also retrieved
+
 	//returns absolute path, but in encoder this URL is stored in database as relative to be able to move data between computers
 	//see SqliteEncoder.removeURLpath
 	public static string GetVideoFileName (int sessionID, Constants.TestTypes testType, int uniqueID) {
@@ -1036,6 +1076,25 @@ public class Util
 	 * --------------------- End of GetPhoto stuff
 	 */
 
+	/*
+	 * --------------------- Start of video stuff
+	 */
+
+	//Pre: filename without 0001.png
+	public static string GetWebcamPhotoTempFileNamePre(string videoDevice)
+	{
+		string fileName = Constants.PhotoTemp;
+
+		return Path.Combine(Path.GetTempPath(), Constants.PhotoTemp + "-" + videoDevice + "-");
+	}
+
+	//Pre: filename with 0001.png
+	public static string GetWebcamPhotoTempFileNamePost(string videoDevice)
+	{
+		return GetWebcamPhotoTempFileNamePre(videoDevice) + "0001.png";
+	}
+
+
 	public static string GetVideoTempFileName() {
 		return Path.Combine(
 				Path.GetTempPath(), Constants.VideoTemp + 
@@ -1051,6 +1110,7 @@ public class Util
 				Path.GetTempPath(), fileName + GetMultimediaExtension(Constants.MultimediaItems.PHOTO));
 	}
 	
+
 	public static string GetMultimediaExtension (string filename)
 	{
 		if(UtilMultimedia.GetImageType(filename) == UtilMultimedia.ImageTypes.JPEG)
@@ -1081,13 +1141,16 @@ public class Util
 				File.Move(origin, destination);
 			} catch {
 			*/
+				//check size before copyiing. To know if file has been copied while is not fully written
+				LogB.Information("sizeOrigin: " + (new System.IO.FileInfo(origin).Length).ToString());
+
 				File.Copy(origin, destination, true); //can be overwritten
 			//}
 			return true;
 		} else
 			return false;
 	}
-	
+
 	public static void DeleteVideo(int sessionID, Constants.TestTypes type, int uniqueID) {
 		string fileName = GetVideoFileName(sessionID, type, uniqueID);
 		if(File.Exists(fileName)) 
@@ -1166,10 +1229,10 @@ public class Util
 	public static string GetSoundsDir(){
 		return GetImagesDir();
 	}
-	
-	
+
+	static string backupDir = GetDatabaseDir() + Path.DirectorySeparatorChar + "backup";
+
 	public static void BackupDirCreateIfNeeded () {
-		string backupDir = GetDatabaseDir() + Path.DirectorySeparatorChar + "backup";
 		if( ! Directory.Exists(backupDir)) {
 			Directory.CreateDirectory (backupDir);
 			LogB.Information ("created backup dir");
@@ -1178,8 +1241,6 @@ public class Util
 
 	public static void BackupDatabase () {
 		string homeDir = GetDatabaseDir();
-		string backupDir = homeDir + Path.DirectorySeparatorChar + "backup";
-		
 		string dateParsed = UtilDate.ToFile(DateTime.Now);
 
 		if(File.Exists(System.IO.Path.Combine(homeDir, "chronojump.db")))
@@ -1190,14 +1251,6 @@ public class Util
 		}
 	}
 
-	//http://stackoverflow.com/a/58779	
-	public static void CopyFilesRecursively(DirectoryInfo source, DirectoryInfo target) {
-		foreach (DirectoryInfo dir in source.GetDirectories())
-			CopyFilesRecursively(dir, target.CreateSubdirectory(dir.Name));
-		foreach (FileInfo file in source.GetFiles())
-			file.CopyTo(Path.Combine(target.FullName, file.Name));
-	}
-
 	public static bool FileDelete(string fileName) 
 	{
 		LogB.Information("Checking if this filename exists: " + fileName);
@@ -1550,6 +1603,15 @@ public class Util
 		return soundList[soundListPos];
 	}
 
+	public static bool SoundIsPum()
+	{
+		return (soundList[soundListPos].EndsWith("we_will_rock_you_pum.wav"));
+	}
+	public static bool SoundIsPam()
+	{
+		return (soundList[soundListPos].EndsWith("we_will_rock_you_pam.wav"));
+	}
+
 
 	/*
 	 * ------------- end of sound stuff -----------
@@ -2148,3 +2210,50 @@ public class Util
 		}
 	}
 }
+
+public class UtilCopy
+{
+	public int BackupMainDirsCount;
+	public int BackupSecondDirsCount;
+	public int BackupSecondDirsLength;
+	public string LastMainDir;
+	public string LastSecondDir;
+
+	//to go faster on CopyFilesRecursively
+	static string backupDir = Util.GetDatabaseDir() + Path.DirectorySeparatorChar + "backup";
+
+	public UtilCopy()
+	{
+		BackupMainDirsCount = 0;
+		BackupSecondDirsCount = 0;
+		BackupSecondDirsLength = 0;
+		LastMainDir = "";
+		LastSecondDir = "";
+	}
+
+	//http://stackoverflow.com/a/58779
+	public void CopyFilesRecursively(DirectoryInfo source, DirectoryInfo target, uint level)
+	{
+		DirectoryInfo [] diArray = source.GetDirectories();
+		foreach (DirectoryInfo dir in diArray)
+			if(dir.ToString() != backupDir) //do not copy backup files
+			{
+				if(level == 0)
+				{
+					BackupMainDirsCount ++;
+					LastMainDir = Util.GetLastPartOfPath (dir.ToString());
+					BackupSecondDirsCount = 0;
+					//LogB.Information("at level 0: " + dir);
+				} else if(level == 1) {
+					BackupSecondDirsLength = diArray.Length;
+					BackupSecondDirsCount ++;
+					LastSecondDir = Util.GetLastPartOfPath (dir.ToString());
+					//LogB.Information("at level 1: " + dir);
+				}
+				CopyFilesRecursively(dir, target.CreateSubdirectory(dir.Name), level +1);
+
+			}
+		foreach (FileInfo file in source.GetFiles())
+			file.CopyTo(Path.Combine(target.FullName, file.Name));
+	}
+}
