@@ -246,10 +246,24 @@ public class UtilEncoder
 	public static string GetSprintImage() {
 		return System.IO.Path.Combine(Path.GetTempPath(), "sprintGraph.png");
 	}
+	public static string GetSprintEncoderImage() {
+		return System.IO.Path.Combine(Path.GetTempPath(), "sprintEncoderGraph.png");
+	}
 
-	public static string GetmifPath() {
+	public static string GetScriptsPath() {
 		return System.IO.Path.Combine(Util.GetDataDir(), "r-scripts");
 	}
+
+	public static string GetRaceAnalyzerScript() {
+		return System.IO.Path.Combine(GetSprintPath(), "sprintEncoder.R");
+	}
+	public static string GetRaceAnalyzerCSVFileName() {
+		return Path.Combine(Path.GetTempPath(), "cj_race_analyzer_data.csv");
+	}
+	public static string GetRaceAnalyzerTempFileName() {
+		return Path.Combine(Path.GetTempPath(), "cj_race_analyzer_graph.png");
+	}
+
 	public static string GetmifScript() {
 		return System.IO.Path.Combine(GetSprintPath(), "maximumIsometricForce.R");
 	}
@@ -336,7 +350,7 @@ public class UtilEncoder
 
 	public static EncoderGraphROptions PrepareEncoderGraphOptions(
 			string title, EncoderStruct es, bool neuromuscularProfileDo, bool translate, bool debug, bool crossValidate,
-			bool cutByTriggers, string triggerStr)
+			bool cutByTriggers, string triggerStr, bool separateSessionInDays, EncoderGraphROptions.AnalysisModes analysisMode)
 	{
 		string operatingSystem = OperatingSystemForRGraphs();
 			
@@ -391,7 +405,7 @@ public class UtilEncoder
 				title, operatingSystem,
 				Util.StringArrayToString(Constants.EncoderEnglishWords,";"),
 				Util.StringArrayToString(encoderTranslatedWordsOK,";"),
-				debug, crossValidate, cutByTriggers, triggerStr
+				debug, crossValidate, cutByTriggers, triggerStr, separateSessionInDays, analysisMode
 				);
 	}
 
@@ -808,6 +822,8 @@ public class UtilEncoder
 							Constants.EncoderConfigurationNames.LINEARONPLANEWEIGHTDIFFANGLE));
 				list.Add(new EncoderConfiguration(
 							Constants.EncoderConfigurationNames.LINEARONPLANEWEIGHTDIFFANGLEMOVPULLEY));
+				list.Add(new EncoderConfiguration(
+							Constants.EncoderConfigurationNames.PNEUMATIC));
 			} else {
 				list.Add(new EncoderConfiguration(
 							Constants.EncoderConfigurationNames.LINEARINERTIAL));
