@@ -136,6 +136,11 @@ public class UtilGtk
 		}
 	}
 
+	public static void ComboDelByPosition(ComboBox myCombo, int pos)
+	{
+		myCombo.RemoveText(pos);
+	}
+
 	public static void ComboDelThisValue(ComboBox myCombo, string toRemove) {
 		int i=0;
 		TreeIter iter;
@@ -205,6 +210,15 @@ public class UtilGtk
 			myCombo.AppendText (l.ToString());
 	}
 	
+	public static void ComboUpdate(ComboBox myCombo, List<string> list) {
+		//1stdelete combo values
+		comboDelAll(myCombo);
+
+		//2nd put new values
+		foreach (string l in list)
+			myCombo.AppendText (l);
+	}
+
 	public static void ComboAdd(ComboBox myCombo, string str) {
 		myCombo.AppendText (str);
 	}
@@ -445,6 +459,8 @@ public class UtilGtk
 	public static Gdk.Color BLUE = new Gdk.Color(0x6c,0x77,0xab);
 	public static Gdk.Color BLUE_CLEAR = new Gdk.Color(0xa0,0xa7,0xca);
 	public static Gdk.Color YELLOW = new Gdk.Color(0xff,0xcc,0x01);
+	public static Gdk.Color YELLOW_DARK = new Gdk.Color(0xcd,0xcd,0x00);
+	public static Gdk.Color ORANGE_DARK = new Gdk.Color(0xff,0x7f,0x00);
 	
 	public static Gdk.Color GREEN_PLOTS = new Gdk.Color(0,200,0);
 	public static Gdk.Color RED_PLOTS = new Gdk.Color(200,0,0);
@@ -531,6 +547,17 @@ public class UtilGtk
 	{
 		v.ModifyBg(StateType.Normal, color);
 	}
+	public static void ViewportColorDefault(Gtk.Viewport v)
+	{
+		//v.ModifyBg(StateType.Normal); //resets to the default color
+
+		//create a new viewport and get the color
+		Gtk.Viewport vTemp = new Gtk.Viewport();
+		Gdk.Color colorViewportDefault = vTemp.Style.Background(StateType.Normal);
+
+		//assign the color to our requested viewport
+		v.ModifyBg(StateType.Normal, colorViewportDefault); //resets to the default color
+	}
 
 	public static void ChronopicColors(Gtk.Viewport v, Gtk.Label l1, Gtk.Label l2, bool connected) {
 		//if(! v.Style.Background(StateType.Normal).Equal(BLUE))
@@ -665,7 +692,8 @@ public class UtilGtk
 	 */
 
 	
-	public static void ErasePaint(Gtk.DrawingArea da, Gdk.Pixmap px) {
+	public static void ErasePaint(Gtk.DrawingArea da, Gdk.Pixmap px)
+	{
 		px.DrawRectangle (da.Style.WhiteGC, true, 0, 0, da.Allocation.Width, da.Allocation.Height);
 		da.QueueDraw(); // -- refresh
 	}
